@@ -2,6 +2,7 @@
 """This file contains the interface for analysis plugins."""
 
 import abc
+import collections
 import logging
 import Queue
 import sys
@@ -9,6 +10,7 @@ import threading
 import time
 
 import requests
+
 # Some distributions unvendor urllib3 from the requests module, and we need to
 # access some methods inside urllib3 to disable warnings. We'll try to import it
 # here, to keep the imports together.
@@ -17,17 +19,14 @@ try:
 except ImportError:
   urllib3 = None
 
-from collections import defaultdict
-
 from plaso.analysis import definitions
-from plaso.engine import queue
-from plaso.lib import timelib
+from plaso.containers import events
+from plaso.containers import reports
 from plaso.lib import errors
-from plaso.lib import event
 
 
-class AnalysisPlugin(queue.ItemQueueConsumer):
-  """Class that implements the analysis plugin object interface."""
+class AnalysisPlugin(object):
+  """Class that defines the analysis plugin interface."""
 
   # The URLS should contain a list of URLs with additional information about
   # this analysis plugin.
@@ -48,37 +47,18 @@ class AnalysisPlugin(queue.ItemQueueConsumer):
   # should be able to run during the extraction phase.
   ENABLE_IN_EXTRACTION = False
 
-  # A flag to indicate that this plugin takes a long time to compile a report.
-  LONG_RUNNING_PLUGIN = False
-
-  def __init__(self, incoming_queue):
-    """Initializes an analysis plugin.
-
-    Args:
-      incoming_queue: A queue that is used to listen to incoming events.
-    """
-    super(AnalysisPlugin, self).__init__(incoming_queue)
+  def __init__(self):
+    """Initializes an analysis plugin."""
+    super(AnalysisPlugin, self).__init__()
     self.plugin_type = definitions.PLUGIN_TYPE_REPORT
 
-  def _ConsumeItem(self, item, analysis_mediator=None, **kwargs):
-    """Consumes an item callback for ConsumeItems.
-
-    Args:
-      item: the item object.
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
-      kwargs: keyword arguments to pass to the _ConsumeItem callback.
-    """
-    # TODO: rename to ExamineItem.
-    self.ExamineEvent(analysis_mediator, item, **kwargs)
-
   @property
   def plugin_name(self):
-    """Return the name of the plugin."""
+    """str: name of the plugin."""
     return self.NAME
 
   @abc.abstractmethod
-  def CompileReport(self, analysis_mediator):
+  def CompileReport(self, mediator):
     """Compiles a report of the analysis.
 
     After the plugin has received every copy of an event to
@@ -86,40 +66,23 @@ class AnalysisPlugin(queue.ItemQueueConsumer):
     can be assembled.
 
     Args:
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
+      mediator (AnalysisMediator): mediates interactions between
+          analysis plugins and other components, such as storage and dfvfs.
 
     Returns:
-      The analysis report (instance of AnalysisReport).
+      AnalysisReport: report.
     """
 
   @abc.abstractmethod
-  def ExamineEvent(self, analysis_mediator, event_object, **kwargs):
+  def ExamineEvent(self, mediator, event):
     """Analyzes an event object.
 
     Args:
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
-      event_object: An event object (instance of EventObject).
+      mediator (AnalysisMediator): mediates interactions between
+          analysis plugins and other components, such as storage and dfvfs.
+      event (EventObject): event.
     """
 
-  def RunPlugin(self, analysis_mediator):
-    """For each item in the queue send the read event to analysis.
-
-    Args:
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
-    """
-    self.ConsumeItems(analysis_mediator=analysis_mediator)
-
-    analysis_report = self.CompileReport(analysis_mediator)
-
-    if analysis_report:
-      analysis_report.time_compiled = timelib.Timestamp.GetNow()
-      analysis_mediator.ProduceAnalysisReport(
-          analysis_report, plugin_name=self.plugin_name)
-    analysis_mediator.ReportingComplete()
-
 
 class HashTaggingAnalysisPlugin(AnalysisPlugin):
   """An interface for plugins that tag events based on the source file hash.
@@ -128,39 +91,31 @@ class HashTaggingAnalysisPlugin(AnalysisPlugin):
   the HashAnalyzer interface.
 
   Attributes:
-    hash_analysis_queue: A queue (instance of Queue.Queue) that contains
-                         the results of analysis of file hashes.
-    hash_queue: A queue (instance of Queue.Queue) that contains file hashes.
+    hash_analysis_queue (Queue.queue): queue that contains the results of
+        analysis of file hashes.
+    hash_queue (Queue.queue): queue that contains file hashes.
   """
   # The event data types the plugin will collect hashes from. Subclasses
   # must override this attribute.
   DATA_TYPES = []
-  # The plugin will select hashes from the event objects from these attributes,
-  # in priority order. More collision-resistant hashing algorithms should be
-  # preferred over less resistant algorithms.
-  REQUIRED_HASH_ATTRIBUTES = frozenset(
-      [u'sha256_hash', u'sha1_hash', u'md5_hash'])
+
   # The default number of seconds for the plugin to wait for analysis results
   # to be added to the hash_analysis_queue by the analyzer thread.
   DEFAULT_QUEUE_TIMEOUT = 4
   SECONDS_BETWEEN_STATUS_LOG_MESSAGES = 30
-  # Hashing analysis plugins can take a long time to run, so set this by
-  # default.
-  LONG_RUNNING_PLUGIN = True
 
-  def __init__(self, incoming_queue, analyzer_class):
+  def __init__(self, analyzer_class):
     """Initializes a hash tagging analysis plugin.
 
     Args:
-      incoming_queue: A queue that is used to listen for incoming events.
-      analyzer_class: A subclass of HashAnalyzer that will be instantiated
-                      by the plugin.
+      analyzer_class (type): A subclass of HashAnalyzer that will be
+          instantiated by the plugin.
     """
-    super(HashTaggingAnalysisPlugin, self).__init__(incoming_queue)
+    super(HashTaggingAnalysisPlugin, self).__init__()
     self._analysis_queue_timeout = self.DEFAULT_QUEUE_TIMEOUT
     self._analyzer_started = False
-    self._event_uuids_by_pathspec = defaultdict(list)
-    self._hash_pathspecs = defaultdict(list)
+    self._event_uuids_by_pathspec = collections.defaultdict(list)
+    self._hash_pathspecs = collections.defaultdict(list)
     self._requester_class = None
     self._time_of_last_status_log = time.time()
     self.hash_analysis_queue = Queue.Queue()
@@ -168,75 +123,50 @@ class HashTaggingAnalysisPlugin(AnalysisPlugin):
 
     self._analyzer = analyzer_class(self.hash_queue, self.hash_analysis_queue)
 
-  def _GenerateTextLine(self, analysis_mediator, pathspec, tag_strings):
-    """Generates a line of text regarding the plugins findings.
-
-    Args:
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
-      pathspec: The pathspec (instance of dfvfs.PathSpec) whose hash was
-                looked up by the plugin.
-      tag_strings: A list of strings describing the plugin's results for a given
-                   pathspec.
-    """
-    display_name = analysis_mediator.GetDisplayName(pathspec)
-    return u'{0:s}: {1:s}'.format(display_name, u', '.join(tag_strings))
-
-  @abc.abstractmethod
-  def GenerateTagStrings(self, hash_information):
-    """Generates a list of strings to tag events with.
-
-    Args:
-      hash_information: An object that encapsulates the result of the
-                        analysis of a hash, as returned by the Analyze() method
-                        of the analyzer class associated with this plugin.
-
-    Returns:
-      A list of string tags to apply to events.
-    """
-
-  def _CreateTag(self, event_uuid, tag_strings):
+  def _CreateTag(self, event_uuid, labels):
     """Creates an event tag.
 
     Args:
-      event_uuid: The UUID of the event that should be tagged.
-      tag_strings: A list of strings that the event should be tagged with.
+      event_uuid (uuid.UUID): identifier of the event that should be tagged.
+      labels (list[str]): labels for the gag.
+
+    Returns:
+      EventTag: event tag.
     """
-    event_tag = event.EventTag()
-    event_tag.event_uuid = event_uuid
-    event_tag.comment = u'Tag applied by {0:s} analysis plugin'.format(
-        self.NAME)
-    event_tag.tags = tag_strings
+    event_tag = events.EventTag(
+        comment=u'Tag applied by {0:s} analysis plugin'.format(self.NAME),
+        event_uuid=event_uuid)
+    event_tag.AddLabels(labels)
     return event_tag
 
   def _HandleHashAnalysis(self, hash_analysis):
-    """Deals with a the results of the analysis of a hash.
+    """Deals with the results of the analysis of a hash.
 
-    This method ensures that tag strings are generated for the hash,
+    This method ensures that labels are generated for the hash,
     then tags all events derived from files with that hash.
 
     Args:
-      hash_analysis: The the hash analysis plugin's results for a given hash
-                     (instance of HashAnalysis).
+      hash_analysis (HashAnalysis): hash analysis plugin's results for a given
+          hash.
 
     Returns:
-      A tuple of:
-        pathspecs: A list of pathspecs that had the hash value looked up.
-        tag_strings: A list of strings that corresponds to the hash value that
-                     was looked up.
-        tags: A list of EventTags for all events that were extracted from the
-              pathspecs.
+      tuple: containing:
+
+        list[dfvfs.PathSpec]: pathspecs that had the hash value looked up.
+        list[str]: labels that corresponds to the hash value that was looked up.
+        list[EventTag]: event tags for all events that were extracted from the
+            path specifications.
     """
     tags = []
-    event_uuids = []
-    tag_strings = self.GenerateTagStrings(hash_analysis.hash_information)
-    pathspecs = self._hash_pathspecs[hash_analysis.subject_hash]
+    labels = self.GenerateLabels(hash_analysis.hash_information)
+    pathspecs = self._hash_pathspecs.pop(hash_analysis.subject_hash)
     for pathspec in pathspecs:
-      event_uuids.extend(self._event_uuids_by_pathspec[pathspec])
-    for event_uuid in event_uuids:
-      tag = self._CreateTag(event_uuid, tag_strings)
-      tags.append(tag)
-    return pathspecs, tag_strings, tags
+      event_uuids = self._event_uuids_by_pathspec.pop(pathspec, [])
+      if labels:
+        for event_uuid in event_uuids:
+          tag = self._CreateTag(event_uuid, labels)
+          tags.append(tag)
+    return pathspecs, labels, tags
 
   def _EnsureRequesterStarted(self):
     """Checks if the analyzer is running and starts it if not."""
@@ -244,64 +174,53 @@ class HashTaggingAnalysisPlugin(AnalysisPlugin):
       self._analyzer.start()
       self._analyzer_started = True
 
-  def ExamineEvent(self, analysis_mediator, event_object, **kwargs):
-    """Evaluates whether an event contains the appropriate data for a hash
-    lookup.
+  def ExamineEvent(self, mediator, event):
+    """Evaluates whether an event contains the right data for a hash lookup.
 
     Args:
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
-      event_object: An event object (instance of EventObject).
+      mediator (AnalysisMediator): mediates interactions between
+          analysis plugins and other components, such as storage and dfvfs.
+      event (EventObject): event.
     """
     self._EnsureRequesterStarted()
-    pathspec = event_object.pathspec
-    event_uuids = self._event_uuids_by_pathspec[pathspec]
-    event_uuids.append(event_object.uuid)
-    if event_object.data_type in self.DATA_TYPES:
-      for attribute in self.REQUIRED_HASH_ATTRIBUTES:
-        hash_for_lookup = getattr(event_object, attribute, None)
-        if not hash_for_lookup:
-          continue
-        pathspecs = self._hash_pathspecs[hash_for_lookup]
-        pathspecs.append(pathspec)
-        # There may be multiple pathspecs that have the same hash. We only
-        # want to look them up once.
-        if len(pathspecs) == 1:
-          self.hash_queue.put(hash_for_lookup)
-        return
-      warning_message = (
-          u'Event with ID {0:s} had none of the required attributes '
-          u'{1:s}.').format(
-              event_object.uuid, self.REQUIRED_HASH_ATTRIBUTES)
-      logging.warning(warning_message)
+
+    path_spec = event.pathspec
+    event_uuids = self._event_uuids_by_pathspec[path_spec]
+    event_uuids.append(event.uuid)
+    if event.data_type not in self.DATA_TYPES:
+      return
+
+    if not self._analyzer.lookup_hash:
+      return
+
+    lookup_hash = u'{0:s}_hash'.format(self._analyzer.lookup_hash)
+    lookup_hash = getattr(event, lookup_hash, None)
+    if not lookup_hash:
+      display_name = mediator.GetDisplayName(path_spec)
+      logging.warning((
+          u'Lookup hash attribute: {0:s}_hash missing from event that '
+          u'originated from: {1:s}.').format(
+              self._analyzer.lookup_hash, display_name))
+      return
+
+    path_specs = self._hash_pathspecs[lookup_hash]
+    path_specs.append(path_spec)
+    # There may be multiple path specification that have the same hash. We only
+    # want to look them up once.
+    if len(path_specs) == 1:
+      self.hash_queue.put(lookup_hash)
 
   def _ContinueReportCompilation(self):
     """Determines if the plugin should continue trying to compile the report.
 
     Returns:
-      True if the plugin should continue, False otherwise.
+      bool: True if the plugin should continue, False otherwise.
     """
     analyzer_alive = self._analyzer.is_alive()
     hash_queue_has_tasks = self.hash_queue.unfinished_tasks > 0
     analysis_queue = not self.hash_analysis_queue.empty()
     return (analyzer_alive and hash_queue_has_tasks) or analysis_queue
 
-  def EstimateTimeRemaining(self):
-    """Estimate how long until all hashes have been analyzed.
-
-    Returns:
-      The estimated number of seconds until all hashes have been analyzed.
-    """
-    number_of_hashes = self.hash_queue.qsize()
-    hashes_per_batch = self._analyzer.hashes_per_batch
-    wait_time_per_batch = self._analyzer.wait_after_analysis
-    average_analysis_time = (
-        self._analyzer.seconds_spent_analyzing /
-        self._analyzer.analyses_performed)
-    batches_remaining = number_of_hashes / hashes_per_batch
-    estimated_seconds_per_batch = average_analysis_time + wait_time_per_batch
-    return batches_remaining * estimated_seconds_per_batch
-
   # TODO: Refactor to do this more elegantly, perhaps via callback.
   def _LogProgressUpdateIfReasonable(self):
     """Prints a progress update if enough time has passed."""
@@ -319,18 +238,20 @@ class HashTaggingAnalysisPlugin(AnalysisPlugin):
     logging.info(log_message)
     self._time_of_last_status_log = current_time
 
-  def CompileReport(self, analysis_mediator):
-    """Compiles a report of the analysis.
+  def CompileReport(self, mediator):
+    """Compiles an analysis report.
 
     Args:
-      analysis_mediator: The analysis mediator object (instance of
-                         AnalysisMediator).
+      mediator (AnalysisMediator): mediates interactions between
+          analysis plugins and other components, such as storage and dfvfs.
 
     Returns:
-      The analysis report (instance of AnalysisReport).
+      AnalysisReport: report.
     """
+    # TODO: refactor to update the counter on demand instead of
+    # during reporting.
+    path_specs_per_labels_counter = collections.Counter()
     tags = []
-    lines_of_text = [u'{0:s} hash tagging Results'.format(self.NAME)]
     while self._ContinueReportCompilation():
       try:
         self._LogProgressUpdateIfReasonable()
@@ -340,19 +261,70 @@ class HashTaggingAnalysisPlugin(AnalysisPlugin):
         # The result queue is empty, but there could still be items that need
         # to be processed by the analyzer.
         continue
-      pathspecs, tag_strings, new_tags = self._HandleHashAnalysis(
+      pathspecs, labels, new_tags = self._HandleHashAnalysis(
           hash_analysis)
+
       tags.extend(new_tags)
-      for pathspec in pathspecs:
-        text_line = self._GenerateTextLine(
-            analysis_mediator, pathspec, tag_strings)
-        lines_of_text.append(text_line)
+      for label in labels:
+        path_specs_per_labels_counter[label] += len(pathspecs)
+
     self._analyzer.SignalAbort()
 
-    report = event.AnalysisReport(self.NAME)
-    report.SetText(lines_of_text)
-    report.SetTags(tags)
-    return report
+    lines_of_text = [u'{0:s} hash tagging results'.format(self.NAME)]
+    for label, count in path_specs_per_labels_counter.items():
+      line_of_text = (
+          u'{0:d} path specifications tagged with label: {1:s}'.format(
+              count, label))
+      lines_of_text.append(line_of_text)
+    lines_of_text.append(u'')
+    report_text = u'\n'.join(lines_of_text)
+
+    analysis_report = reports.AnalysisReport(
+        plugin_name=self.NAME, text=report_text)
+    analysis_report.SetTags(tags)
+    return analysis_report
+
+  def EstimateTimeRemaining(self):
+    """Estimates how long until all hashes have been analyzed.
+
+    Returns:
+      int: estimated number of seconds until all hashes have been analyzed.
+    """
+    number_of_hashes = self.hash_queue.qsize()
+    hashes_per_batch = self._analyzer.hashes_per_batch
+    wait_time_per_batch = self._analyzer.wait_after_analysis
+    analyses_performed = self._analyzer.analyses_performed
+
+    if analyses_performed == 0:
+      average_analysis_time = self._analyzer.seconds_spent_analyzing
+    else:
+      average_analysis_time, _ = divmod(
+          self._analyzer.seconds_spent_analyzing, analyses_performed)
+
+    batches_remaining, _ = divmod(number_of_hashes, hashes_per_batch)
+    estimated_seconds_per_batch = average_analysis_time + wait_time_per_batch
+    return batches_remaining * estimated_seconds_per_batch
+
+  @abc.abstractmethod
+  def GenerateLabels(self, hash_information):
+    """Generates a list of strings to tag events with.
+
+    Args:
+      hash_information (object): object that mediates the result of the
+          analysis of a hash, as returned by the Analyze() method of the
+          analyzer class associated with this plugin.
+
+    Returns:
+      list[str]: list of labels to apply to events.
+    """
+
+  def SetLookupHash(self, lookup_hash):
+    """Sets the hash to query.
+
+    Args:
+      lookup_hash (str): name of the hash attribute to look up.
+    """
+    self._analyzer.SetLookupHash(lookup_hash)
 
 
 class HashAnalyzer(threading.Thread):
@@ -361,32 +333,34 @@ class HashAnalyzer(threading.Thread):
   This interface should be implemented once for each hash analysis plugin.
 
   Attributes:
-    analyses_performed: The number of analysis batches completed by this
-                        analyzer.
-    hashes_per_batch: The maximum number of hashes to analyze at once.
-    seconds_spent_analyzing: The number of seconds this analyzer has spent
-                             performing analysis (as opposed to waiting on
-                             queues, etc.)
-    wait_after_analysis: How long the analyzer will sleep for after analyzing a
-                         batch of hashes.
+    analyses_performed (int): number of analysis batches completed by this
+        analyzer.
+    hashes_per_batch (int): maximum number of hashes to analyze at once.
+    lookup_hash (str): name of the hash attribute to look up.
+    seconds_spent_analyzing (int): number of seconds this analyzer has spent
+        performing analysis (as opposed to waiting on queues, etc.)
+    wait_after_analysis (int): number of seconds the analyzer will sleep for
+        after analyzing a batch of hashes.
   """
   # How long to wait for new items to be added to the the input queue.
   EMPTY_QUEUE_WAIT_TIME = 4
 
+  # List of lookup hashes supported by the analyzer.
+  SUPPORTED_HASHES = []
+
   def __init__(
       self, hash_queue, hash_analysis_queue, hashes_per_batch=1,
-      wait_after_analysis=0):
+      lookup_hash=u'sha256', wait_after_analysis=0):
     """Initializes a hash analyzer.
 
     Args:
-      hash_queue: A queue (instance of Queue.queue) that contains hashes to
-                  be analyzed.
-      hash_analysis_queue: A queue (instance of Queue.queue) that the analyzer
-                           will append HashAnalysis objects to.
-      hashes_per_batch: The number of hashes to analyze at once. The default
-                        is 1.
-      wait_after_analysis: The number of seconds to wait after each batch is
-                           analyzed.
+      hash_queue (Queue.queue): contains hashes to be analyzed.
+      hash_analysis_queue (Queue.queue): queue that the analyzer will append
+          HashAnalysis objects to.
+      hashes_per_batch (Optional[int]): number of hashes to analyze at once.
+      lookup_hash (Optional[str]): name of the hash attribute to look up.
+      wait_after_analysis (Optional[int]: number of seconds to wait after each
+          batch is analyzed.
     """
     super(HashAnalyzer, self).__init__()
     self._abort = False
@@ -394,33 +368,21 @@ class HashAnalyzer(threading.Thread):
     self._hash_analysis_queue = hash_analysis_queue
     self.analyses_performed = 0
     self.hashes_per_batch = hashes_per_batch
+    self.lookup_hash = lookup_hash
     self.seconds_spent_analyzing = 0
     self.wait_after_analysis = wait_after_analysis
-    # Indicate that this is a daemon thread. The program will exit if only
-    # daemon threads are running. This thread should never block program exit.
-    self.daemon = True
-
-  @abc.abstractmethod
-  def Analyze(self, hashes):
-    """Analyzes a list of hashes.
-
-    Args:
-      hashes: A list of hashes (strings) to look up.
-
-    Returns:
-      A list of hash analysis objects (instances of HashAnalysis).
-    """
 
   def _GetHashes(self, target_queue, max_hashes):
     """Retrieves a list of items from a queue.
 
     Args:
-      target_queue: The target_queue to retrieve items from.
-      max_hashes: The maximum number of items to retrieve from the target_queue.
+      target_queue (Queue.queue): queue to retrieve hashes from.
+      max_hashes (int): maximum number of items to retrieve from the
+          target_queue.
 
     Returns:
-      A list of at most max_hashes elements from the target_queue. The list
-      may have no elements if the target_queue is empty.
+      list[object]: list of at most max_hashes elements from the target_queue.
+          The list may have no elements if the target_queue is empty.
     """
     hashes = []
     for _ in range(0, max_hashes):
@@ -431,9 +393,16 @@ class HashAnalyzer(threading.Thread):
       hashes.append(item)
     return hashes
 
-  def SignalAbort(self):
-    """Instructs this analyzer to stop running."""
-    self._abort = True
+  @abc.abstractmethod
+  def Analyze(self, hashes):
+    """Analyzes a list of hashes.
+
+    Args:
+      hashes (list[str]): list of hashes to look up.
+
+    Returns:
+      list[HashAnalysis]: list of results of analyzing the hashes.
+    """
 
   # This method is part of the threading.Thread interface, hence its name does
   # not follow the style guide.
@@ -455,6 +424,24 @@ class HashAnalyzer(threading.Thread):
         # Wait for some more hashes to be added to the queue.
         time.sleep(self.EMPTY_QUEUE_WAIT_TIME)
 
+  def SetLookupHash(self, lookup_hash):
+    """Sets the hash to query.
+
+    Args:
+      lookup_hash (str): name of the hash attribute to look up.
+
+    Raises:
+      ValueError: if the lookup hash is not supported.
+    """
+    if lookup_hash not in self.SUPPORTED_HASHES:
+      raise ValueError(u'Unsupported lookup hash: {0!s}'.format(lookup_hash))
+
+    self.lookup_hash = lookup_hash
+
+  def SignalAbort(self):
+    """Instructs this analyzer to stop running."""
+    self._abort = True
+
 
 class HTTPHashAnalyzer(HashAnalyzer):
   """A class that provides a useful interface for hash plugins using HTTP(S)"""
@@ -463,10 +450,9 @@ class HTTPHashAnalyzer(HashAnalyzer):
     """Initializes a HTTP hash analyzer.
 
     Args:
-      hash_queue: A queue (instance of Queue.queue) that contains hashes to
-                  be analyzed.
-      hash_analysis_queue: A queue (instance of Queue.queue) that the analyzer
-                           will append HashAnalysis objects to.
+      hash_queue (Queue.queue): A queue that contains hashes to be analyzed.
+      hash_analysis_queue (Queue.queue): queue that the analyzer will append
+          HashAnalysis objects to.
     """
     super(HTTPHashAnalyzer, self).__init__(
         hash_queue, hash_analysis_queue, **kwargs)
@@ -505,28 +491,28 @@ class HTTPHashAnalyzer(HashAnalyzer):
     """Analyzes a list of hashes.
 
     Args:
-      hashes: A list of hashes (strings) to look up.
+      hashes (list[str]): hashes to look up.
 
     Returns:
-      A list of hash analysis objects (instances of HashAnalysis).
+      list[HashAnalysis]: analysis results.
     """
 
   def MakeRequestAndDecodeJSON(self, url, method, **kwargs):
     """Make a HTTP request and decode the results as JSON.
 
     Args:
-      url: The URL to make a request to.
-      method: The HTTP method to use to make the request, as a string. GET and
-              POST are supported.
-      kwargs: Parameters to the requests .get() or post() methods, depending
-              on the value of the method parameter.
+      url (str): URL to make a request to.
+      method (str): HTTP method to used to make the request. GET and POST are
+          supported.
+      kwargs: parameters to the requests .get() or post() methods, depending
+          on the value of the method parameter.
 
     Returns:
-      The body of the HTTP response, decoded from JSON.
+      dict[str, object]: body of the HTTP response, decoded from JSON.
 
     Raises:
       ConnectionError: If it is not possible to connect to the given URL, or it
-                       the request returns a HTTP error.
+          the request returns a HTTP error.
       ValueError: If an invalid HTTP method is specified.
     """
     method = method.lower()
@@ -558,19 +544,18 @@ class HashAnalysis(object):
   """A class that holds information about a hash.
 
   Attributes:
-    hash_information: An object containing information about the hash.
-    subject_hash: The hash that was analyzed.
+    hash_information (object): object containing information about the hash.
+    subject_hash (str):  hash that was analyzed.
   """
 
   def __init__(self, subject_hash, hash_information):
     """Initializes a HashAnalysis object.
 
     Args:
-      subject_hash: The hash that the hash_information relates to.
-      hash_information: An object containing information about the hash.
-                        This object will be used by the _GenerateTagString
-                        method in the HashTaggingAnalysisPlugin to tag events
-                        that relate to the hash.
+      subject_hash (str): hash that the hash_information relates to.
+      hash_information (object): information about the hash. This object will be
+          used by the GenerateLabels method in the HashTaggingAnalysisPlugin
+          to tag events that relate to the hash.
     """
     self.hash_information = hash_information
     self.subject_hash = subject_hash
