@@ -10,17 +10,19 @@ from plaso.lib import errors
 
 class VirusTotalAnalyzer(interface.HTTPHashAnalyzer):
   """Class that analyzes file hashes by consulting VirusTotal."""
+
   _VIRUSTOTAL_API_REPORT_URL = (
       u'https://www.virustotal.com/vtapi/v2/file/report')
 
+  SUPPORTED_HASHES = [u'md5', u'sha1', u'sha256']
+
   def __init__(self, hash_queue, hash_analysis_queue, **kwargs):
     """Initializes a VirusTotal Analyzer thread.
 
     Args:
-      hash_queue: A queue (instance of Queue.queue) that contains hashes to
-                  be analyzed.
-      hash_analysis_queue: A queue (instance of Queue.queue) that the analyzer
-                           will append HashAnalysis objects to.
+      hash_queue (Queue.queue): queue that contains hashes to be analyzed.
+      hash_analysis_queue (Queue.queue): queue the analyzer will append
+          HashAnalysis objects to.
     """
     super(VirusTotalAnalyzer, self).__init__(
         hash_queue, hash_analysis_queue, **kwargs)
@@ -31,7 +33,7 @@ class VirusTotalAnalyzer(interface.HTTPHashAnalyzer):
     """Sets the VirusTotal API key to use in queries.
 
     Args:
-      _api_key: The VirusTotal API key
+      api_key (str): VirusTotal API key
     """
     self._api_key = api_key
 
@@ -42,10 +44,10 @@ class VirusTotalAnalyzer(interface.HTTPHashAnalyzer):
       https://www.virustotal.com/en/documentation/public-api/
 
     Args:
-      hashes: A list of hashes (strings) to look up.
+      hashes (list[str]): hashes to look up.
 
     Returns:
-      A list of HashAnalysis objects.
+      list[HashAnalysis]: analysis results.
 
     Raises:
       RuntimeError: If the VirusTotal API key has not been set.
@@ -83,8 +85,6 @@ class VirusTotalAnalyzer(interface.HTTPHashAnalyzer):
 
 class VirusTotalAnalysisPlugin(interface.HashTaggingAnalysisPlugin):
   """An analysis plugin for looking up hashes in VirusTotal."""
-  # VirusTotal allows lookups using any of these hash algorithms.
-  REQUIRED_HASH_ATTRIBUTES = [u'sha256_hash', u'sha1_hash', u'md5_hash']
 
   # TODO: Check if there are other file types worth checking VirusTotal for.
   DATA_TYPES = [u'pe:compilation:compilation_time']
@@ -97,48 +97,30 @@ class VirusTotalAnalysisPlugin(interface.HashTaggingAnalysisPlugin):
   _VIRUSTOTAL_PRESENT_RESPONSE_CODE = 1
   _VIRUSTOTAL_ANALYSIS_PENDING_RESPONSE_CODE = -2
 
-  def __init__(self, event_queue):
-    """Initializes a VirusTotal analysis plugin.
-
-    Args:
-      event_queue: A queue that is used to listen for incoming events.
-    """
-    super(VirusTotalAnalysisPlugin, self).__init__(
-        event_queue, VirusTotalAnalyzer)
+  def __init__(self):
+    """Initializes a VirusTotal analysis plugin."""
+    super(VirusTotalAnalysisPlugin, self).__init__(VirusTotalAnalyzer)
     self._api_key = None
 
-  def SetAPIKey(self, api_key):
-    """Sets the VirusTotal API key to use in queries.
-
-    Args:
-      _api_key: The VirusTotal API key
-    """
-    self._analyzer.SetAPIKey(api_key)
-
-  def EnableFreeAPIKeyRateLimit(self, rate_limit):
+  def EnableFreeAPIKeyRateLimit(self):
     """Configures Rate limiting for queries to VirusTotal.
 
     The default rate limit for free VirusTotal API keys is 4 requests per
     minute.
-
-    Args:
-      rate_limit: Whether not to apply the free API key rate limit.
     """
-    if rate_limit:
-      self._analyzer.hashes_per_batch = 4
-      self._analyzer.wait_after_analysis = 60
-      self._analysis_queue_timeout = self._analyzer.wait_after_analysis + 1
+    self._analyzer.hashes_per_batch = 4
+    self._analyzer.wait_after_analysis = 60
+    self._analysis_queue_timeout = self._analyzer.wait_after_analysis + 1
 
-  def GenerateTagStrings(self, hash_information):
+  def GenerateLabels(self, hash_information):
     """Generates a list of strings that will be used in the event tag.
 
     Args:
-      hash_information: A dictionary containing the JSON decoded contents of the
-                        result of a VirusTotal lookup, as produced by the
-                        VirusTotalAnalyzer.
+      hash_information (dict[str, object]): the JSON decoded contents of the
+          result of a VirusTotal lookup, as produced by the VirusTotalAnalyzer.
 
     Returns:
-      A list of strings describing the results from VirusTotal.
+      list[str]: strings describing the results from VirusTotal.
     """
     response_code = hash_information[u'response_code']
     if response_code == self._VIRUSTOTAL_NOT_PRESENT_RESPONSE_CODE:
@@ -156,5 +138,13 @@ class VirusTotalAnalysisPlugin(interface.HashTaggingAnalysisPlugin):
               response_code))
       return [u'virustotal_unknown_response_code_{0:d}'.format(response_code)]
 
+  def SetAPIKey(self, api_key):
+    """Sets the VirusTotal API key to use in queries.
+
+    Args:
+      api_key (str): VirusTotal API key
+    """
+    self._analyzer.SetAPIKey(api_key)
+
 
 manager.AnalysisPluginManager.RegisterPlugin(VirusTotalAnalysisPlugin)
