@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""The arguments helper for the 4n6time MySQL database output module."""
+"""The 4n6time MySQL database output module CLI arguments helper."""
 
 from plaso.lib import errors
 from plaso.cli.helpers import interface
@@ -9,15 +9,16 @@ from plaso.cli.helpers import manager
 from plaso.output import mysql_4n6time
 
 
-class MySQL4n6TimeHelper(database_config.DatabaseConfigHelper):
-  """CLI argument helper for a 4n6Time MySQL database server."""
+class MySQL4n6TimeDatabaseArgumentsHelper(
+    database_config.DatabaseArgumentsHelper):
+  """4n6time MySQL database server CLI arguments helper."""
 
   _DEFAULT_USERNAME = u'root'
   _DEFAULT_PASSWORD = u'forensic'
 
 
-class MySQL4n6TimeOutputHelper(interface.ArgumentsHelper):
-  """CLI arguments helper class for a MySQL 4n6time output module."""
+class MySQL4n6TimeOutputArgumentsHelper(interface.ArgumentsHelper):
+  """4n6time MySQL database output module CLI arguments helper."""
 
   NAME = u'4n6time_mysql'
   CATEGORY = u'output'
@@ -25,25 +26,26 @@ class MySQL4n6TimeOutputHelper(interface.ArgumentsHelper):
 
   @classmethod
   def AddArguments(cls, argument_group):
-    """Add command line arguments the helper supports to an argument group.
+    """Adds command line arguments the helper supports to an argument group.
 
     This function takes an argument parser or an argument group object and adds
     to it all the command line arguments this helper supports.
 
     Args:
-      argument_group: the argparse group (instance of argparse._ArgumentGroup or
-                      or argparse.ArgumentParser).
+      argument_group (argparse._ArgumentGroup|argparse.ArgumentParser):
+          argparse group.
     """
-    shared_4n6time_output.Shared4n6TimeOutputHelper.AddArguments(argument_group)
-    MySQL4n6TimeHelper.AddArguments(argument_group)
+    shared_4n6time_output.Shared4n6TimeOutputArgumentsHelper.AddArguments(
+        argument_group)
+    MySQL4n6TimeDatabaseArgumentsHelper.AddArguments(argument_group)
 
   @classmethod
   def ParseOptions(cls, options, output_module):
     """Parses and validates options.
 
     Args:
-      options: the parser option object (instance of argparse.Namespace).
-      output_module: an output module (instance of OutputModule).
+      options (argparse.Namespace): parser options.
+      output_module (OutputModule): output module to configure.
 
     Raises:
       BadConfigObject: when the output module object is of the wrong type.
@@ -52,9 +54,9 @@ class MySQL4n6TimeOutputHelper(interface.ArgumentsHelper):
       raise errors.BadConfigObject(
           u'Output module is not an instance of MySQL4n6TimeOutputModule')
 
-    MySQL4n6TimeHelper.ParseOptions(options, output_module)
-    shared_4n6time_output.Shared4n6TimeOutputHelper.ParseOptions(
+    MySQL4n6TimeDatabaseArgumentsHelper.ParseOptions(options, output_module)
+    shared_4n6time_output.Shared4n6TimeOutputArgumentsHelper.ParseOptions(
         options, output_module)
 
 
-manager.ArgumentHelperManager.RegisterHelper(MySQL4n6TimeOutputHelper)
+manager.ArgumentHelperManager.RegisterHelper(MySQL4n6TimeOutputArgumentsHelper)
