@@ -15,7 +15,10 @@ from plaso.formatters import chrome_cache
 from plaso.formatters import chrome_cookies
 from plaso.formatters import chrome_extension_activity
 from plaso.formatters import chrome_preferences
+from plaso.formatters import cron
 from plaso.formatters import cups_ipp
+from plaso.formatters import docker
+from plaso.formatters import dpkg
 from plaso.formatters import file_history
 from plaso.formatters import file_system
 from plaso.formatters import firefox
@@ -25,8 +28,10 @@ from plaso.formatters import ganalytics
 from plaso.formatters import gdrive
 from plaso.formatters import hachoir
 from plaso.formatters import iis
+from plaso.formatters import imessage
 from plaso.formatters import ipod
 from plaso.formatters import java_idx
+from plaso.formatters import kik_ios
 from plaso.formatters import ls_quarantine
 from plaso.formatters import mac_appfirewall
 from plaso.formatters import mac_document_versions
@@ -38,6 +43,7 @@ from plaso.formatters import mactime
 from plaso.formatters import mcafeeav
 from plaso.formatters import msie_webcache
 from plaso.formatters import msiecf
+from plaso.formatters import officemru
 from plaso.formatters import olecf
 from plaso.formatters import opera
 from plaso.formatters import oxml
@@ -49,15 +55,20 @@ from plaso.formatters import pls_recall
 from plaso.formatters import recycler
 from plaso.formatters import safari
 from plaso.formatters import safari_cookies
+from plaso.formatters import sam_users
 from plaso.formatters import sccm
 from plaso.formatters import selinux
 from plaso.formatters import shell_items
+from plaso.formatters import shutdown
 from plaso.formatters import skydrivelog
 from plaso.formatters import skype
 from plaso.formatters import symantec
 from plaso.formatters import syslog
+from plaso.formatters import ssh
 from plaso.formatters import task_scheduler
 from plaso.formatters import text
+from plaso.formatters import twitter_ios
+from plaso.formatters import userassist
 from plaso.formatters import utmp
 from plaso.formatters import utmpx
 from plaso.formatters import windows
@@ -73,3 +84,4 @@ from plaso.formatters import winrestore
 from plaso.formatters import xchatlog
 from plaso.formatters import xchatscrollback
 from plaso.formatters import zeitgeist
+from plaso.formatters import zsh_extended_history
