@@ -8,16 +8,18 @@ from dfvfs.helpers import windows_path_resolver
 from dfvfs.lib import definitions as dfvfs_definitions
 from dfvfs.path import factory as path_spec_factory
 from dfvfs.resolver import resolver as path_spec_resolver
+from dfwinreg import registry as dfwinreg_registry
 
-from plaso.dfwinreg import registry as dfwinreg_registry
-from plaso.engine import queue
-from plaso.engine import single_process
+from plaso.containers import sessions
 from plaso.frontend import extraction_frontend
+from plaso.lib import py2to3
 from plaso.parsers import mediator as parsers_mediator
 from plaso.parsers import manager as parsers_manager
 from plaso.parsers import winreg
 from plaso.parsers import winreg_plugins  # pylint: disable=unused-import
 from plaso.preprocessors import manager as preprocess_manager
+# TODO: refactor usage of fake storage.
+from plaso.storage import fake_storage
 
 
 # The Registry (file) types.
@@ -267,43 +269,6 @@ class PluginList(object):
     return plugins_to_run
 
 
-class PregItemQueueConsumer(queue.ItemQueueConsumer):
-  """Class that implements a list event object queue consumer."""
-
-  def __init__(self, event_queue):
-    """Initializes the list event object queue consumer.
-
-    Args:
-      event_queue: the event object queue (instance of Queue).
-    """
-    super(PregItemQueueConsumer, self).__init__(event_queue)
-    self._event_objects = []
-
-  def _ConsumeItem(self, event_object, **unused_kwargs):
-    """Consumes an item callback for ConsumeItems.
-
-    Args:
-      event_object: the event object (instance of EventObject).
-    """
-    self._event_objects.append(event_object)
-
-  def GetItems(self):
-    """Retrieves the consumed event objects.
-
-    Yields:
-      Event objects (instance of EventObject)
-    """
-    if not self._event_objects:
-      raise StopIteration
-
-    event_object = self._event_objects.pop(0)
-    while event_object:
-      yield event_object
-      if not self._event_objects:
-        break
-      event_object = self._event_objects.pop(0)
-
-
 class PregFrontend(extraction_frontend.ExtractionFrontend):
   """Class that implements the preg front-end.
 
@@ -346,8 +311,7 @@ class PregFrontend(extraction_frontend.ExtractionFrontend):
     Yields:
       A Registry helper object (instance of PregRegistryHelper).
     """
-    # TODO: deprecate usage of pre_obj.
-    path_attributes = self.knowledge_base_object.pre_obj.__dict__
+    path_attributes = self.knowledge_base_object.GetPathAttributes()
 
     for source_path_spec in self._source_path_specs:
       if source_path_spec.type_indicator == dfvfs_definitions.TYPE_INDICATOR_OS:
@@ -463,26 +427,6 @@ class PregFrontend(extraction_frontend.ExtractionFrontend):
 
     return file_system, mount_point
 
-  def CreateParserMediator(self, event_queue=None):
-    """Create a parser mediator object.
-
-    Args:
-      event_queue: an optional event queue object (instance of Queue).
-
-    Returns:
-      A parser mediator object (instance of parsers_mediator.ParserMediator).
-    """
-    if event_queue is None:
-      event_queue = single_process.SingleProcessQueue()
-    event_queue_producer = queue.ItemQueueProducer(event_queue)
-
-    parse_error_queue = single_process.SingleProcessQueue()
-    parse_error_queue_producer = queue.ItemQueueProducer(parse_error_queue)
-
-    return parsers_mediator.ParserMediator(
-        event_queue_producer, parse_error_queue_producer,
-        self.knowledge_base_object)
-
   def ExpandKeysRedirect(self, keys):
     """Expands a list of Registry key paths with their redirect equivalents.
 
@@ -606,7 +550,7 @@ class PregFrontend(extraction_frontend.ExtractionFrontend):
           types.add(registry_file_type.upper())
       else:
         for plugin_name in plugin_names:
-          types.extend(self._registry_plugin_list.GetRegistryTypes(plugin_name))
+          types.update(self._registry_plugin_list.GetRegistryTypes(plugin_name))
 
       paths = self.GetRegistryFilePaths(types)
 
@@ -752,16 +696,20 @@ class PregFrontend(extraction_frontend.ExtractionFrontend):
     if not registry_helper:
       return {}
 
-    if isinstance(registry_key, basestring):
+    if isinstance(registry_key, py2to3.STRING_TYPES):
       registry_key = registry_helper.GetKeyByPath(registry_key)
 
     if not registry_key:
       return {}
 
-    event_queue = single_process.SingleProcessQueue()
-    event_queue_consumer = PregItemQueueConsumer(event_queue)
+    # TODO: refactor usage of fake storage.
+    session = sessions.Session()
+    storage_writer = fake_storage.FakeStorageWriter(session)
+    storage_writer.Open()
+
+    parser_mediator = parsers_mediator.ParserMediator(
+        storage_writer, self.knowledge_base_object)
 
-    parser_mediator = self.CreateParserMediator(event_queue)
     parser_mediator.SetFileEntry(registry_helper.file_entry)
 
     return_dict = {}
@@ -783,11 +731,8 @@ class PregFrontend(extraction_frontend.ExtractionFrontend):
 
       found_matching_plugin = True
       plugin_object.Process(parser_mediator, registry_key)
-      event_queue_consumer.ConsumeItems()
-      event_objects = [
-          event_object for event_object in event_queue_consumer.GetItems()]
-      if event_objects:
-        return_dict[plugin_object] = event_objects
+      if storage_writer.events:
+        return_dict[plugin_object] = storage_writer.events
 
     if not found_matching_plugin:
       winreg_parser = parsers_manager.ParsersManager.GetParserObjectByName(
@@ -798,11 +743,8 @@ class PregFrontend(extraction_frontend.ExtractionFrontend):
           u'winreg_default')
 
       default_plugin_object.Process(parser_mediator, registry_key)
-      event_queue_consumer.ConsumeItems()
-      event_objects = [
-          event_object for event_object in event_queue_consumer.GetItems()]
-      if event_objects:
-        return_dict[default_plugin_object] = event_objects
+      if storage_writer.events:
+        return_dict[default_plugin_object] = storage_writer.events
 
     return return_dict
 
