@@ -102,7 +102,17 @@ import re
 
 from plaso.lib import errors
 from plaso.lib import lexer
-from plaso.lib import utils
+from plaso.lib import py2to3
+
+
+# pylint: disable=attribute-defined-outside-init
+# pylint: disable=missing-docstring
+
+def GetUnicodeString(string):
+  """Converts the string to Unicode if necessary."""
+  if not isinstance(string, py2to3.UNICODE_TYPE):
+    return str(string).decode(u'utf8', errors=u'ignore')
+  return string
 
 
 class InvalidNumberOfOperands(errors.Error):
@@ -295,7 +305,7 @@ class Contains(GenericBinaryOperator):
   """Whether the right operand is contained in the value."""
 
   def Operation(self, x, y):
-    if isinstance(x, str) or isinstance(x, unicode):
+    if isinstance(x, py2to3.STRING_TYPES):
       return y.lower() in x.lower()
 
     return y in x
@@ -312,7 +322,7 @@ class InSet(GenericBinaryOperator):
 
     # x might be an iterable
     # first we need to skip strings or we'll do silly things
-    if (isinstance(x, basestring)
+    if (isinstance(x, py2to3.STRING_TYPES)
         or isinstance(x, bytes)):
       return False
 
@@ -334,14 +344,14 @@ class Regexp(GenericBinaryOperator):
     logging.debug(u'Compiled: {0!s}'.format(self.right_operand))
     try:
       self.compiled_re = re.compile(
-          utils.GetUnicodeString(self.right_operand), re.DOTALL)
+          GetUnicodeString(self.right_operand), re.DOTALL)
     except re.error:
       raise ValueError(u'Regular expression "{0!s}" is malformed.'.format(
           self.right_operand))
 
   def Operation(self, x, unused_y):
     try:
-      if self.compiled_re.search(utils.GetUnicodeString(x)):
+      if self.compiled_re.search(GetUnicodeString(x)):
         return True
     except TypeError:
       pass
@@ -357,7 +367,7 @@ class RegexpInsensitive(Regexp):
     # Note that right_operand is not necessarily a string.
     logging.debug(u'Compiled: {0!s}'.format(self.right_operand))
     try:
-      self.compiled_re = re.compile(utils.GetUnicodeString(self.right_operand),
+      self.compiled_re = re.compile(GetUnicodeString(self.right_operand),
                                     re.I | re.DOTALL)
     except re.error:
       raise ValueError(u'Regular expression "{0!s}" is malformed.'.format(
@@ -520,7 +530,7 @@ class ValueExpander(object):
     Yields:
       The values once the object is traversed.
     """
-    if isinstance(path, basestring):
+    if isinstance(path, py2to3.STRING_TYPES):
       path = path.split(self.FIELD_SEPARATOR)
 
     attr_name = self._GetAttributeName(path)
