@@ -9,12 +9,11 @@ from plaso.formatters import mediator as formatters_mediator
 
 # TODO: Changes this so it becomes an attribute instead of having backend
 # load a front-end library.
-from plaso.frontend import presets
 from plaso.lib import errors
-from plaso.lib import limit
 from plaso.lib import objectfilter
+from plaso.lib import py2to3
 from plaso.lib import timelib
-from plaso.lib import utils
+from plaso.parsers import presets
 
 
 class DictObject(object):
@@ -123,7 +122,7 @@ class PlasoValueExpander(objectfilter.AttributeValueExpander):
         ret = DictObject(ret)
 
       if attr_name == 'tag':
-        return ret.tags
+        return ret.labels
 
       return ret
 
@@ -210,7 +209,7 @@ class ParserList(objectfilter.GenericBinaryOperator):
   def __init__(self, *children, **kwargs):
     """Construct the parser list and retrieve a list of available parsers."""
     super(ParserList, self).__init__(*children, **kwargs)
-    self.compiled_list = presets.categories.get(
+    self.compiled_list = presets.CATEGORIES.get(
         self.right_operand.lower(), [])
 
   def Operation(self, x, unused_y):
@@ -263,21 +262,34 @@ class DateCompareObject(object):
     Raises:
       ValueError: if the date string is invalid.
     """
-    self.text = utils.GetUnicodeString(data)
-    if isinstance(data, int) or isinstance(data, long):
+    if isinstance(data, py2to3.INTEGER_TYPES):
       self.data = data
+      self.text = u'{0:d}'.format(data)
+
     elif isinstance(data, float):
-      self.data = long(data)
-    elif isinstance(data, str) or isinstance(data, unicode):
+      self.data = py2to3.LONG_TYPE(data)
+      self.text = u'{0:f}'.format(data)
+
+    elif isinstance(data, py2to3.STRING_TYPES):
+      if isinstance(data, py2to3.BYTES_TYPE):
+        self.text = data.decode(u'utf-8', errors=u'ignore')
+      else:
+        self.text = data
+
       try:
-        self.data = timelib.Timestamp.FromTimeString(
-            utils.GetUnicodeString(data))
+        self.data = timelib.Timestamp.FromTimeString(self.text)
       except (ValueError, errors.TimestampError):
-        raise ValueError(u'Wrongly formatted date string: {0:s}'.format(data))
+        raise ValueError(u'Wrongly formatted date string: {0:s}'.format(
+            self.text))
+
     elif isinstance(data, datetime.datetime):
       self.data = timelib.Timestamp.FromPythonDatetime(data)
-    elif isinstance(DateCompareObject, data):
+      self.text = u'{0!s}'.format(data)
+
+    elif isinstance(data, DateCompareObject):
       self.data = data.data
+      self.text = u'{0!s}'.format(data)
+
     else:
       raise ValueError(u'Unsupported type: {0:s}.'.format(type(data)))
 
@@ -316,102 +328,11 @@ class BaseParser(objectfilter.Parser):
   expression_cls = PlasoExpression
 
 
-class TrueObject(object):
-  """A simple object that always returns true for all comparison.
-
-  This object is used for testing certain conditions inside filter queries.
-  By returning true for all comparisons this object can be used to evaluate
-  specific portions of a filter query.
-  """
-
-  def __init__(self, txt=''):
-    """Save the text object so it can be used when comparing text."""
-    self.txt = txt
-
-  def __getattr__(self, unused_attr):
-    """Return a TrueObject for every attribute request."""
-    return self
-
-  def __eq__(self, unused_x):
-    """Return true for tests of equality."""
-    return True
-
-  def __gt__(self, unused_x):
-    """Return true for checks for greater."""
-    return True
-
-  def __ge__(self, unused_x):
-    """Return true for checks for greater or equal."""
-    return True
-
-  def __lt__(self, unused_x):
-    """Return true for checks of less."""
-    return True
-
-  def __le__(self, unused_x):
-    """Return true for checks of less or equal."""
-    return True
-
-  def __ne__(self, unused_x):
-    """Return true for all not equal comparisons."""
-    return True
-
-  def __iter__(self):
-    """Return a generator so a test for the in keyword can be used."""
-    yield self
-
-  def __str__(self):
-    """Return a string to make regular expression searches possible.
-
-    Returns:
-      A string that contains the original query with some of the matches
-      expanded, perhaps several times.
-    """
-    # Regular expressions in pfilter may include the following escapes:
-    #     "\\'\"rnbt\.ws":
-    txt = self.txt
-    if r'\.' in self.txt:
-      txt += self.txt.replace(r'\.', ' _ text _ ')
-
-    if r'\b' in self.txt:
-      txt += self.txt.replace(r'\b', ' ')
-
-    if r'\s' in self.txt:
-      txt += self.txt.replace(r'\s', ' ')
-
-    return txt
-
-
-class MockTestFilter(object):
-  """A mock test filter object used to test certain portion of test queries.
-
-  The logic behind this object is that a single attribute can be isolated
-  for comparison. That is to say all calls to attributes will lead to a TRUE
-  response, except those attributes that are specifically stated in the
-  constructor. This way it is simple to test for instance whether or not
-  to include a parser at all, before actually running the tool. The same applies
-  to filtering out certain filenames, etc.
-  """
-
-  def __init__(self, query, **kwargs):
-    """Constructor, only valid attribute is the parser one."""
-    self.attributes = kwargs
-    self.txt = query
-
-  def __getattr__(self, attr):
-    """Return TrueObject for all requests except for stored attributes."""
-    if attr in self.attributes:
-      return self.attributes.get(attr, None)
-
-    # TODO: Either delete this entire object (MockTestFilter) or implement
-    # a false object and return the correct one depending on whether we
-    # are looking for a true or negative response (eg "not" keyword included).
-    return TrueObject(self.txt)
-
-
 class TimeRangeCache(object):
   """A class that stores timeranges from filters."""
 
+  MAX_INT64 = 2**64-1
+
   @classmethod
   def SetLowerTimestamp(cls, timestamp):
     """Sets the lower bound timestamp."""
@@ -436,7 +357,7 @@ class TimeRangeCache(object):
   def GetTimeRange(cls):
     """Return the first and last timestamp of filter range."""
     first = getattr(cls, '_lower', 0)
-    last = getattr(cls, '_upper', limit.MAX_INT64)
+    last = getattr(cls, '_upper', cls.MAX_INT64)
 
     if first < last:
       return first, last
