@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
+"""Imports for the output (module) manager."""
+
 from plaso.output import dynamic
-# TODO: renable after refactor as indicated in:
-# https://github.com/log2timeline/plaso/issues/197
-# from plaso.output import elastic
+from plaso.output import elastic
 from plaso.output import json_line
 from plaso.output import json_out
+from plaso.output import kml
 from plaso.output import l2t_csv
 from plaso.output import mysql_4n6time
 from plaso.output import null
-from plaso.output import pstorage
 from plaso.output import rawpy
 from plaso.output import sqlite_4n6time
 from plaso.output import timesketch_out
