@@ -7,6 +7,7 @@ http://forensicswiki.org/wiki/L2T_CSV
 
 from plaso.lib import definitions
 from plaso.lib import errors
+from plaso.lib import py2to3
 from plaso.lib import timelib
 from plaso.output import interface
 from plaso.output import manager
@@ -27,106 +28,108 @@ class L2TCSVOutputModule(interface.LinearOutputModule):
     """Formats a field.
 
     Args:
-      field: the string that makes up the field.
+      field (str): field value.
 
      Returns:
-       A string containing the value for the field.
+       str: formatted field value.
     """
-    if self._FIELD_DELIMITER:
+    if self._FIELD_DELIMITER and isinstance(field, py2to3.STRING_TYPES):
       return field.replace(self._FIELD_DELIMITER, u' ')
     return field
 
-  def _FormatHostname(self, event_object):
+  def _FormatHostname(self, event):
     """Formats the hostname.
 
     Args:
-      event_object: the event object (instance of EventObject).
+      event (EventObject): event.
 
      Returns:
-       A string containing the value for the hostname field.
+       str: formatted hostname field.
     """
-    hostname = self._output_mediator.GetHostname(event_object)
+    hostname = self._output_mediator.GetHostname(event)
     return self._FormatField(hostname)
 
-  def _FormatUsername(self, event_object):
+  def _FormatUsername(self, event):
     """Formats the username.
 
     Args:
-      event_object: the event object (instance of EventObject).
+      event (EventObject): event.
 
      Returns:
-       A string containing the value for the username field.
+       str: formatted username field.
     """
-    username = self._output_mediator.GetUsername(event_object)
+    username = self._output_mediator.GetUsername(event)
     return self._FormatField(username)
 
-  def WriteEventBody(self, event_object):
+  def WriteEventBody(self, event):
     """Writes the body of an event object to the output.
 
     Args:
-      event_object: the event object (instance of EventObject).
+      event (EventObject): event.
 
     Raises:
       NoFormatterFound: If no event formatter can be found to match the data
                         type in the event object.
     """
-    if not hasattr(event_object, u'timestamp'):
+    if not hasattr(event, u'timestamp'):
       return
 
-    message, message_short = self._output_mediator.GetFormattedMessages(
-        event_object)
+    message, message_short = self._output_mediator.GetFormattedMessages(event)
     if message is None or message_short is None:
       raise errors.NoFormatterFound(
           u'Unable to find event formatter for: {0:s}.'.format(
-              getattr(event_object, u'data_type', u'UNKNOWN')))
+              getattr(event, u'data_type', u'UNKNOWN')))
 
-    source_short, source = self._output_mediator.GetFormattedSources(
-        event_object)
+    source_short, source = self._output_mediator.GetFormattedSources(event)
     if source is None or source_short is None:
       raise errors.NoFormatterFound(
           u'Unable to find event formatter for: {0:s}.'.format(
-              getattr(event_object, u'data_type', u'UNKNOWN')))
+              getattr(event, u'data_type', u'UNKNOWN')))
 
     date_use = timelib.Timestamp.CopyToDatetime(
-        event_object.timestamp, self._output_mediator.timezone)
+        event.timestamp, self._output_mediator.timezone)
 
     format_variables = self._output_mediator.GetFormatStringAttributeNames(
-        event_object)
+        event)
     if format_variables is None:
+      data_type = getattr(event, u'data_type', u'UNKNOWN')
       raise errors.NoFormatterFound(
-          u'Unable to find event formatter for: {0:s}.'.format(
-              getattr(event_object, u'data_type', u'UNKNOWN')))
+          u'Unable to find event formatter for: {0:s}.'.format(data_type))
 
-    extras = []
-    for key in event_object.GetAttributes():
-      if (key in definitions.RESERVED_VARIABLE_NAMES or
-          key in format_variables):
+    extra_attributes = []
+    for attribute_name, attribute_value in sorted(event.GetAttributes()):
+      if (attribute_name in definitions.RESERVED_VARIABLE_NAMES or
+          attribute_name in format_variables):
         continue
-      value = getattr(event_object, key)
 
       # With ! in {1!s} we force a string conversion since some of
       # the extra attributes values can be integer, float point or
       # boolean values.
-      extras.append(u'{0:s}: {1!s} '.format(key, value))
-    extra = u' '.join(extras)
+      extra_attributes.append(
+          u'{0:s}: {1!s} '.format(attribute_name, attribute_value))
 
-    inode = getattr(event_object, u'inode', u'-')
-    if inode == u'-':
-      if hasattr(event_object, u'pathspec') and hasattr(
-          event_object.pathspec, u'image_inode'):
-        inode = event_object.pathspec.image_inode
+    extra_attributes = u' '.join(extra_attributes)
+    extra_attributes = extra_attributes.replace(u'\n', u'-').replace(u'\r', u'')
 
-    hostname = self._FormatHostname(event_object)
-    username = self._FormatUsername(event_object)
+    inode = getattr(event, u'inode', None)
+    if inode is None:
+      if hasattr(event, u'pathspec') and hasattr(
+          event.pathspec, u'image_inode'):
+        inode = event.pathspec.image_inode
+    if inode is None:
+      inode = u'-'
+
+    hostname = self._FormatHostname(event)
+    username = self._FormatUsername(event)
 
     notes = []
-    note_string = getattr(event_object, u'notes', None)
+    note_string = getattr(event, u'notes', None)
     if note_string:
       notes.append(note_string)
 
-    tag = getattr(event_object, u'tag', None)
+    tag = getattr(event, u'tag', None)
     if tag:
-      notes.extend(tag.tags)
+      notes.extend(tag.labels)
 
     if not notes:
       notes.append(u'-')
@@ -136,27 +139,32 @@ class L2TCSVOutputModule(interface.LinearOutputModule):
     time_string = u'{0:02d}:{1:02d}:{2:02d}'.format(
         date_use.hour, date_use.minute, date_use.second)
 
-    output_values = (
+    output_values = [
         date_string,
         time_string,
         u'{0!s}'.format(self._output_mediator.timezone),
-        self._output_mediator.GetMACBRepresentation(event_object),
+        self._output_mediator.GetMACBRepresentation(event),
         source_short,
         source,
-        getattr(event_object, u'timestamp_desc', u'-'),
+        getattr(event, u'timestamp_desc', u'-'),
         username,
         hostname,
         message_short,
         message,
         u'2',
-        getattr(event_object, u'display_name', u'-'),
+        getattr(event, u'display_name', u'-'),
         u'{0!s}'.format(inode),
         u' '.join(notes),
-        getattr(event_object, u'parser', u'-'),
-        extra.replace(u'\n', u'-').replace(u'\r', u''))
+        getattr(event, u'parser', u'-'),
+        extra_attributes]
 
-    output_line = u'{0:s}\n'.format(
-        u','.join(value.replace(u',', u' ') for value in output_values))
+    for index, value in enumerate(output_values):
+      if not isinstance(value, py2to3.STRING_TYPES):
+        value = u''
+      output_values[index] = value.replace(u',', u' ')
+
+    output_line = u','.join(output_values)
+    output_line = u'{0:s}\n'.format(output_line)
     self._WriteLine(output_line)
 
   def WriteHeader(self):
