@@ -12,7 +12,7 @@ from plaso.output import manager
 from plaso.output import shared_4n6time
 
 
-class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
+class SQLite4n6TimeOutputModule(shared_4n6time.Shared4n6TimeOutputModule):
   """Saves the data in a SQLite database, used by the tool 4n6time."""
 
   NAME = u'4n6time_sqlite'
@@ -20,7 +20,7 @@ class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
       u'Saves the data in a SQLite database, used by the tool 4n6time.')
 
   _META_FIELDS = frozenset([
-      u'sourcetype', u'source', u'user', u'host', u'MACB', u'color', u'type',
+      u'sourcetype', u'source', u'user', u'host', u'MACB', u'type',
       u'record_number'])
 
   _CREATE_TABLE_QUERY = (
@@ -29,8 +29,7 @@ class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
       u'user TEXT, host TEXT, description TEXT, filename TEXT, '
       u'inode TEXT, notes TEXT, format TEXT, extra TEXT, '
       u'datetime datetime, reportnotes TEXT, '
-      u'inreport TEXT, tag TEXT, color TEXT, offset INT, '
-      u'store_number INT, store_index INT, vss_store_number INT, '
+      u'inreport TEXT, tag TEXT, offset INT, vss_store_number INT, '
       u'url TEXT, record_number TEXT, event_identifier TEXT, '
       u'event_type TEXT, source_name TEXT, user_sid TEXT, '
       u'computer_name TEXT, evidence TEXT)')
@@ -39,15 +38,14 @@ class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
       u'INSERT INTO log2timeline(timezone, MACB, source, '
       u'sourcetype, type, user, host, description, filename, '
       u'inode, notes, format, extra, datetime, reportnotes, inreport, '
-      u'tag, color, offset, store_number, store_index, vss_store_number, '
-      u'URL, record_number, event_identifier, event_type, '
-      u'source_name, user_sid, computer_name, evidence) '
+      u'tag, offset, vss_store_number, URL, record_number, '
+      u'event_identifier, event_type, source_name, user_sid, computer_name, '
+      u'evidence) '
       u'VALUES (:timezone, :MACB, :source, :sourcetype, :type, :user, :host, '
       u':description, :filename, :inode, :notes, :format, :extra, :datetime, '
-      u':reportnotes, :inreport, :tag, :color, :offset, :store_number, '
-      u':store_index, :vss_store_number, :URL, :record_number, '
-      u':event_identifier, :event_type, :source_name, :user_sid, '
-      u':computer_name, :evidence)')
+      u':reportnotes, :inreport, :tag, :offset, :vss_store_number, '
+      u':URL, :record_number, :event_identifier, :event_type, :source_name, '
+      u':user_sid, :computer_name, :evidence)')
 
   def __init__(self, output_mediator):
     """Initializes the output module object.
@@ -60,6 +58,7 @@ class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
     """
     super(SQLite4n6TimeOutputModule, self).__init__(output_mediator)
     self._connection = None
+    self._count = 0
     self._cursor = None
     self._filename = None
 
@@ -190,7 +189,7 @@ class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
       if self._set_status:
         self._set_status(u'Created table: l2t_disk')
 
-    self.count = 0
+    self._count = 0
 
   def SetFilename(self, filename):
     """Sets the filename.
@@ -205,25 +204,18 @@ class SQLite4n6TimeOutputModule(shared_4n6time.Base4n6TimeOutputModule):
 
     Args:
       event_object: the event object (instance of EventObject).
-
-    Raises:
-      NoFormatterFound: If no event formatter can be found to match the data
-                        type in the event object.
     """
-    if u'timestamp' not in event_object.GetAttributes():
-      return
-
     # sqlite seems to support milli seconds precision but that seems
     # not to be used by 4n6time
     row = self._GetSanitizedEventValues(event_object)
 
     self._cursor.execute(self._INSERT_QUERY, row)
-    self.count += 1
+    self._count += 1
     # Commit the current transaction every 10000 inserts.
-    if self.count % 10000 == 0:
+    if self._count % 10000 == 0:
       self._connection.commit()
       if self._set_status:
-        self._set_status(u'Inserting event: {0:d}'.format(self.count))
+        self._set_status(u'Inserting event: {0:d}'.format(self._count))
 
 
 manager.OutputManager.RegisterOutput(SQLite4n6TimeOutputModule)
