@@ -5,9 +5,11 @@ import os
 
 import construct
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
+from plaso.lib import py2to3
+from plaso.lib import specification
 from plaso.parsers import interface
 from plaso.parsers import manager
 
@@ -89,10 +91,10 @@ class ASLParser(interface.FileObjectParser):
   NAME = u'asl_log'
   DESCRIPTION = u'Parser for ASL log files.'
 
-  _ASL_MAGIC = b'ASL DB\x00\x00\x00\x00\x00\x00'
+  _ASL_SIGNATURE = b'ASL DB\x00\x00\x00\x00\x00\x00'
 
   # ASL File header.
-  # magic: magic number that identify ASL files.
+  # signature: sequence of bytes that identifies an ASL file.
   # version: version of the file.
   # offset: first record in the file.
   # timestamp: time when the first entry was written.
@@ -100,7 +102,7 @@ class ASLParser(interface.FileObjectParser):
   # last_offset: last record in the file.
   _ASL_HEADER_STRUCT = construct.Struct(
       u'asl_header_struct',
-      construct.String(u'magic', 12),
+      construct.String(u'signature', 12),
       construct.UBInt32(u'version'),
       construct.UBInt64(u'offset'),
       construct.UBInt64(u'timestamp'),
@@ -182,6 +184,13 @@ class ASLParser(interface.FileObjectParser):
       construct.UBInt32(u'size'),
       construct.Bytes(u'value', lambda ctx: ctx.size))
 
+  @classmethod
+  def GetFormatSpecification(cls):
+    """Retrieves the format specification."""
+    format_specification = specification.FormatSpecification(cls.NAME)
+    format_specification.AddNewSignature(cls._ASL_SIGNATURE, offset=0)
+    return format_specification
+
   def ParseFileObject(self, parser_mediator, file_object, **kwargs):
     """Parses an ALS file-like object.
 
@@ -200,7 +209,7 @@ class ASLParser(interface.FileObjectParser):
       raise errors.UnableToParseFile(
           u'Unable to parse ASL Header with error: {0:s}.'.format(exception))
 
-    if header.magic != self._ASL_MAGIC:
+    if header.signature != self._ASL_SIGNATURE:
       raise errors.UnableToParseFile(u'Not an ASL Header, unable to parse.')
 
     offset = header.offset
@@ -216,7 +225,7 @@ class ASLParser(interface.FileObjectParser):
       # Sanity check, the last read element must be the same as
       # indicated by the header.
       if offset == 0 and previous_offset != header_last_offset:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'Unable to parse header. Last element header does not match '
             u'header offset.')
       previous_offset = offset
@@ -242,7 +251,7 @@ class ASLParser(interface.FileObjectParser):
     try:
       dynamic_data = file_object.read(offset - dynamic_data_offset)
     except IOError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to read ASL record dynamic data with error: {0:s}'.format(
               exception))
       return None, None
@@ -253,7 +262,7 @@ class ASLParser(interface.FileObjectParser):
     try:
       record_struct = self._ASL_RECORD_STRUCT.parse_stream(file_object)
     except (IOError, construct.FieldError) as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to parse ASL record with error: {0:s}'.format(exception))
       return None, None
 
@@ -296,7 +305,7 @@ class ASLParser(interface.FileObjectParser):
       try:
         field_data = file_object.read(8)
       except IOError as exception:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'unable to read ASL field with error: {0:s}'.format(exception))
         return None, None
 
@@ -318,7 +327,7 @@ class ASLParser(interface.FileObjectParser):
       try:
         pointer_value = self._ASL_POINTER.parse(field_data)
       except ValueError as exception:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'unable to parse ASL field with error: {0:s}'.format(exception))
         return None, None
 
@@ -341,7 +350,7 @@ class ASLParser(interface.FileObjectParser):
           values.append(dyn_value)
 
         except (IOError, construct.FieldError) as exception:
-          parser_mediator.ProduceParseError((
+          parser_mediator.ProduceExtractionError((
               u'unable to parse ASL record dynamic value with error: '
               u'{0:s}').format(exception))
           return None, None
@@ -362,7 +371,7 @@ class ASLParser(interface.FileObjectParser):
             values.append(dyn_value)
 
           except (IOError, construct.FieldError):
-            parser_mediator.ProduceParseError((
+            parser_mediator.ProduceExtractionError((
                 u'the pointer at {0:d} (0x{0:08x}) points to invalid '
                 u'information.').format(
                     main_position - self._ASL_POINTER.sizeof()))
@@ -394,7 +403,7 @@ class ASLParser(interface.FileObjectParser):
     # The first four are always the host, sender, facility, and message.
     number_of_values = len(values)
     if number_of_values < 4:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'less than four values read from an ASL event.')
 
     computer_name = u'N/A'
@@ -419,13 +428,13 @@ class ASLParser(interface.FileObjectParser):
     extra_information = u''
     if number_of_values > 4 and number_of_values % 2 == 0:
       # Taking all the extra attributes and merging them together,
-      # eg: a = [1, 2, 3, 4] will look like "1: 2, 3: 4".
+      # e.g. a = [1, 2, 3, 4] will look like "1: 2, 3: 4".
       try:
-        extra_values = map(unicode, values[4:])
+        extra_values = map(py2to3.UNICODE_TYPE, values[4:])
         extra_information = u', '.join(
             map(u': '.join, zip(extra_values[0::2], extra_values[1::2])))
       except UnicodeDecodeError as exception:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'Unable to decode all ASL values in the extra information fields.')
 
     event_object = ASLEvent(
