@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""This file contains import statements for the ESE database plugins."""
+"""Imports for the ESE database parser."""
 
 from plaso.parsers.esedb_plugins import file_history
 from plaso.parsers.esedb_plugins import msie_webcache
