@@ -8,7 +8,7 @@ import os
 import construct
 import pyparsing
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.parsers import interface
