@@ -11,7 +11,7 @@ import logging
 
 import pyparsing
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import eventdata
 from plaso.lib import errors
 from plaso.lib import timelib
@@ -211,7 +211,7 @@ class WinIISParser(text_parser.PyparsingSingleLineTextParser):
       timestamp = self._ConvertToTimestamp(date, time)
     except errors.TimestampError as exception:
       timestamp = timelib.Timestamp.NONE_TIMESTAMP
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to determine timestamp with error: {0:s}'.format(
               exception))
 
