@@ -6,7 +6,7 @@ import re
 
 import pyparsing
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.lib import timelib
@@ -31,7 +31,7 @@ class MacWifiLogEvent(time_events.TimestampEvent):
       agent: TODO
       function: TODO
       text: The log message
-      action: A string containing known WiFI actions, eg: connected to
+      action: A string containing known WiFI actions, e.g. connected to
               an AP, configured, etc. If the action is not known,
               the value is the message of the log (text variable).
     """
@@ -84,8 +84,8 @@ class MacWifiLogParser(text_parser.PyparsingSingleLineTextParser):
   def __init__(self):
     """Initializes a parser object."""
     super(MacWifiLogParser, self).__init__()
-    self._year_use = 0
     self._last_month = None
+    self._year_use = 0
 
   def _GetAction(self, agent, function, text):
     """Parse the well know actions for easy reading.
@@ -182,7 +182,7 @@ class MacWifiLogParser(text_parser.PyparsingSingleLineTextParser):
       timestamp = self._ConvertToTimestamp(
           structure.day, month, self._year_use, structure.time)
     except errors.TimestampError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to determine timestamp with error: {0:s}'.format(
               exception))
       return
