@@ -4,7 +4,7 @@
 McAfee AV uses 4 logs to track when scans were run, when virus databases were
 updated, and when files match the virus database."""
 
-from plaso.events import text_events
+from plaso.containers import text_events
 from plaso.lib import errors
 from plaso.lib import timelib
 from plaso.parsers import manager
@@ -90,7 +90,7 @@ class McafeeAccessProtectionParser(text_parser.TextCSVParser):
       timestamp = self._ConvertToTimestamp(
           row[u'date'], row[u'time'], parser_mediator.timezone)
     except errors.TimestampError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'Unable to parse time string: [{0:s} {1:s}] with error {2:s}'.format(
               repr(row[u'date']), repr(row[u'time']), exception))
       return
