@@ -8,7 +8,7 @@ import zipfile
 
 from xml.etree import ElementTree
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.lib import timelib
@@ -64,7 +64,7 @@ class OpenXMLParser(interface.FileObjectParser):
 
   def _FixString(self, key):
     """Convert CamelCase to lower_with_underscore."""
-    # TODO: Add unicode support.
+    # TODO: Add Unicode support.
     fix_key = re.sub(r'(.)([A-Z][a-z]+)', r'\1_\2', key)
     return re.sub(r'([a-z0-9])([A-Z])', r'\1_\2', fix_key).lower()
 
@@ -87,7 +87,7 @@ class OpenXMLParser(interface.FileObjectParser):
       return timelib.Timestamp.FromTimeString(time_string)
 
     except errors.TimestampError:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'Unable to parse time string: {0:s}'.format(time_string))
 
   def ParseFileObject(self, parser_mediator, file_object):
@@ -127,7 +127,7 @@ class OpenXMLParser(interface.FileObjectParser):
     try:
       rels_xml = zip_container.read(u'_rels/.rels')
     except zipfile.BadZipfile as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'Unable to parse file with error: {0:s}'.format(exception))
       return
 
