@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """This file contains the Spotlight Volume Configuration plist in Plaso."""
 
-from plaso.events import plist_event
+from plaso.containers import plist_event
 from plaso.parsers import plist
 from plaso.parsers.plist_plugins import interface
 
