@@ -3,7 +3,7 @@
 
 import construct
 
-from plaso.events import plist_event
+from plaso.containers import plist_event
 from plaso.parsers import plist
 from plaso.parsers.plist_plugins import interface
 
