@@ -6,7 +6,7 @@
    the downloads table.
 """
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import timelib
 from plaso.lib import eventdata
 from plaso.parsers import sqlite
