@@ -6,7 +6,7 @@ try:
 except ImportError:
   import sqlite3
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import eventdata
 from plaso.parsers import sqlite
 from plaso.parsers.sqlite_plugins import interface
