@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Parser for the Firefox Cookie database."""
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.lib import timelib
