@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Parser for the Mac OS X Document Versions files."""
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import eventdata
 from plaso.parsers import sqlite
 from plaso.parsers.sqlite_plugins import interface
