@@ -4,7 +4,7 @@
 import codecs
 import json
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.lib import py2to3
@@ -208,7 +208,7 @@ class MacKeeperCachePlugin(interface.SQLitePlugin):
       try:
         timestamp = timelib.Timestamp.FromTimeString(time_value)
       except errors.TimestampError:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'Unable to parse time string: {0:s}'.format(time_value))
         return
 
