@@ -5,7 +5,7 @@
    from files opened to websites visited and conversations.
 """
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import eventdata
 from plaso.parsers import sqlite
 from plaso.parsers.sqlite_plugins import interface
