@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 """This file contains a Symantec parser in plaso."""
 
-from plaso.events import text_events
+from plaso.containers import text_events
 from plaso.lib import errors
 from plaso.lib import timelib
 from plaso.parsers import manager
 from plaso.parsers import text_parser
 
-import pytz
+import pytz  # pylint: disable=wrong-import-order
 
 
 __author__ = 'David Nides (david.nides@gmail.com)'
@@ -127,7 +127,7 @@ class SymantecParser(text_parser.TextCSVParser):
           row[u'time'], timezone=parser_mediator.timezone)
     except (TypeError, ValueError, errors.TimestampError) as exception:
       timestamp = timelib.Timestamp.NONE_TIMESTAMP
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to determine timestamp with error: {0:s}'.format(
               exception))
 
