@@ -9,398 +9,27 @@ parser.
 import abc
 import csv
 import logging
-import os
 
-from dfvfs.helpers import text_file
 import pyparsing
 
-from plaso.events import text_events
+from dfvfs.helpers import text_file
+
+from plaso.containers import events
 from plaso.lib import errors
-from plaso.lib import event
-from plaso.lib import lexer
-from plaso.lib import timelib
 from plaso.lib import utils
 from plaso.parsers import interface
 
-import pytz
 
 # Pylint complains about some functions not being implemented that shouldn't
 # be since they need to be implemented by children.
 # pylint: disable=abstract-method
 
-
-class SlowLexicalTextParser(
-    interface.FileObjectParser, lexer.SelfFeederMixIn):
-  """Generic text based parser that uses lexer to assist with parsing.
-
-  This text parser is based on a rather slow lexer, which makes the
-  use of this interface highly discouraged. Parsers that already
-  implement it will most likely all be rewritten to support faster
-  text parsing implementations.
-
-  This text based parser needs to be extended to provide an accurate
-  list of tokens that define the structure of the log file that the
-  parser is designed for.
-  """
-
-  _INITIAL_FILE_OFFSET = None
-
-  # Define the max number of lines before we determine this is
-  # not the correct parser.
-  MAX_LINES = 15
-
-  # List of tokens that describe the structure of the log file.
-  tokens = [
-      lexer.Token(u'INITIAL', r'(.+)\n', u'ParseString', u''),
-      ]
-
-  def __init__(self, local_zone=True):
-    """Constructor for the SlowLexicalTextParser.
-
-    Args:
-      local_zone: a boolean value that determines if the entries
-                  in the log file are stored in the local time
-                  zone of the computer that stored it or in a fixed
-                  timezone, like UTC.
-    """
-    # TODO: remove the multiple inheritance.
-    lexer.SelfFeederMixIn.__init__(self)
-    interface.FileObjectParser.__init__(self)
-    self._file_verified = False
-    self.line_ready = False
-    self.attributes = {
-        u'body': u'',
-        u'iyear': 0,
-        u'imonth': 0,
-        u'iday': 0,
-        u'time': u'',
-        u'hostname': u'',
-        u'username': u'',
-    }
-    self.local_zone = local_zone
-
-  def ClearValues(self):
-    """Clears all the values inside the attributes dict.
-
-    All values that start with the letter 'i' are considered
-    to be an integer, otherwise string value is assumed.
-    """
-    self.line_ready = False
-    for attr in self.attributes:
-      if attr.startswith(u'i'):
-        self.attributes[attr] = 0
-      else:
-        self.attributes[attr] = u''
-
-  def CreateEvent(self, timestamp, offset, attributes):
-    """Creates an event.
-
-       This function should be overwritten by text parsers that required
-       the generation of specific event object type, the default event
-       type is TextEvent.
-
-    Args:
-      timestamp: the timestamp time value. The timestamp contains the
-                 number of microseconds since Jan 1, 1970 00:00:00 UTC.
-      offset: the offset of the event.
-      attributes: a dictionary that contains the event's attributes.
-
-    Returns:
-      An event object (instance of TextEvent).
-    """
-    return text_events.TextEvent(timestamp, offset, attributes)
-
-  def ParseIncomplete(self, match=None, **unused_kwargs):
-    """Parse a partial line match and append to the body attribute.
-
-    Args:
-      match: optional regular expression match object (instance of SRE_Match).
-    """
-    if not match:
-      return
-
-    try:
-      self.attributes[u'body'] += match.group(0)
-    except UnicodeDecodeError:
-      # TODO: Support other encodings than UTF-8 here, read from the
-      # knowledge base or parse from the file itself.
-      self.attributes[u'body'] += u'{0:s}'.format(
-          match.group(0).decode(u'utf-8', errors=u'ignore'))
-
-    self.line_ready = True
-
-  def ParseMessage(self, **unused_kwargs):
-    """Signal that a line is ready to be parsed."""
-    self.line_ready = True
-
-  def ParseFileObject(self, parser_mediator, file_object, **kwargs):
-    """Parses a text file-like object using a lexer.
-
-    Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      file_object: a file-like object.
-
-    Raises:
-      UnableToParseFile: when the file cannot be parsed.
-    """
-    file_entry = parser_mediator.GetFileEntry()
-    path_spec_printable = u'{0:s}:{1:s}'.format(
-        file_entry.path_spec.type_indicator, file_entry.name)
-
-    # TODO: this is necessary since we inherit from lexer.SelfFeederMixIn.
-    self.file_object = file_object
-    self._file_verified = False
-
-    # Start by checking, is this a text file or not? Before we proceed
-    # any further.
-    file_object.seek(0, os.SEEK_SET)
-    if not utils.IsText(file_object.read(40)):
-      raise errors.UnableToParseFile(u'Not a text file, unable to proceed.')
-
-    file_object.seek(0, os.SEEK_SET)
-
-    error_count = 0
-    # We need to clear out few values in the Lexer before continuing.
-    # There might be some leftovers from previous run.
-    self.error = 0
-    self.buffer = b''
-
-    while True:
-      _ = self.NextToken()
-
-      if self.state == u'INITIAL':
-        self.entry_offset = getattr(self, u'next_entry_offset', 0)
-        self.next_entry_offset = file_object.tell() - len(self.buffer)
-
-      if not self._file_verified and self.error >= self.MAX_LINES * 2:
-        logging.debug(
-            u'Lexer error count: {0:d} and current state {1:s}'.format(
-                self.error, self.state))
-        raise errors.UnableToParseFile(
-            u'[{0:s}] unsupported file: {1:s}.'.format(
-                self.NAME, path_spec_printable))
-
-      if self.line_ready:
-        try:
-          self.ParseLine(parser_mediator)
-          self._file_verified = True
-
-        except errors.TimestampError as exception:
-          error_count += 1
-          if self._file_verified:
-            logging.debug(
-                u'[{0:s} VERIFIED] Error count: {1:d} and ERROR: {2:d}'.format(
-                    path_spec_printable, error_count, self.error))
-            logging.warning(
-                u'[{0:s}] Unable to parse timestamp with error: {1:s}'.format(
-                    self.NAME, exception))
-
-          else:
-            logging.debug((
-                u'[{0:s} EVALUATING] Error count: {1:d} and ERROR: '
-                u'{2:d})').format(path_spec_printable, error_count, self.error))
-
-            if error_count >= self.MAX_LINES:
-              raise errors.UnableToParseFile(
-                  u'[{0:s}] unsupported file: {1:s}.'.format(
-                      self.NAME, path_spec_printable))
-
-        finally:
-          self.ClearValues()
-
-      if self.Empty():
-        # Try to fill the buffer to prevent the parser from ending prematurely.
-        self.Feed()
-
-      if self.Empty():
-        break
-
-    if not self._file_verified:
-      raise errors.UnableToParseFile(
-          u'[{0:s}] unable to parse file: {1:s}.'.format(
-              self.NAME, path_spec_printable))
-
-    file_offset = file_object.get_offset()
-    if file_offset < file_object.get_size():
-      parser_mediator.ProduceParseError((
-          u'{0:s} prematurely terminated parsing: {1:s} at offset: '
-          u'0x{2:08x}.').format(
-              self.NAME, path_spec_printable, file_offset))
-
-  def ParseString(self, match=None, **unused_kwargs):
-    """Return a string with combined values from the lexer.
-
-    Args:
-      match: optional regular expression match object (instance of SRE_Match).
-
-    Returns:
-      A string that combines the values that are so far
-      saved from the lexer.
-    """
-    try:
-      self.attributes[u'body'] += match.group(1).strip(u'\n')
-    except IndexError:
-      self.attributes[u'body'] += match.group(0).strip(u'\n')
-
-  def PrintLine(self):
-    """"Return a string with combined values from the lexer."""
-    year = getattr(self.attributes, u'iyear', None)
-    month = getattr(self.attributes, u'imonth', None)
-    day = getattr(self.attributes, u'iday', None)
-
-    if None in [year, month, day]:
-      date_string = u'[DATE NOT SET]'
-    else:
-      try:
-        year = int(year, 10)
-        month = int(month, 10)
-        day = int(day, 10)
-
-        date_string = u'{0:04d}-{1:02d}-{2:02d}'.format(year, month, day)
-      except ValueError:
-        date_string = u'[DATE INVALID]'
-
-    time_string = getattr(self.attributes, u'time', u'[TIME NOT SET]')
-    hostname_string = getattr(self.attributes, u'hostname', u'HOSTNAME NOT SET')
-    reporter_string = getattr(
-        self.attributes, u'reporter', u'[REPORTER NOT SET]')
-    body_string = getattr(self.attributes, u'body', u'[BODY NOT SET]')
-
-    # TODO: this is a work in progress. The reason for the try-catch is that
-    # the text parser is handed a non-text file and must deal with converting
-    # arbitrary binary data.
-    try:
-      line = u'{0:s} {1:s} [{2:s}] {3:s} => {4:s}'.format(
-          date_string, time_string, hostname_string, reporter_string,
-          body_string)
-    except UnicodeError:
-      line = u'Unable to print line - due to encoding error.'
-
-    return line
-
-  def ParseLine(self, parser_mediator):
-    """Parses the current log line for events.
-
-    Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-    """
-    year_string = self.attributes.get(u'iyear')
-    if not year_string:
-      if not self._file_verified:
-        raise errors.UnableToParseFile()
-      parser_mediator.ProduceParseError(
-          u'year missing in log line: {0:s}'.format(self.PrintLine()))
-      return
-
-    time_string = self.attributes.get(u'time')
-    if not time_string:
-      if not self._file_verified:
-        raise errors.UnableToParseFile()
-      parser_mediator.ProduceParseError(
-          u'time values missing in log line: {0:s}'.format(self.PrintLine()))
-      return
-
-    time_values = time_string.split(u':')
-    if len(time_values) < 3:
-      if not self._file_verified:
-        raise errors.UnableToParseFile()
-      parser_mediator.ProduceParseError(
-          u'unsupported time format in log line: {0:s}'.format(
-              self.PrintLine()))
-      return
-
-    seconds_values = time_values[2].split(u'.')
-    if len(seconds_values) == 2:
-      seconds_string, microseconds_string = seconds_values
-    else:
-      seconds_string = time_values[2]
-      microseconds_string = 0
-
-    try:
-      # TODO: fix the need to convert non string values into integers and
-      # string to integer conversion without an explicit base.
-      year = int(year_string)
-      hours = int(time_values[0])
-      minutes = int(time_values[1])
-      seconds = int(seconds_string)
-      microseconds = int(microseconds_string)
-
-    except ValueError as exception:
-      if not self._file_verified:
-        raise errors.UnableToParseFile()
-      parser_mediator.ProduceParseError(
-          u'unable to parse log line: {0:s} with error: {1:s}'.format(
-              self.PrintLine(), exception))
-      return
-
-    if self.local_zone:
-      timezone = parser_mediator.timezone
-    else:
-      timezone = pytz.UTC
-
-    try:
-      timestamp = timelib.Timestamp.FromTimeParts(
-          year, self.attributes[u'imonth'], self.attributes[u'iday'],
-          hours, minutes, seconds, microseconds=microseconds,
-          timezone=timezone)
-    except errors.TimestampError as exception:
-      timestamp = timelib.Timestamp.NONE_TIMESTAMP
-      parser_mediator.ProduceParseError(
-          u'unable to determine timestamp with error: {0:s}'.format(
-              exception))
-
-    event_object = self.CreateEvent(
-        timestamp, getattr(self, u'entry_offset', 0), self.attributes)
-    parser_mediator.ProduceEvent(event_object)
-
-  def SetDay(self, match=None, **unused_kwargs):
-    """Parses the day of the month.
-
-       This is a callback function for the text parser (lexer) and is
-       called by the corresponding lexer state.
-
-    Args:
-      match: optional regular expression match object (instance of SRE_Match).
-    """
-    self.attributes[u'iday'] = int(match.group(1))
-  def SetMonth(self, match=None, **unused_kwargs):
-    """Parses the month.
-
-       This is a callback function for the text parser (lexer) and is
-       called by the corresponding lexer state.
-
-    Args:
-      match: optional regular expression match object (instance of SRE_Match).
-    """
-    self.attributes[u'imonth'] = int(
-        timelib.MONTH_DICT.get(match.group(1).lower(), 1))
-
-  def SetTime(self, match=None, **unused_kwargs):
-    """Set the time attribute.
-
-    Args:
-      match: optional regular expression match object (instance of SRE_Match).
-    """
-    self.attributes[u'time'] = match.group(1)
-
-  def SetYear(self, match=None, **unused_kwargs):
-    """Parses the year.
-
-       This is a callback function for the text parser (lexer) and is
-       called by the corresponding lexer state.
-
-    Args:
-      match: optional regular expression match object (instance of SRE_Match).
-    """
-    self.attributes[u'iyear'] = int(match.group(1))
-
-
 class TextCSVParser(interface.FileObjectParser):
   """An implementation of a simple CSV line-per-entry log files.
 
   Attributes:
-    encoding: The encoding used in the CSV file, or None, if the encoding is
-              unknown.
+    encoding (str): encoding used in the CSV file, or None if the encoding is
+        unknown.
   """
 
   # A list that contains the names of all the fields in the log file.
@@ -425,26 +54,27 @@ class TextCSVParser(interface.FileObjectParser):
   MAGIC_TEST_STRING = b'RegnThvotturMeistarans'
 
   def __init__(self, encoding=None):
-    """Initialize the CSV reader.
+    """Initializes a parser object.
 
-    Arguments:
-      encoding: Optional encoding used in the CSV file. If None, the system
-                codepage set in the parser mediator will be used.
+    Args:
+      encoding (Optional[str]): encoding used in the CSV file, where None
+          indicates the codepage of the parser mediator should be used.
     """
     super(TextCSVParser, self).__init__()
     self.encoding = encoding
 
   def _ConvertRowToUnicode(self, parser_mediator, row):
-    """Converts all strings in a CSV row dict to unicode.
+    """Converts all strings in a CSV row dict to Unicode.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      row: a single row from the CSV file. Strings in this dict are binary
-           strings.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      row (dict[str, bytes]): a row from a CSV file, where the dictionary
+          key contains the column name and the value a binary string.
 
     Returns:
-      A dict containing data from the CSV file, with all strings converted to
-      unicode.
+      dict[str, str]: a row from the CSV file, where the dictionary key
+          contains the column name and the value a Unicode string.
     """
     if not self.encoding:
       # If no encoding is set, we default to the system codepage.
@@ -455,35 +85,24 @@ class TextCSVParser(interface.FileObjectParser):
         row[key] = value.decode(self.encoding)
       except UnicodeDecodeError:
         replaced_value = value.decode(self.encoding, errors=u'replace')
-        parser_mediator.ProduceParseError(
-            u'Error decoding string as {0:s}, characters have been '
+        parser_mediator.ProduceExtractionError(
+            u'error decoding string as {0:s}, characters have been '
             u'replaced in {1:s}'.format(self.encoding, replaced_value))
         row[key] = replaced_value
     return row
 
-  def VerifyRow(self, unused_parser_mediator, unused_row):
-    """Return a bool indicating whether or not this is the correct parser.
-
-    Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      row: a single row from the CSV file. Strings in this dict are binary
-           strings, to aid in file verification.
-
-    Returns:
-      True if this is the correct parser, False otherwise.
-    """
-    pass
-
   def ParseRow(self, parser_mediator, row_offset, row):
     """Parse a line of the log file and extract event objects.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
       row_offset: the offset of the row.
       row: a dictionary containing all the fields as denoted in the
-           COLUMNS class list. Strings in this dict are unicode strings.
+           COLUMNS class list. Strings in this dict are Unicode strings.
     """
-    event_object = event.EventObject()
+    # TODO: replace EventObject with a CSV specific event object.
+    event_object = events.EventObject()
     if row_offset is not None:
       event_object.offset = row_offset
     event_object.row_dict = row
@@ -493,8 +112,9 @@ class TextCSVParser(interface.FileObjectParser):
     """Parses a CSV text file-like object.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      file_object: a file-like object.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      file_object (dfvfs.FileIO): file-like object.
 
     Raises:
       UnableToParseFile: when the file cannot be parsed.
@@ -545,9 +165,24 @@ class TextCSVParser(interface.FileObjectParser):
     self.ParseRow(parser_mediator, text_file_object.tell(), row)
 
     for row in reader:
+      if parser_mediator.abort:
+        break
       row = self._ConvertRowToUnicode(parser_mediator, row)
       self.ParseRow(parser_mediator, text_file_object.tell(), row)
 
+  def VerifyRow(self, unused_parser_mediator, unused_row):
+    """Return a bool indicating whether or not this is the correct parser.
+
+    Args:
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      row (dict[str, bytes]): a single row from the CSV file.
+
+    Returns:
+      bool: True if this is the correct parser, False otherwise.
+    """
+    pass
+
 
 def PyParseRangeCheck(lower_bound, upper_bound):
   """Verify that a number is within a defined range.
@@ -559,14 +194,19 @@ def PyParseRangeCheck(lower_bound, upper_bound):
   in setParseAction with the upper and lower bound set as parameters.
 
   Args:
-    lower_bound: an integer representing the lower bound of the range.
-    upper_bound: an integer representing the upper bound of the range.
+    lower_bound (int): lower bound of the range.
+    upper_bound (int): upper bound of the range.
 
   Returns:
-    A callback method that can be used by pyparsing setParseAction.
+    Function: callback method that can be used by pyparsing setParseAction.
   """
   def CheckRange(unused_string, unused_location, tokens):
-    """Parse the arguments."""
+    """Parse the arguments.
+
+    Args:
+      location (int): location within the string where the match was made.
+      tokens (list[str]): tokens.
+    """
     try:
       check_number = tokens[0]
     except IndexError:
@@ -598,10 +238,10 @@ def PyParseIntCast(unused_string, unused_location, tokens):
   them all to an integer value.
 
   Args:
-    unused_string: the original parsed string.
-    unused_location: the location within the string where the match was made.
-    tokens: A list of extracted tokens (where the string to be converted is
-    stored).
+    string (str): original parsed string.
+    location (int): location within the string where the match was made.
+    tokens (list[str]): extracted tokens, where the string to be converted
+        is stored.
   """
   # Cast the regular tokens.
   for index, token in enumerate(tokens):
@@ -631,10 +271,10 @@ def PyParseJoinList(unused_string, unused_location, tokens):
   token.
 
   Args:
-    unused_string: the original parsed string.
-    unused_location: the location within the string where the match was made.
-    tokens: a list of extracted tokens. This is the list that should be joined
-    together and stored as a single token.
+    string (str): original parsed string.
+    location (int): location within the string where the match was made.
+    tokens (list[str]): extracted tokens, where the string to be converted
+        is stored.
   """
   join_list = []
   for token in tokens:
@@ -726,31 +366,33 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
   # attribute.
   _ENCODING = u'ascii'
 
+  _EMPTY_LINES = frozenset([b'\n', b'\r', b'\r\n'])
+
   def __init__(self):
-    """Initializes the pyparsing single-line text parser object."""
+    """Initializes a parser object."""
     super(PyparsingSingleLineTextParser, self).__init__()
-    self.encoding = self._ENCODING
     self._current_offset = 0
     # TODO: self._line_structures is a work-around and this needs
     # a structural fix.
     self._line_structures = self.LINE_STRUCTURES
+    self.encoding = self._ENCODING
 
   def _ReadLine(
       self, parser_mediator, text_file_object, max_len=0, quiet=False, depth=0):
-    """Read a single line from a text file and return it back.
+    """Reads a line from a text file.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      text_file_object: a text file object (instance of dfvfs.TextFile).
-      max_len: optional maximum number of bytes a single line can take.
-      quiet: optional boolean value to indicate parse warning should not be
-             displayed.
-      depth: optional number of new lines the parser can encounter before
-             bailing out.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      text_file_object (dfvfs.TextFile): text file.
+      max_len (Optional[int]): maximum number of bytes a single line can take.
+      quiet (Optional[bool]): True if parse warnings should not be displayed.
+      depth (Optional[int]): number of new lines the parser can encounter
+          before bailing out.
 
     Returns:
-      A single line read from the file-like object, or the maximum number of
-      characters (if max_len defined and line longer than the defined size).
+      str: single line read from the file-like object, or the maximum number of
+          characters, if max_len defined and line longer than the defined size.
     """
     if max_len:
       line = text_file_object.readline(max_len)
@@ -760,8 +402,7 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
     if not line:
       return
 
-    # If line is empty, skip it and go on.
-    if line in [b'\n', b'\r\n']:
+    if line in self._EMPTY_LINES:
       # Max 40 new lines in a row before we bail out.
       if depth == 40:
         return u''
@@ -773,23 +414,22 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
       return line.strip()
 
     try:
-      decoded_line = line.decode(self.encoding)
-      return decoded_line.strip()
+      line = line.decode(self.encoding)
     except UnicodeDecodeError:
       if not quiet:
-        display_name = parser_mediator.GetDisplayName()
-        logging.warning((
-            u'Unable to decode line [{0:s}...] with encoding: {1:s} in '
-            u'file: {2:s}').format(
-                repr(line[1:30]), self.encoding, display_name))
-      return line.strip()
+        parser_mediator.ProduceExtractionError(
+            u'unable to decode line: "{0:s}..." with encoding: {1:s}'.format(
+                repr(line[:30]), self.encoding))
+
+    return line.strip()
 
   def ParseFileObject(self, parser_mediator, file_object, **kwargs):
     """Parses a text file-like object using a pyparsing definition.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      file_object: a file-like object.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      file_object (dfvfs.FileIO): file-like object.
 
     Raises:
       UnableToParseFile: when the file cannot be parsed.
@@ -826,6 +466,8 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
     self._current_offset = 0
     # Read every line in the text file.
     while line:
+      if parser_mediator.abort:
+        break
       parsed_structure = None
       use_key = None
       # Try to parse the line using all the line structures.
@@ -847,8 +489,8 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
       else:
         if len(line) > 80:
           line = u'{0:s}...'.format(line[0:77])
-        parser_mediator.ProduceParseError(
-            u'Unable to parse log line: {0:s} at offset {1:d}'.format(
+        parser_mediator.ProduceExtractionError(
+            u'unable to parse log line: {0:s} at offset {1:d}'.format(
                 repr(line), self._current_offset))
 
       self._current_offset = text_file_object.get_offset()
@@ -862,14 +504,13 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
     and produces an EventObject if possible from that structure.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      key: an identification string indicating the name of the parsed
-           structure.
-      structure: a pyparsing.ParseResults object from a line in the
-                 log file.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      key (str): name of the parsed structure.
+      structure (pyparsing.ParseResults): tokens from a parsed log line.
 
     Returns:
-      An event object (instance of EventObject) or None.
+      EventObject: event or None.
     """
 
   @abc.abstractmethod
@@ -880,11 +521,12 @@ class PyparsingSingleLineTextParser(interface.FileObjectParser):
     that the file is the correct one for this particular parser.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      line: a single line from the text file.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      line (str): single line from the text file.
 
     Returns:
-      True if this is the correct parser, False otherwise.
+      bool: True if this is the correct parser, False otherwise.
     """
 
 
@@ -895,8 +537,8 @@ class EncodedTextReader(object):
     """Initializes the encoded test reader object.
 
     Args:
-      buffer_size: optional buffer size.
-      encoding: optional encoding.
+      buffer_size (Optional[int]): buffer size.
+      encoding (Optional[str]): encoding.
     """
     super(EncodedTextReader, self).__init__()
     self._buffer = b''
@@ -920,10 +562,10 @@ class EncodedTextReader(object):
     """Reads a line from the file object.
 
     Args:
-      file_object: the file-like object.
+      file_object (dfvfs.FileIO): file-like object.
 
     Returns:
-      A string containing the line.
+      str: line read from the file-like object.
     """
     if len(self._buffer) < self._buffer_size:
       self._buffer = b''.join([
@@ -960,10 +602,10 @@ class EncodedTextReader(object):
     """Reads a line.
 
     Args:
-      file_object: the file-like object.
+      file_object (dfvfs.FileIO): file-like object.
 
     Returns:
-      A single line read from the lines buffer.
+      str: line read from the lines buffer.
     """
     line, _, self.lines = self.lines.partition(u'\n')
     if not line:
@@ -976,7 +618,7 @@ class EncodedTextReader(object):
     """Reads lines into the lines buffer.
 
     Args:
-      file_object: the file-like object.
+      file_object (dfvfs.FileIO): file-like object.
     """
     lines_size = len(self.lines)
     if lines_size < self._buffer_size:
@@ -1000,8 +642,8 @@ class EncodedTextReader(object):
     """Skips ahead a number of characters.
 
     Args:
-      file_object: the file-like object.
-      number_of_characters: the number of characters.
+      file_object (dfvfs.FileIO): file-like object.
+      number_of_characters (int): number of characters.
     """
     lines_size = len(self.lines)
     while number_of_characters >= lines_size:
@@ -1022,7 +664,7 @@ class PyparsingMultiLineTextParser(PyparsingSingleLineTextParser):
   BUFFER_SIZE = 2048
 
   def __init__(self):
-    """Initializes the pyparsing multi-line text parser object."""
+    """Initializes a parser object."""
     super(PyparsingMultiLineTextParser, self).__init__()
     self._buffer_size = self.BUFFER_SIZE
     self._text_reader = EncodedTextReader(
@@ -1032,8 +674,9 @@ class PyparsingMultiLineTextParser(PyparsingSingleLineTextParser):
     """Parses a text file-like object using a pyparsing definition.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      file_object: a file-like object.
+      parser_mediator (ParserMediator): mediates interactions between parsers
+          and other components, such as storage and dfvfs.
+      file_object (dfvfs.FileIO): file-like object.
 
     Raises:
       UnableToParseFile: when the file cannot be parsed.
@@ -1062,6 +705,8 @@ class PyparsingMultiLineTextParser(PyparsingSingleLineTextParser):
 
     # Read every line in the text file.
     while self._text_reader.lines:
+      if parser_mediator.abort:
+        break
       # Initialize pyparsing objects.
       tokens = None
       start = 0
@@ -1097,12 +742,12 @@ class PyparsingMultiLineTextParser(PyparsingSingleLineTextParser):
         if odd_line:
           if len(odd_line) > 80:
             odd_line = u'{0:s}...'.format(odd_line[0:77])
-          parser_mediator.ProduceParseError(
-              u'Unable to parse log line: {0:s}'.format(repr(odd_line)))
+          parser_mediator.ProduceExtractionError(
+              u'unable to parse log line: {0:s}'.format(repr(odd_line)))
 
       try:
         self._text_reader.ReadLines(file_object)
       except UnicodeDecodeError as exception:
-        parser_mediator.ProduceParseError(
-            u'Unable to read lines from file with error: {0:s}'.format(
+        parser_mediator.ProduceExtractionError(
+            u'unable to read lines from file with error: {0:s}'.format(
                 exception))
