@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 """Parser for Linux UTMP files."""
 
-import construct
 import logging
 import os
 import socket
 
-from plaso.events import time_events
+import construct
+
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.parsers import interface
@@ -191,7 +192,7 @@ class UtmpParser(interface.FileObjectParser):
       entry = self.LINUX_UTMP_ENTRY.parse(data)
     except (IOError, construct.FieldError):
       logging.warning((
-          u'UTMP entry at 0x{:x} couldn\'t be parsed.').format(offset))
+          u'UTMP entry at 0x{0:x} couldn\'t be parsed.').format(offset))
       return self._ReadUtmpEvent(file_object)
 
     user = self._GetTextFromNullTerminatedString(entry.username)
