@@ -4,7 +4,7 @@
 import pyevt
 
 from plaso import dependencies
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import eventdata
 from plaso.lib import specification
 from plaso.parsers import interface
@@ -18,37 +18,39 @@ class WinEvtRecordEvent(time_events.PosixTimeEvent):
   """Convenience class for a Windows EventLog (EVT) record event.
 
   Attributes:
-    computer_name: the computer name stored in the event record.
-    event_category: the event category.
-    event_identifier: the event identifier.
-    event_type: the event type.
-    facility: the event facility.
-    message_identifier: the event message identifier.
-    offset: the data offset of the event record with in the file.
-    record_number: the event record number.
-    recovered: boolean value to indicate the record was recovered.
-    severity: the event severity.
-    source_name: the name of the event source.
-    strings: array of event strings.
-    user_sid: the user security identifier (SID) stored in the event record.
+    computer_name (str): computer name stored in the event record.
+    event_category (int): event category.
+    event_identifier (int): event identifier.
+    event_type (int): event type.
+    facility (int): event facility.
+    message_identifier (int): event message identifier.
+    offset (int): data offset of the event record with in the file.
+    record_number (int): event record number.
+    recovered (bool): True if the record was recovered.
+    severity (int): event severity.
+    source_name (str): name of the event source.
+    strings (list[str]): event strings.
+    user_sid (str): user security identifier (SID) stored in the event record.
   """
 
   DATA_TYPE = u'windows:evt:record'
 
   def __init__(
-      self, timestamp, timestamp_description, evt_record, record_number,
+      self, posix_time, timestamp_description, evt_record, record_number,
       event_identifier, recovered=False):
     """Initializes the event.
 
     Args:
-      timestamp: the POSIX timestamp value.
-      timestamp_description: a description string for the timestamp value.
-      evt_record: the EVT record (instance of pyevt.record).
-      record_number: the event record number.
-      event_identifier: the event identifier.
-      recovered: optional boolean value to indicate the record was recovered.
+      posix_time (int): POSIX time value, which contains the number of seconds
+          since January 1, 1970 00:00:00 UTC.
+      timestamp_description (str): description of the usage of the timestamp
+          value.
+      evt_record (pyevt.record): event record.
+      record_number (int): event record number.
+      event_identifier (int): event identifier.
+      recovered (Optional[bool]): True if the record was recovered.
     """
-    super(WinEvtRecordEvent, self).__init__(timestamp, timestamp_description)
+    super(WinEvtRecordEvent, self).__init__(posix_time, timestamp_description)
 
     self.offset = evt_record.offset
     self.recovered = recovered
@@ -89,7 +91,7 @@ class WinEvtParser(interface.FileObjectParser):
     """Retrieves the format specification.
 
     Returns:
-      The format specification (instance of FormatSpecification).
+      FormatSpecification: format specification.
     """
     format_specification = specification.FormatSpecification(cls.NAME)
     format_specification.AddNewSignature(b'LfLe', offset=4)
@@ -100,15 +102,15 @@ class WinEvtParser(interface.FileObjectParser):
     """Extract data from a Windows EventLog (EVT) record.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      record_index: the event record index.
-      evt_record: an event record (instance of pyevt.record).
-      recovered: optional boolean value to indicate the record was recovered.
+      parser_mediator (ParserMediator): parser mediator.
+      record_index (int): event record index.
+      evt_record (pyevt.record): event record.
+      recovered (Optional[bool]): True if the record was recovered.
     """
     try:
       record_number = evt_record.identifier
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read record identifier from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
@@ -117,7 +119,7 @@ class WinEvtParser(interface.FileObjectParser):
     try:
       event_identifier = evt_record.event_identifier
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read event identifier from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
@@ -126,7 +128,7 @@ class WinEvtParser(interface.FileObjectParser):
     try:
       creation_time = evt_record.get_creation_time_as_integer()
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read creation time from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
@@ -141,7 +143,7 @@ class WinEvtParser(interface.FileObjectParser):
     try:
       written_time = evt_record.get_written_time_as_integer()
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read written time from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
@@ -159,8 +161,8 @@ class WinEvtParser(interface.FileObjectParser):
     """Parses a Windows EventLog (EVT) file-like object.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      file_object: a file-like object.
+      parser_mediator (ParserMediator): parser mediator.
+      file_object (dfvfs.FileIO): a file-like object.
     """
     evt_file = pyevt.file()
     evt_file.set_ascii_codepage(parser_mediator.codepage)
@@ -168,24 +170,30 @@ class WinEvtParser(interface.FileObjectParser):
     try:
       evt_file.open_file_object(file_object)
     except IOError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to open file with error: {0:s}'.format(exception))
       return
 
     for record_index, evt_record in enumerate(evt_file.records):
+      if parser_mediator.abort:
+        break
+
       try:
         self._ParseRecord(parser_mediator, record_index, evt_record)
       except IOError as exception:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'unable to parse event record: {0:d} with error: {1:s}'.format(
                 record_index, exception))
 
     for record_index, evt_record in enumerate(evt_file.recovered_records):
+      if parser_mediator.abort:
+        break
+
       try:
         self._ParseRecord(
             parser_mediator, record_index, evt_record, recovered=True)
       except IOError as exception:
-        parser_mediator.ProduceParseError((
+        parser_mediator.ProduceExtractionError((
             u'unable to parse recovered event record: {0:d} with error: '
             u'{1:s}').format(record_index, exception))
 
