@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 """Parser for Windows XML EventLog (EVTX) files."""
 
+from collections import namedtuple
 import pyevtx
 
 from plaso import dependencies
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import eventdata
 from plaso.lib import specification
 from plaso.parsers import interface
@@ -18,36 +19,37 @@ class WinEvtxRecordEvent(time_events.FiletimeEvent):
   """Convenience class for a Windows XML EventLog (EVTX) record event.
 
   Attributes:
-    computer_name: the computer name stored in the event record.
-    event_identifier: the event identifier.
-    event_level: the event level.
-    message_identifier: the event message identifier.
-    offset: the data offset of the event record with in the file.
-    record_number: the event record number.
-    recovered: boolean value to indicate the record was recovered.
-    source_name: the name of the event source.
-    strings: array of event strings.
-    user_sid: the user security identifier (SID) stored in the event record.
-    xml_string: XML representation of the event.
+    computer_name (str): computer name stored in the event record.
+    event_identifier (int): event identifier.
+    event_level (int): event level.
+    message_identifier (int): event message identifier.
+    offset (int): data offset of the event record with in the file.
+    record_number (int): event record number.
+    recovered (bool): True if the record was recovered.
+    source_name (str): name of the event source.
+    strings (list[str]): event strings.
+    user_sid (str): user security identifier (SID) stored in the event record.
+    xml_string (str): XML representation of the event.
   """
 
   DATA_TYPE = u'windows:evtx:record'
 
   def __init__(
-      self, timestamp, evtx_record, record_number, event_identifier,
-      event_identifier_qualifiers, recovered=False):
+      self, filetime, evtx_record, record_number, event_identifier,
+      event_identifier_qualifiers, strings_parsed, recovered=False):
     """Initializes the event.
 
     Args:
-      timestamp: the FILETIME value for the timestamp.
-      evtx_record: the EVTX record (instance of pyevtx.record).
-      record_number: the event record number.
-      event_identifier: the event identifier.
-      event_identifier_qualifiers: the event identifier qualifiers.
-      recovered: optional boolean value to indicate the record was recovered.
+      filetime (int): FILETIME timestamp value.
+      evtx_record (pyevtx.record): event record.
+      record_number (int): event record number.
+      event_identifier (int): event identifier.
+      event_identifier_qualifiers (int): event identifier qualifiers.
+      strings_parsed [dict]: parsed information from evtx_record.strings
+      recovered (Optional[bool]): True if the record was recovered.
     """
     super(WinEvtxRecordEvent, self).__init__(
-        timestamp, eventdata.EventTimestamp.WRITTEN_TIME)
+        filetime, eventdata.EventTimestamp.WRITTEN_TIME)
 
     self.offset = evtx_record.offset
     self.recovered = recovered
@@ -71,7 +73,7 @@ class WinEvtxRecordEvent(time_events.FiletimeEvent):
     self.user_sid = evtx_record.user_security_identifier
 
     self.strings = list(evtx_record.strings)
-
+    self.strings_parsed = strings_parsed
     self.xml_string = evtx_record.xml_string
 
 
@@ -90,20 +92,44 @@ class WinEvtxParser(interface.FileObjectParser):
     format_specification.AddNewSignature(b'ElfFile\x00', offset=0)
     return format_specification
 
+  # Mapping from evtx_record.strings entries to meaningful names.
+  # This mapping is different for each event_identifier.
+  # TODO: make this more generic in context of #158.
+
+  Rule = namedtuple('Rule', ['index', 'name'])
+
+  _EVTX_FIELD_MAP = {
+      4624: [
+          Rule(0, u'source_user_id'),
+          Rule(1, u'source_user_name'),
+          Rule(4, u'target_user_id'),
+          Rule(5, u'target_user_name'),
+          Rule(11, u'target_machine_name'),
+          Rule(18, u'target_machine_ip')
+      ],
+      4648: [
+          Rule(0, u'source_user_id'),
+          Rule(1, u'source_user_name'),
+          Rule(5, u'target_user_name'),
+          Rule(8, u'target_machine_name'),
+          Rule(12, u'target_machine_ip')
+      ]
+  }
+
   def _ParseRecord(
       self, parser_mediator, record_index, evtx_record, recovered=False):
     """Extract data from a Windows XML EventLog (EVTX) record.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      record_index: the event record index.
-      evtx_record: an event record (instance of pyevtx.record).
-      recovered: optional boolean value to indicate the record was recovered.
+      parser_mediator (ParserMediator): parser mediator.
+      record_index (int): event record index.
+      evtx_record (pyevtx.record): event record.
+      recovered (Optional[bool]): True if the record was recovered.
     """
     try:
       record_number = evtx_record.identifier
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read record identifier from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
@@ -112,7 +138,7 @@ class WinEvtxParser(interface.FileObjectParser):
     try:
       event_identifier = evtx_record.event_identifier
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read event identifier from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
@@ -121,7 +147,7 @@ class WinEvtxParser(interface.FileObjectParser):
     try:
       event_identifier_qualifiers = evtx_record.event_identifier_qualifiers
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read event identifier qualifiers from event record: '
           u'{0:d} with error: {1:s}').format(record_index, exception))
 
@@ -130,16 +156,28 @@ class WinEvtxParser(interface.FileObjectParser):
     try:
       written_time = evtx_record.get_written_time_as_integer()
     except OverflowError as exception:
-      parser_mediator.ProduceParseError((
+      parser_mediator.ProduceExtractionError((
           u'unable to read written time from event record: {0:d} '
           u'with error: {1:s}').format(record_index, exception))
 
       written_time = None
 
+    strings_parsed = {}
+    if event_identifier in self._EVTX_FIELD_MAP:
+      rules = self._EVTX_FIELD_MAP.get(event_identifier, [])
+      for rule in rules:
+        if len(evtx_record.strings) <= rule.index:
+          parser_mediator.ProduceExtractionError((
+              u'evtx_record.strings has unexpected length of {0:d} '
+              u'(expected at least {1:d})'.format(
+                  len(evtx_record.strings), rule.index)))
+        strings_parsed[rule.name] = evtx_record.strings[rule.index]
+
+
     if written_time is not None:
       event_object = WinEvtxRecordEvent(
           written_time, evtx_record, record_number, event_identifier,
-          event_identifier_qualifiers, recovered=recovered)
+          event_identifier_qualifiers, strings_parsed, recovered=recovered)
       parser_mediator.ProduceEvent(event_object)
 
     # TODO: what if written_time is None.
@@ -148,8 +186,8 @@ class WinEvtxParser(interface.FileObjectParser):
     """Parses a Windows XML EventLog (EVTX) file-like object.
 
     Args:
-      parser_mediator: a parser mediator object (instance of ParserMediator).
-      file_object: a file-like object.
+      parser_mediator (ParserMediator): parser mediator.
+      file_object (dfvfs.FileIO): a file-like object.
     """
     evtx_file = pyevtx.file()
     evtx_file.set_ascii_codepage(parser_mediator.codepage)
@@ -157,24 +195,30 @@ class WinEvtxParser(interface.FileObjectParser):
     try:
       evtx_file.open_file_object(file_object)
     except IOError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to open file with error: {0:s}'.format(exception))
       return
 
     for record_index, evtx_record in enumerate(evtx_file.records):
+      if parser_mediator.abort:
+        break
+
       try:
         self._ParseRecord(parser_mediator, record_index, evtx_record)
       except IOError as exception:
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'unable to parse event record: {0:d} with error: {1:s}'.format(
                 record_index, exception))
 
     for record_index, evtx_record in enumerate(evtx_file.recovered_records):
+      if parser_mediator.abort:
+        break
+
       try:
         self._ParseRecord(
             parser_mediator, record_index, evtx_record, recovered=True)
       except IOError as exception:
-        parser_mediator.ProduceParseError((
+        parser_mediator.ProduceExtractionError((
             u'unable to parse recovered event record: {0:d} with error: '
             u'{1:s}').format(record_index, exception))
 
