@@ -6,8 +6,8 @@ import uuid
 import pylnk
 
 from plaso import dependencies
-from plaso.events import time_events
-from plaso.events import windows_events
+from plaso.containers import time_events
+from plaso.containers import windows_events
 from plaso.lib import eventdata
 from plaso.lib import specification
 from plaso.parsers import interface
@@ -120,7 +120,7 @@ class WinLnkParser(interface.FileObjectParser):
     try:
       lnk_file.open_file_object(file_object)
     except IOError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to open file with error: {0:s}'.format(exception))
       return
 
@@ -136,17 +136,31 @@ class WinLnkParser(interface.FileObjectParser):
 
       link_target = shell_items_parser.CopyToPath()
 
-    parser_mediator.ProduceEvents(
-        [WinLnkLinkEvent(
-            lnk_file.get_file_access_time_as_integer(),
-            eventdata.EventTimestamp.ACCESS_TIME, lnk_file, link_target),
-         WinLnkLinkEvent(
-             lnk_file.get_file_creation_time_as_integer(),
-             eventdata.EventTimestamp.CREATION_TIME, lnk_file, link_target),
-         WinLnkLinkEvent(
-             lnk_file.get_file_modification_time_as_integer(),
-             eventdata.EventTimestamp.MODIFICATION_TIME, lnk_file,
-             link_target)])
+    access_time = lnk_file.get_file_access_time_as_integer()
+    if access_time > 0:
+      parser_mediator.ProduceEvent(
+          WinLnkLinkEvent(
+              access_time, eventdata.EventTimestamp.ACCESS_TIME, lnk_file,
+              link_target))
+
+    creation_time = lnk_file.get_file_creation_time_as_integer()
+    if creation_time > 0:
+      parser_mediator.ProduceEvent(
+          WinLnkLinkEvent(
+              creation_time, eventdata.EventTimestamp.CREATION_TIME, lnk_file,
+              link_target))
+
+    modification_time = lnk_file.get_file_modification_time_as_integer()
+    if modification_time > 0:
+      parser_mediator.ProduceEvent(
+          WinLnkLinkEvent(
+              modification_time, eventdata.EventTimestamp.MODIFICATION_TIME,
+              lnk_file, link_target))
+
+    if access_time == 0 and creation_time == 0 and modification_time == 0:
+      parser_mediator.ProduceEvent(
+          WinLnkLinkEvent(
+              0, eventdata.EventTimestamp.NOT_A_TIME, lnk_file, link_target))
 
     try:
       uuid_object = uuid.UUID(lnk_file.droid_file_identifier)
