@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """Parser for the CCleaner Registry key."""
 
-from plaso.events import time_events
-from plaso.events import windows_events
+from plaso.containers import time_events
+from plaso.containers import windows_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.lib import timelib
@@ -20,7 +20,7 @@ class CCleanerUpdateEvent(time_events.TimestampEvent):
     key_path: the Windows Registry key path.
   """
 
-  DATA_TYPE = 'ccleaner:update'
+  DATA_TYPE = u'ccleaner:update'
 
   def __init__(self, timestamp, key_path):
     """Initializes an event object.
@@ -82,7 +82,7 @@ class CCleanerPlugin(interface.WindowsRegistryPlugin):
             date_time_string, timezone=parser_mediator.timezone)
       except errors.TimestampError:
         timestamp = None
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'unable to parse time string: {0:s}'.format(date_time_string))
 
       if timestamp is not None:
