@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """This file contains the MSIE zone settings plugin."""
 
-from plaso.events import windows_events
+from plaso.containers import windows_events
 from plaso.parsers import winreg
 from plaso.parsers.winreg_plugins import interface
 
@@ -193,7 +193,7 @@ class MsieZoneSettingsPlugin(interface.WindowsRegistryPlugin):
 
     if registry_key.number_of_subkeys == 0:
       error_string = u'Key: {0:s} missing subkeys.'.format(registry_key.path)
-      parser_mediator.ProduceParseError(error_string)
+      parser_mediator.ProduceExtractionError(error_string)
       return
 
     for zone_key in registry_key.GetSubkeys():
