@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
-"""This file contains a parser for MS Office MRUs for Plaso."""
+""""Windows Registry plugin for the Microsoft Office MRU."""
 
 import re
 
-from plaso.events import windows_events
+from plaso.containers import time_events
+from plaso.containers import windows_events
+from plaso.lib import eventdata
 from plaso.parsers import winreg
 from plaso.parsers.winreg_plugins import interface
 
@@ -11,6 +13,35 @@ from plaso.parsers.winreg_plugins import interface
 __author__ = 'David Nides (david.nides@gmail.com)'
 
 
+class OfficeMRUWindowsRegistryEvent(time_events.FiletimeEvent):
+  """Convenience class for an Microsoft Office MRU Windows Registry event.
+
+  Attributes:
+    key_path: a string containing the Windows Registry key path.
+    offset: an integer containing the data offset of the Microsoft Office MRU
+            Windows Registry value.
+    value_string: a string containing the MRU value.
+  """
+  DATA_TYPE = u'windows:registry:office_mru'
+
+  def __init__(self, filetime, key_path, offset, value_string):
+    """Initializes a Windows Registry event.
+
+    Args:
+      filetime: an integer containing a FILETIME timestamp.
+      key_path: a string containing the Windows Registry key path.
+      offset: an integer containing the data offset of the Microsoft Office MRU
+              Windows Registry value.
+      value_string: a string containing the MRU value.
+    """
+    # TODO: determine if this should be last written time.
+    super(OfficeMRUWindowsRegistryEvent, self).__init__(
+        filetime, eventdata.EventTimestamp.WRITTEN_TIME)
+    self.key_path = key_path
+    self.offset = offset
+    self.value_string = value_string
+
+
 class OfficeMRUPlugin(interface.WindowsRegistryPlugin):
   """Plugin that parses Microsoft Office MRU keys."""
 
@@ -63,7 +94,7 @@ class OfficeMRUPlugin(interface.WindowsRegistryPlugin):
                     dfwinreg.WinRegistryKey).
     """
     # TODO: Test other Office versions to make sure this plugin is applicable.
-    mru_values_dict = {}
+    values_dict = {}
     for registry_value in registry_key.GetValues():
       # Ignore any value not in the form: 'Item [0-9]+'.
       if not registry_value.name or not self._RE_VALUE_NAME.search(
@@ -84,22 +115,20 @@ class OfficeMRUPlugin(interface.WindowsRegistryPlugin):
       try:
         filetime = int(values[0][0], 16)
       except ValueError:
-        parser_mediator.ProduceParseError((
+        parser_mediator.ProduceExtractionError((
             u'unable to convert filetime string to an integer for '
             u'value: {0:s}.').format(registry_value.name))
         continue
 
-      mru_values_dict[registry_value.name] = value_string
+      values_dict[registry_value.name] = value_string
 
-      # TODO: change into a separate event object.
-      values_dict = {registry_value.name: value_string}
-      event_object = windows_events.WindowsRegistryEvent(
-          filetime, registry_key.path, values_dict,
-          offset=registry_key.offset, source_append=self._SOURCE_APPEND)
+      # TODO: split value string in individual values?
+      event_object = OfficeMRUWindowsRegistryEvent(
+          filetime, registry_key.path, registry_value.offset, value_string)
       parser_mediator.ProduceEvent(event_object)
 
     event_object = windows_events.WindowsRegistryEvent(
-        registry_key.last_written_time, registry_key.path, mru_values_dict,
+        registry_key.last_written_time, registry_key.path, values_dict,
         offset=registry_key.offset, source_append=self._SOURCE_APPEND)
     parser_mediator.ProduceEvent(event_object)
 
