@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Plug-in to collect information about the Windows timezone settings."""
 
-from plaso.events import windows_events
+from plaso.containers import windows_events
 from plaso.parsers import winreg
 from plaso.parsers.winreg_plugins import interface
 
