@@ -3,7 +3,7 @@
 
 import logging
 
-from plaso.events import windows_events
+from plaso.containers import windows_events
 from plaso.lib import eventdata
 from plaso.parsers import winreg
 from plaso.parsers.winreg_plugins import interface
