@@ -1,17 +1,50 @@
 # -*- coding: utf-8 -*-
-"""This file contains the UserAssist Windows Registry plugin."""
+"""The UserAssist Windows Registry plugin."""
 
 import logging
 
 import construct
 
-from plaso.events import windows_events
+from plaso.containers import time_events
+from plaso.lib import eventdata
 from plaso.parsers import winreg
 from plaso.parsers.winreg_plugins import interface
 from plaso.winnt import environ_expand
 from plaso.winnt import known_folder_ids
 
 
+class UserAssistWindowsRegistryEvent(time_events.FiletimeEvent):
+  """Convenience class for an UserAssist Windows Registry event.
+
+  Attributes:
+    key_path: a string containing the Windows Registry key path.
+    offset: an integer containing the data offset of the UserAssist
+            Windows Registry value.
+    regvalue: a dictionary containing the UserAssist values.
+  """
+
+  DATA_TYPE = u'windows:registry:userassist'
+
+  def __init__(self, filetime, key_path, offset, values_dict):
+    """Initializes an UserAssist Windows Registry event.
+
+    Args:
+      filetime: an integer containing a FILETIME timestamp.
+      key_path: a string containing the Windows Registry key path.
+      offset: an integer containing the data offset of the UserAssist
+              Windows Registry value.
+      values_dict: dictionary object containing the UserAssist values.
+    """
+    # TODO: check if last written is correct.
+    super(UserAssistWindowsRegistryEvent, self).__init__(
+        filetime, eventdata.EventTimestamp.WRITTEN_TIME)
+
+    self.key_path = key_path
+    self.offset = offset
+    # TODO: rename regvalue to ???.
+    self.regvalue = values_dict
+
+
 class UserAssistWindowsRegistryKeyPathFilter(
     interface.WindowsRegistryKeyPathFilter):
   """UserAssist Windows Registry key path filter."""
@@ -98,21 +131,22 @@ class UserAssistPlugin(interface.WindowsRegistryPlugin):
     count_subkey = registry_key.GetSubkeyByName(u'Count')
 
     if not version_value:
-      parser_mediator.ProduceParseError(u'Missing version value')
+      parser_mediator.ProduceExtractionError(u'Missing version value')
       return
 
     if not version_value.DataIsInteger():
-      parser_mediator.ProduceParseError(u'Unsupported version value data type')
+      parser_mediator.ProduceExtractionError(
+          u'Unsupported version value data type')
       return
 
     format_version = version_value.GetDataAsObject()
-    if format_version not in [3, 5]:
-      parser_mediator.ProduceParseError(
+    if format_version not in (3, 5):
+      parser_mediator.ProduceExtractionError(
           u'Unsupported format version: {0:d}'.format(format_version))
       return
 
     if not count_subkey:
-      parser_mediator.ProduceParseError(u'Missing count subkey')
+      parser_mediator.ProduceExtractionError(u'Missing count subkey')
       return
 
     userassist_entry_index = 0
@@ -150,13 +184,13 @@ class UserAssistPlugin(interface.WindowsRegistryPlugin):
         value_name = u'\\'.join(path_segments)
         # Check if we might need to substitute values.
         if u'%' in value_name:
-          # TODO: deprecate direct use of pre_obj.
+          path_attributes = parser_mediator.knowledge_base.GetPathAttributes()
           value_name = environ_expand.ExpandWindowsEnvironmentVariables(
-              value_name, parser_mediator.knowledge_base.pre_obj)
+              value_name, path_attributes)
 
       value_data_size = len(registry_value.data)
       if not registry_value.DataIsBinaryData():
-        parser_mediator.ProduceParseError(
+        parser_mediator.ProduceExtractionError(
             u'Unsupported value data type: {0:s}'.format(
                 registry_value.data_type_string))
 
@@ -165,7 +199,7 @@ class UserAssistPlugin(interface.WindowsRegistryPlugin):
 
       elif format_version == 3:
         if value_data_size != self._USERASSIST_V3_STRUCT.sizeof():
-          parser_mediator.ProduceParseError(
+          parser_mediator.ProduceExtractionError(
               u'Unsupported value data size: {0:d}'.format(value_data_size))
 
         else:
@@ -178,14 +212,13 @@ class UserAssistPlugin(interface.WindowsRegistryPlugin):
 
           values_dict = {}
           values_dict[value_name] = u'[Count: {0:d}]'.format(count)
-          event_object = windows_events.WindowsRegistryEvent(
-              filetime, count_subkey.path, values_dict,
-              offset=registry_value.offset)
+          event_object = UserAssistWindowsRegistryEvent(
+              filetime, count_subkey.path, registry_value.offset, values_dict)
           parser_mediator.ProduceEvent(event_object)
 
       elif format_version == 5:
         if value_data_size != self._USERASSIST_V5_STRUCT.sizeof():
-          parser_mediator.ProduceParseError(
+          parser_mediator.ProduceExtractionError(
               u'Unsupported value data size: {0:d}'.format(value_data_size))
 
         parsed_data = self._USERASSIST_V5_STRUCT.parse(registry_value.data)
@@ -203,9 +236,8 @@ class UserAssistPlugin(interface.WindowsRegistryPlugin):
                 userassist_entry_index, count, app_focus_count,
                 focus_duration)
 
-        event_object = windows_events.WindowsRegistryEvent(
-            filetime, count_subkey.path, values_dict,
-            offset=count_subkey.offset)
+        event_object = UserAssistWindowsRegistryEvent(
+            filetime, count_subkey.path, count_subkey.offset, values_dict)
         parser_mediator.ProduceEvent(event_object)
 
 
