@@ -56,7 +56,7 @@ import logging
 
 import pyparsing
 
-from plaso.events import time_events
+from plaso.containers import time_events
 from plaso.lib import errors
 from plaso.lib import eventdata
 from plaso.lib import timelib
@@ -132,7 +132,7 @@ class XChatLogParser(text_parser.PyparsingSingleLineTextParser):
   ]
 
   def __init__(self):
-    """Initializes a XChatLog parser object."""
+    """Initializes a parser object."""
     super(XChatLogParser, self).__init__()
     self._xchat_year = 0
     self.offset = 0
@@ -187,7 +187,7 @@ class XChatLogParser(text_parser.PyparsingSingleLineTextParser):
     try:
       timestamp = self._ConvertToTimestamp(structure, parser_mediator.timezone)
     except errors.TimestampError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to determine timestamp with error: {0:s}'.format(
               exception))
       return
@@ -222,7 +222,7 @@ class XChatLogParser(text_parser.PyparsingSingleLineTextParser):
       timestamp = self._ConvertToTimestamp(
           structure, parser_mediator.timezone, year=self._xchat_year)
     except errors.TimestampError as exception:
-      parser_mediator.ProduceParseError(
+      parser_mediator.ProduceExtractionError(
           u'unable to determine timestamp with error: {0:s}'.format(
               exception))
       return
