@@ -5,10 +5,10 @@ import logging
 
 from dfvfs.helpers import file_system_searcher
 from dfvfs.helpers import windows_path_resolver
+from dfwinreg import interface as dfwinreg_interface
+from dfwinreg import regf as dfwinreg_regf
+from dfwinreg import registry as dfwinreg_registry
 
-from plaso.dfwinreg import interface as dfwinreg_interface
-from plaso.dfwinreg import regf as dfwinreg_regf
-from plaso.dfwinreg import registry as dfwinreg_registry
 from plaso.lib import errors
 
 
@@ -19,16 +19,10 @@ class FileSystemWinRegistryFileReader(dfwinreg_interface.WinRegistryFileReader):
     """Initializes a Windows Registry file reader object.
 
     Args:
-      file_system: the file system object (instance of vfs.FileSystem).
-      mount_point: the mount point path specification (instance of
-                   path.PathSpec).
-      path_attributes: optional dictionary of path attributes. The path
-                       attributes correspond to environment variable names
-                       that can be used in the Windows paths. E.g. the
-                       systemroot path attribute corresponds to the
-                       %SystemRoot% environment variable. At moment only
-                       the systemroot and userprofile path attributes are
-                       supported.
+      file_system (dfvfs.FileSytem): file system.
+      mount_point (dfvfs.PathSpec): mount point path specification.
+      path_attributes (Optional[dict[str, str]]): path attributes e.g.
+          {'SystemRoot': '\\Windows'}
     """
     super(FileSystemWinRegistryFileReader, self).__init__()
     self._file_system = file_system
@@ -47,20 +41,20 @@ class FileSystemWinRegistryFileReader(dfwinreg_interface.WinRegistryFileReader):
           self._path_resolver.SetEnvironmentVariable(
               u'UserProfile', attribute_value)
 
-  def _OpenPathSpec(self, path_spec, ascii_codepage=u'cp1252'):
+  def _OpenPathSpec(self, path_specification, ascii_codepage=u'cp1252'):
     """Opens the Windows Registry file specified by the path specification.
 
     Args:
-      path_spec: a path specfication (instance of dfvfs.PathSpec).
-      ascii_codepage: optional ASCII string codepage.
+      path_specification (dfvfs.PathSpec): path specfication.
+      ascii_codepage (Optional[str]): ASCII string codepage.
 
     Returns:
-      The Windows Registry file (instance of WinRegistryFile) or None.
+      WinRegistryFile: Windows Registry file or None.
     """
-    if not path_spec:
+    if not path_specification:
       return
 
-    file_entry = self._file_system.GetFileEntryByPathSpec(path_spec)
+    file_entry = self._file_system.GetFileEntryByPathSpec(path_specification)
     if file_entry is None:
       return
 
@@ -86,17 +80,17 @@ class FileSystemWinRegistryFileReader(dfwinreg_interface.WinRegistryFileReader):
     """Opens the Windows Registry file specified by the path.
 
     Args:
-      path: string containing the path of the Windows Registry file.
-      ascii_codepage: optional ASCII string codepage.
+      path (str): path of the Windows Registry file.
+      ascii_codepage (Optional[str]): ASCII string codepage.
 
     Returns:
-      The Windows Registry file (instance of WinRegistryFile) or None.
+      WinRegistryFile: Windows Registry file or None.
     """
-    path_spec = self._path_resolver.ResolvePath(path)
-    if path_spec is None:
+    path_specification = self._path_resolver.ResolvePath(path)
+    if path_specification is None:
       return
 
-    return self._OpenPathSpec(path_spec)
+    return self._OpenPathSpec(path_specification)
 
 
 class PreprocessPluginsManager(object):
@@ -241,12 +235,9 @@ class PreprocessPluginsManager(object):
     # Run the Registry plugins separately so we do not have to open
     # Registry files in every plugin.
 
+    path_attributes = None
     if knowledge_base:
-      pre_obj = knowledge_base.pre_obj
-      path_attributes = pre_obj.__dict__
-    else:
-      pre_obj = None
-      path_attributes = None
+      path_attributes = knowledge_base.GetPathAttributes()
 
     registry_file_reader = FileSystemWinRegistryFileReader(
         file_system, mount_point, path_attributes=path_attributes)
