@@ -11,6 +11,7 @@ HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\Time Zones
 
 TIME_ZONES = {
     u'AlaskanStandardTime': u'US/Alaska',
+    u'Arabic Standard Time': u'Asia/Baghdad',
     u'AtlanticStandardTime': u'Canada/Atlantic',
     u'AzoresStandardTime': u'Atlantic/Azores',
     u'CanadaCentralStandardTime': u'CST6CDT',
@@ -44,6 +45,7 @@ TIME_ZONES = {
     u'Pacific Standard Time': u'PST8PDT',
     u'PacificStandardTime': u'PST8PDT',
     u'RomanceStandardTime': u'Europe/Belgrade',
+    u'RomanceDaylightTime': u'Europe/Belgrade',
     u'SamoaStandardTime': u'US/Samoa',
     u'SAPacificStandardTime': u'EST5EDT',
     u'SAWesternStandardTime': u'Canada/Atlantic',
@@ -122,6 +124,12 @@ TIME_ZONES = {
     u'@tzres.dll,-290': u'Europe/Warsaw',
     u'@tzres.dll,-291': u'Europe/Warsaw',
     u'@tzres.dll,-292': u'Europe/Warsaw',
+    u'@tzres.dll,-300': u'Europe/Paris',
+    u'@tzres.dll,-301': u'Europe/Paris',
+    u'@tzres.dll,-302': u'Europe/Paris',
+    u'@tzres.dll,-320': u'Europe/Berlin',
+    u'@tzres.dll,-321': u'Europe/Berlin',
+    u'@tzres.dll,-322': u'Europe/Berlin',
     u'@tzres.dll,-331': u'Europe/Nicosia',
     u'@tzres.dll,-332': u'Europe/Nicosia',
     u'@tzres.dll,-340': u'Africa/Cairo',
@@ -131,6 +139,11 @@ TIME_ZONES = {
     u'@tzres.dll,-351': u'Europe/Sofia',
     u'@tzres.dll,-352': u'Europe/Sofia',
     u'@tzres.dll,-365': u'Egypt',
+    u'@tzres.dll,-371': u'Asia/Jerusalem',
+    u'@tzres.dll,-372': u'Asia/Jerusalem',
+    u'@tzres.dll,-380': u'Africa/Harare',
+    u'@tzres.dll,-381': u'Africa/Harare',
+    u'@tzres.dll,-382': u'Africa/Harare',
     u'@tzres.dll,-390': u'Asia/Kuwait',
     u'@tzres.dll,-391': u'Asia/Kuwait',
     u'@tzres.dll,-392': u'Asia/Kuwait',
@@ -143,6 +156,9 @@ TIME_ZONES = {
     u'@tzres.dll,-412': u'Africa/Nairobi',
     u'@tzres.dll,-41': u'Brazil/East',
     u'@tzres.dll,-42': u'Brazil/East',
+    u'@tzres.dll,-420': u'Europe/Moscow',
+    u'@tzres.dll,-421': u'Europe/Moscow',
+    u'@tzres.dll,-422': u'Europe/Moscow',
     u'@tzres.dll,-434': u'Asia/Tbilisi',
     u'@tzres.dll,-435': u'Asia/Tbilisi',
     u'@tzres.dll,-440': u'Asia/Muscat',
@@ -174,6 +190,13 @@ TIME_ZONES = {
     u'@tzres.dll,-570': u'Asia/Chongqing',
     u'@tzres.dll,-571': u'Asia/Chongqing',
     u'@tzres.dll,-572': u'Asia/Chongqing',
+    u'@tzres.dll,-60': u'America/Buenos_Aires',
+    u'@tzres.dll,-611': u'Australia/Perth',
+    u'@tzres.dll,-612': u'Australia/Perth',
+    u'@tzres.dll,-621': u'Asia/Seoul',
+    u'@tzres.dll,-622': u'Asia/Seoul',
+    u'@tzres.dll,-631': u'Asia/Tokyo',
+    u'@tzres.dll,-632': u'Asia/Tokyo',
     u'@tzres.dll,-650': u'Australia/Darwin',
     u'@tzres.dll,-651': u'Australia/Darwin',
     u'@tzres.dll,-652': u'Australia/Darwin',
@@ -186,6 +209,8 @@ TIME_ZONES = {
     u'@tzres.dll,-680': u'Australia/Brisbane',
     u'@tzres.dll,-681': u'Australia/Brisbane',
     u'@tzres.dll,-682': u'Australia/Brisbane',
+    u'@tzres.dll,-691': u'Australia/Hobart',
+    u'@tzres.dll,-692': u'Australia/Hobart',
     u'@tzres.dll,-70': u'Canada/Newfoundland',
     u'@tzres.dll,-71': u'Canada/Newfoundland',
     u'@tzres.dll,-721': u'Pacific/Port_Moresby',
@@ -193,12 +218,18 @@ TIME_ZONES = {
     u'@tzres.dll,-72': u'Canada/Newfoundland',
     u'@tzres.dll,-731': u'Pacific/Fiji',
     u'@tzres.dll,-732': u'Pacific/Fiji',
+    u'@tzres.dll,-740': u'Pacific/Auckland',
+    u'@tzres.dll,-741': u'Pacific/Auckland',
+    u'@tzres.dll,-742': u'Pacific/Auckland',
     u'@tzres.dll,-80': u'Canada/Atlantic',
     u'@tzres.dll,-81': u'Canada/Atlantic',
     u'@tzres.dll,-82': u'Canada/Atlantic',
     u'@tzres.dll,-840': u'America/Argentina/Buenos_Aires',
     u'@tzres.dll,-841': u'America/Argentina/Buenos_Aires',
     u'@tzres.dll,-842': u'America/Argentina/Buenos_Aires',
+    u'@tzres.dll,-870': u'Asia/Karachi',
+    u'@tzres.dll,-871': u'Asia/Karachi',
+    u'@tzres.dll,-872': u'Asia/Karachi',
     u'@tzres.dll,-880': u'UTC',
     u'@tzres.dll,-930': u'UTC',
     u'@tzres.dll,-931': u'UTC',
