@@ -15,9 +15,12 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
   """Tests for the extraction tool object."""
 
   _EXPECTED_OUTPUT_EXTRACTION_OPTIONS = u'\n'.join([
-      (u'usage: extraction_tool_test.py [--hashers HASHER_LIST] '
-       u'[--parsers PARSER_LIST]'),
-      u'                               [-p] [--use_old_preprocess]',
+      (u'usage: extraction_tool_test.py [--hashers HASHER_LIST]'
+       u' [--yara_rules PATH]'),
+      (u'                               [--parsers PARSER_LIST]'
+       u' [--preferred_year YEAR]'),
+      u'                               [-p] [--process_archives]',
+      u'                               [--temporary_directory DIRECTORY]',
       u'',
       u'Test argument parser.',
       u'',
@@ -27,12 +30,12 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
        u'This is a'),
       (u'                        comma separated list where each entry is the '
        u'name of a'),
-      (u'                        hasher. E.g. "md5,sha256", "all" to indicate '
-       u'that all'),
-      (u'                        hashers should be enabled or "none" to '
-       u'disable all'),
-      (u'                        hashers. Use "--hashers list" or "--info" to '
-       u'list the'),
+      (u'                        hasher, such as "md5,sha256". "all" '
+       u'indicates that all'),
+      (u'                        hashers should be enabled. "none" '
+       u'disables all'),
+      (u'                        hashers. Use "--hashers list" or '
+       u'"--info" to list the'),
       u'                        available hashers.',
       u'  --parsers PARSER_LIST',
       (u'                        Define a list of parsers to use by the tool. '
@@ -41,24 +44,43 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
        u'either a'),
       (u'                        name of a parser or a parser list. Each entry '
        u'can be'),
-      (u'                        prepended with a minus sign to negate the '
-       u'selection'),
-      (u'                        (exclude it). The list match is an exact '
-       u'match while'),
-      (u'                        an individual parser matching is a case '
-       u'insensitive'),
-      (u'                        substring match, with support for glob '
-       u'patterns.'),
-      (u'                        Examples would be: "reg" that matches the '
-       u'substring'),
-      u'                        "reg" in all parser names or the glob pattern',
-      (u'                        "sky[pd]" that would match all parsers that '
-       u'have the'),
-      (u'                        string "skyp" or "skyd" in its name. All '
-       u'matching is'),
-      (u'                        case insensitive. Use "--parsers list" or '
-       u'"--info" to'),
-      u'                        list the available parsers.',
+      (u'                        prepended with an exclamation mark to negate '
+       u'the'),
+      (u'                        selection (exclude it). The list match is an '
+       u'exact'),
+      (u'                        match while an individual parser matching is '
+       u'a case'),
+      (u'                        insensitive substring match, with support for '
+       u'glob'),
+      (u'                        patterns. Examples would be: "reg" that '
+       u'matches the'),
+      (u'                        substring "reg" in all parser names or the '
+       u'glob'),
+      (u'                        pattern "sky[pd]" that would match all '
+       u'parsers that'),
+      (u'                        have the string "skyp" or "skyd" in its '
+       u'name. All'),
+      (u'                        matching is case insensitive. Use "--parsers '
+       u'list" or'),
+      u'                        "--info" to list the available parsers.',
+      u'  --preferred_year YEAR, --preferred-year YEAR',
+      (u'                        When a format\'s timestamp does not include '
+       u'a year,'),
+      (u'                        e.g. syslog, use this as the initial year '
+       u'instead of'),
+      u'                        attempting auto-detection.',
+      u'  --process_archives, --process-archives',
+      (u'                        Process file entries embedded within archive '
+       u'files.'),
+      (u'                        This can make processing '
+       u'significantly slower.'),
+      u'  --temporary_directory DIRECTORY, --temporary-directory DIRECTORY',
+      (u'                        Path to the directory that should be used to '
+       u'store'),
+      u'                        temporary files created during extraction.',
+      u'  --yara_rules PATH, --yara-rules PATH',
+      (u'                        Path to a file containing Yara rules '
+       u'definitions.'),
       (u'  -p, --preprocess      Turn on preprocessing. Preprocessing is '
        u'turned on by'),
       (u'                        default when parsing image files, however if '
@@ -66,21 +88,9 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
       (u'                        point is being parsed then this parameter '
        u'needs to be'),
       u'                        set manually.',
-      u'  --use_old_preprocess, --use-old-preprocess',
-      (u'                        Only used in conjunction when appending to a '
-       u'previous'),
-      (u'                        storage file. When this option is used then a '
-       u'new'),
-      (u'                        preprocessing object is not calculated and '
-       u'instead the'),
-      (u'                        last one that got added to the storage file '
-       u'is used.'),
-      (u'                        This can be handy when parsing an image that '
-       u'contains'),
-      u'                        more than a single partition.',
       u''])
 
-  _EXPECTED_PERFOMANCE_OPTIONS = u'\n'.join([
+  _EXPECTED_PERFORMANCE_OPTIONS = u'\n'.join([
       u'usage: extraction_tool_test.py [--buffer_size BUFFER_SIZE]',
       u'                               [--queue_size QUEUE_SIZE]',
       u'',
@@ -97,7 +107,8 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
       u''])
 
   _EXPECTED_PROFILING_OPTIONS = u'\n'.join([
-      u'usage: extraction_tool_test.py [--profile]',
+      (u'usage: extraction_tool_test.py [--profile] '
+       u'[--profiling_directory DIRECTORY]'),
       u'                               [--profiling_sample_rate SAMPLE_RATE]',
       u'                               [--profiling_type TYPE]',
       u'',
@@ -107,6 +118,12 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
       (u'  --profile             Enable profiling. Intended usage is to '
        u'troubleshoot'),
       u'                        memory and performance issues.',
+      u'  --profiling_directory DIRECTORY, --profiling-directory DIRECTORY',
+      (u'                        Path to the directory that should be used '
+       u'to store the'),
+      (u'                        profiling sample files. By default the '
+       u'sample files'),
+      u'                        are stored in the current working directory.',
       (u'  --profiling_sample_rate SAMPLE_RATE, '
        u'--profiling-sample-rate SAMPLE_RATE'),
       (u'                        The profiling sample rate (defaults to a '
@@ -114,30 +131,15 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
       u'                        1000 files).',
       u'  --profiling_type TYPE, --profiling-type TYPE',
       (u'                        The profiling type: "all", "memory", '
-       u'"parsers" or'),
-      u'                        "serializers".',
-      u''])
-
-  _EXPECTED_STORAGE_OPTIONS = u'\n'.join([
-      u'usage: extraction_tool_test.py [--serializer-format FORMAT]',
-      u'',
-      u'Test argument parser.',
-      u'',
-      u'optional arguments:',
-      u'  --serializer-format FORMAT, --serializer_format FORMAT',
-      (u'                        By default the storage uses JSON for '
-       u'serializing event'),
-      (u'                        objects. This parameter can be used to '
-       u'change that'),
-      (u'                        behavior. The choices are "proto" and '
-       u'"json".'),
+       u'"parsers",'),
+      u'                        "processing" or "serializers".',
       u''])
 
   def testAddExtractionOptions(self):
     """Tests the AddExtractionOptions function."""
     argument_parser = argparse.ArgumentParser(
         prog=u'extraction_tool_test.py', description=u'Test argument parser.',
-        add_help=False, formatter_class=argparse.RawDescriptionHelpFormatter)
+        add_help=False, formatter_class=test_lib.SortedArgumentsHelpFormatter)
 
     test_tool = extraction_tool.ExtractionTool()
     test_tool.AddExtractionOptions(argument_parser)
@@ -149,19 +151,19 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
     """Tests the AddPerformanceOptions function."""
     argument_parser = argparse.ArgumentParser(
         prog=u'extraction_tool_test.py', description=u'Test argument parser.',
-        add_help=False, formatter_class=argparse.RawDescriptionHelpFormatter)
+        add_help=False, formatter_class=test_lib.SortedArgumentsHelpFormatter)
 
     test_tool = extraction_tool.ExtractionTool()
     test_tool.AddPerformanceOptions(argument_parser)
 
     output = self._RunArgparseFormatHelp(argument_parser)
-    self.assertEqual(output, self._EXPECTED_PERFOMANCE_OPTIONS)
+    self.assertEqual(output, self._EXPECTED_PERFORMANCE_OPTIONS)
 
   def testAddProfilingOptions(self):
     """Tests the AddProfilingOptions function."""
     argument_parser = argparse.ArgumentParser(
         prog=u'extraction_tool_test.py', description=u'Test argument parser.',
-        add_help=False, formatter_class=argparse.RawDescriptionHelpFormatter)
+        add_help=False, formatter_class=test_lib.SortedArgumentsHelpFormatter)
 
     test_tool = extraction_tool.ExtractionTool()
     test_tool.AddProfilingOptions(argument_parser)
@@ -169,18 +171,6 @@ class ExtractionToolTest(test_lib.CLIToolTestCase):
     output = self._RunArgparseFormatHelp(argument_parser)
     self.assertEqual(output, self._EXPECTED_PROFILING_OPTIONS)
 
-  def testAddStorageOptions(self):
-    """Tests the AddStorageOptions function."""
-    argument_parser = argparse.ArgumentParser(
-        prog=u'extraction_tool_test.py', description=u'Test argument parser.',
-        add_help=False, formatter_class=argparse.RawDescriptionHelpFormatter)
-
-    test_tool = extraction_tool.ExtractionTool()
-    test_tool.AddStorageOptions(argument_parser)
-
-    output = self._RunArgparseFormatHelp(argument_parser)
-    self.assertEqual(output, self._EXPECTED_STORAGE_OPTIONS)
-
   def testParseOptions(self):
     """Tests the ParseOptions function."""
     test_tool = extraction_tool.ExtractionTool()
