@@ -1,12 +1,32 @@
 # -*- coding: utf-8 -*-
 """CLI related functions and classes for testing."""
 
+import argparse
 import io
+import operator
 import os
-import unittest
 
 from plaso.cli import tools
 
+from tests import test_lib as shared_test_lib
+
+
+class SortedArgumentsHelpFormatter(argparse.HelpFormatter):
+  """Class that implements an argparse help formatter with sorted arguments."""
+
+  def add_arguments(self, actions):
+    """Adds arguments.
+
+    Args:
+      actions (TODO): TODO.
+    """
+    actions = sorted(actions, key=operator.attrgetter(u'option_strings'))
+    super(SortedArgumentsHelpFormatter, self).add_arguments(actions)
+
+
+class TestOptions(object):
+  """Class to define test options."""
+
 
 class TestOutputWriter(tools.FileObjectOutputWriter):
   """Class that implements a test output writer."""
@@ -15,7 +35,7 @@ class TestOutputWriter(tools.FileObjectOutputWriter):
     """Initializes the output writer object.
 
     Args:
-      encoding: optional output encoding.
+      encoding (Optional[str]): output encoding.
     """
     file_object = io.BytesIO()
     super(TestOutputWriter, self).__init__(file_object, encoding=encoding)
@@ -25,7 +45,7 @@ class TestOutputWriter(tools.FileObjectOutputWriter):
     """Reads the newly added output data.
 
     Returns:
-      A binary string of the encoded output data.
+      bytes: encoded output data.
     """
     self._file_object.seek(self._read_offset, os.SEEK_SET)
     output_data = self._file_object.read()
@@ -34,41 +54,17 @@ class TestOutputWriter(tools.FileObjectOutputWriter):
     return output_data
 
 
-class TestOptions(object):
-  """Class to define test options."""
-
-
-class CLIToolTestCase(unittest.TestCase):
+class CLIToolTestCase(shared_test_lib.BaseTestCase):
   """The unit test case for a CLI tool."""
 
-  # Show full diff results, part of TestCase so does not follow our naming
-  # conventions.
-  maxDiff = None
-
-  _TEST_DATA_PATH = os.path.join(os.getcwd(), u'test_data')
-
-  def _GetTestFilePath(self, path_segments):
-    """Retrieves the path of a test file relative to the test data directory.
-
-    Args:
-      path_segments: the path segments inside the test data directory.
-
-    Returns:
-      A path of the test file.
-    """
-    # Note that we need to pass the individual path segments to os.path.join
-    # and not a list.
-    return os.path.join(self._TEST_DATA_PATH, *path_segments)
-
   def _RunArgparseFormatHelp(self, argument_parser):
     """Runs argparse.format_help() with test conditions.
 
     Args:
-      argument_parser: an argument parser object (instance of
-                       argparse.ArgumentParser).
+      argument_parser (argparse.ArgumentParser): argument parser.
 
     Returns:
-      A binary string containing the output of argparse.format_help().
+      bytes: output of argparse.format_help().
     """
     columns_environment_variable = os.environ.get(u'COLUMNS', None)
     os.environ[u'COLUMNS'] = u'80'
