@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
-import unittest
+"""The filters shared test library."""
 
 from plaso.filters import interface
 
+from tests import test_lib as shared_test_lib
+
 
 class TestEventFilter(interface.FilterObject):
   """Class to define a filter for a test event."""
@@ -19,5 +21,5 @@ class TestEventFilter(interface.FilterObject):
     pass
 
 
-class FilterTestCase(unittest.TestCase):
+class FilterTestCase(shared_test_lib.BaseTestCase):
   """The unit test case for an event filter."""
