@@ -7,13 +7,12 @@ import unittest
 from plaso.formatters import interface
 from plaso.formatters import mediator
 
-# TODO: refactor to event_test_lib.
-from tests.lib import event as event_test
+from tests.containers import test_lib as containers_test_lib
 from tests.formatters import test_lib
 
 
 class BrokenConditionalEventFormatter(interface.ConditionalEventFormatter):
-  """A broken conditional event formatter."""
+  """An event object for testing the conditional event formatter."""
   DATA_TYPE = u'test:broken_conditional'
   FORMAT_STRING_PIECES = [u'{too} {many} formatting placeholders']
 
@@ -21,12 +20,13 @@ class BrokenConditionalEventFormatter(interface.ConditionalEventFormatter):
   SOURCE_LONG = u'Some Text File.'
 
 
-class ConditionalTestEvent(event_test.TestEvent):
+class ConditionalTestEvent(containers_test_lib.TestEvent):
+  """An event object for testing the conditional event formatter."""
   DATA_TYPE = u'test:event:conditional'
 
 
 class ConditionalTestEventFormatter(interface.ConditionalEventFormatter):
-  """Class to define a formatter for a conditional test event."""
+  """An event formatter for testing the conditional event formatter."""
   DATA_TYPE = u'test:event:conditional'
   FORMAT_STRING_PIECES = [
       u'Description: {description}',
@@ -40,7 +40,7 @@ class ConditionalTestEventFormatter(interface.ConditionalEventFormatter):
 
 
 class WrongEventFormatter(interface.EventFormatter):
-  """A simple event formatter."""
+  """An event formatter for testing."""
   DATA_TYPE = u'test:wrong'
   FORMAT_STRING = u'This format string does not match {body}.'
 
@@ -53,7 +53,7 @@ class EventFormatterTest(unittest.TestCase):
 
   def setUp(self):
     """Makes preparations before running an individual test."""
-    self._event_objects = event_test.GetEventObjects()
+    self._event_objects = containers_test_lib.CreateTestEvents()
 
   def testInitialization(self):
     """Tests the initialization."""
