@@ -1,5 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+"""Tests for the output module interface."""
 
 import unittest
 
@@ -10,16 +11,25 @@ from tests.output import test_lib
 
 
 class TestEvent(object):
-  """Simple class that defines a dummy event."""
+  """Test event object."""
 
   def __init__(self, timestamp, entry):
+    """Initializes an event object."""
+    super(TestEvent, self).__init__()
     self.date = u'03/01/2012'
     try:
       self.timestamp = int(timestamp)
     except ValueError:
       self.timestamp = 0
     self.entry = entry
+
   def EqualityString(self):
+    """Returns a string describing the event object in terms of object equality.
+
+    Returns:
+      A string representation of the event object that can be used for equality
+      comparison.
+    """
     return u';'.join(map(str, [self.timestamp, self.entry]))
 
 
