@@ -16,19 +16,15 @@ from tests.parsers import test_lib
 class AndroidAppUsageParserTest(test_lib.ParserTestCase):
   """Tests for the Android Application Usage History parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = android_app_usage.AndroidAppUsageParser()
-
   def testParse(self):
     """Tests the Parse function."""
-    test_file = self._GetTestFilePath([u'usage-history.xml'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = android_app_usage.AndroidAppUsageParser()
+    storage_writer = self._ParseFile(
+        [u'usage-history.xml'], parser_object)
 
-    self.assertEqual(len(event_objects), 28)
+    self.assertEqual(len(storage_writer.events), 28)
 
-    event_object = event_objects[22]
+    event_object = storage_writer.events[22]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2013-12-09 19:28:33.047000')
@@ -48,7 +44,7 @@ class AndroidAppUsageParserTest(test_lib.ParserTestCase):
 
     self._TestGetMessageStrings(event_object, expected_msg, expected_msg_short)
 
-    event_object = event_objects[17]
+    event_object = storage_writer.events[17]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2013-09-27 19:45:55.675000')
