@@ -14,19 +14,15 @@ from tests.parsers import test_lib
 class ASLParserTest(test_lib.ParserTestCase):
   """Tests for Apple System Log file parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = asl.ASLParser()
-
   def testParse(self):
     """Tests the Parse function."""
-    test_file = self._GetTestFilePath([u'applesystemlog.asl'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = asl.ASLParser()
+    storage_writer = self._ParseFile(
+        [u'applesystemlog.asl'], parser_object)
 
-    self.assertEqual(len(event_objects), 2)
+    self.assertEqual(len(storage_writer.events), 2)
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2013-11-25 09:45:35.705481')
