@@ -15,22 +15,17 @@ from tests.parsers import test_lib
 class CustomDestinationsParserTest(test_lib.ParserTestCase):
   """Tests for the .customDestinations-ms file parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = custom_destinations.CustomDestinationsParser()
-
   def testParse(self):
     """Tests the Parse function."""
-    test_file = self._GetTestFilePath([
-        u'5afe4de1b92fc382.customDestinations-ms'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = custom_destinations.CustomDestinationsParser()
+    storage_writer = self._ParseFile(
+        [u'5afe4de1b92fc382.customDestinations-ms'], parser_object)
 
-    self.assertEqual(len(event_objects), 126)
+    self.assertEqual(len(storage_writer.events), 126)
 
     # A shortcut event object.
     # The last accessed timestamp.
-    event_object = event_objects[121]
+    event_object = storage_writer.events[121]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2009-07-13 23:55:56.248103')
@@ -39,7 +34,7 @@ class CustomDestinationsParserTest(test_lib.ParserTestCase):
     self.assertEqual(event_object.timestamp, expected_timestamp)
 
     # The creation timestamp.
-    event_object = event_objects[122]
+    event_object = storage_writer.events[122]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2009-07-13 23:55:56.248103')
@@ -48,7 +43,7 @@ class CustomDestinationsParserTest(test_lib.ParserTestCase):
     self.assertEqual(event_object.timestamp, expected_timestamp)
 
     # The last modification timestamp.
-    event_object = event_objects[123]
+    event_object = storage_writer.events[123]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2009-07-14 01:39:11.388000')
@@ -76,7 +71,7 @@ class CustomDestinationsParserTest(test_lib.ParserTestCase):
     self._TestGetMessageStrings(event_object, expected_msg, expected_msg_short)
 
     # A shell item event object.
-    event_object = event_objects[18]
+    event_object = storage_writer.events[18]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2010-11-10 07:41:04')
@@ -97,7 +92,7 @@ class CustomDestinationsParserTest(test_lib.ParserTestCase):
     self._TestGetMessageStrings(event_object, expected_msg, expected_msg_short)
 
     # A distributed link tracking event object.
-    event_object = event_objects[12]
+    event_object = storage_writer.events[12]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2010-11-10 19:08:32.656259')
