@@ -8,7 +8,8 @@ from dfvfs.lib import definitions as dfvfs_definitions
 from dfvfs.path import factory as path_spec_factory
 from dfvfs.resolver import resolver as path_spec_resolver
 
-from plaso.engine import single_process
+from plaso.containers import sessions
+from plaso.storage import fake_storage
 
 from tests.parsers import test_lib
 
@@ -18,11 +19,10 @@ class ParsersMediatorTest(test_lib.ParserTestCase):
 
   def testGetDisplayName(self):
     """Tests the GetDisplayName function."""
-    event_queue = single_process.SingleProcessQueue()
-    parse_error_queue = single_process.SingleProcessQueue()
-
-    parsers_mediator = self._GetParserMediator(
-        event_queue, parse_error_queue, knowledge_base_values=None)
+    session = sessions.Session()
+    storage_writer = fake_storage.FakeStorageWriter(session)
+    parsers_mediator = self._CreateParserMediator(
+        storage_writer, knowledge_base_values=None)
 
     with self.assertRaises(ValueError):
       _ = parsers_mediator.GetDisplayName(file_entry=None)
