@@ -7,7 +7,6 @@ import unittest
 from plaso.formatters import ipod as _  # pylint: disable=unused-import
 from plaso.lib import eventdata
 from plaso.lib import timelib
-from plaso.parsers import plist
 from plaso.parsers.plist_plugins import ipod
 
 from tests.parsers.plist_plugins import test_lib
@@ -16,31 +15,41 @@ from tests.parsers.plist_plugins import test_lib
 class TestIPodPlugin(test_lib.PlistPluginTestCase):
   """Tests for the iPod plist plugin."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._plugin = ipod.IPodPlugin()
-    self._parser = plist.PlistParser()
-
   def testProcess(self):
     """Tests the Process function."""
     plist_name = u'com.apple.iPod.plist'
-    event_queue_consumer = self._ParsePlistFileWithPlugin(
-        self._parser, self._plugin, [plist_name], plist_name)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
 
-    self.assertEqual(len(event_objects), 4)
+    plugin_object = ipod.IPodPlugin()
+    storage_writer = self._ParsePlistFileWithPlugin(
+        plugin_object, [plist_name], plist_name)
 
-    event_object = event_objects[1]
+    self.assertEqual(len(storage_writer.events), 4)
+
+    # The order in which PlistParser generates events is nondeterministic
+    # hence we sort the events.
+    events = self._GetSortedEvents(storage_writer.events)
+
+    event_object = events[0]
+
+    timestamp = timelib.Timestamp.CopyFromString(u'1995-11-22 18:25:07')
+    self.assertEqual(event_object.timestamp, timestamp)
+    self.assertEqual(event_object.device_id, u'0000A11300000000')
+
+    event_object = events[2]
 
     timestamp = timelib.Timestamp.CopyFromString(u'2013-10-09 19:27:54')
     self.assertEqual(event_object.timestamp, timestamp)
 
-    expected_string = (
-        u'Device ID: 4C6F6F6E65000000 Type: iPhone [10016] Connected 1 times '
-        u'Serial nr: 526F676572 IMEI [012345678901234]')
+    expected_message = (
+        u'Device ID: 4C6F6F6E65000000 '
+        u'Type: iPhone [10016] '
+        u'Connected 1 times '
+        u'Serial nr: 526F676572 '
+        u'IMEI [012345678901234]')
+    expected_message_short = u'{0:s}...'.format(expected_message[0:77])
 
     self._TestGetMessageStrings(
-        event_object, expected_string, expected_string[0:77] + '...')
+        event_object, expected_message, expected_message_short)
 
     self.assertEqual(
         event_object.timestamp_desc, eventdata.EventTimestamp.LAST_CONNECTED)
@@ -51,11 +60,6 @@ class TestIPodPlugin(test_lib.PlistPluginTestCase):
     self.assertEqual(event_object.imei, u'012345678901234')
     self.assertEqual(event_object.use_count, 1)
 
-    event_object = event_objects[3]
-    timestamp = timelib.Timestamp.CopyFromString(u'1995-11-22 18:25:07')
-    self.assertEqual(event_object.timestamp, timestamp)
-    self.assertEqual(event_object.device_id, u'0000A11300000000')
-
 
 if __name__ == '__main__':
   unittest.main()
