@@ -15,15 +15,11 @@ from tests.parsers import test_lib
 class WinEvtParserTest(test_lib.ParserTestCase):
   """Tests for the Windows EventLog (EVT) parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = winevt.WinEvtParser()
-
   def testParse(self):
     """Tests the Parse function."""
-    test_file = self._GetTestFilePath([u'SysEvent.Evt'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = winevt.WinEvtParser()
+    storage_writer = self._ParseFile(
+        [u'SysEvent.Evt'], parser_object)
 
     # Windows Event Log (EVT) information:
     #	Version                     : 1.1
@@ -31,7 +27,7 @@ class WinEvtParserTest(test_lib.ParserTestCase):
     #	Number of recovered records : 437
     #	Log type                    : System
 
-    self.assertEqual(len(event_objects), (6063 + 437) * 2)
+    self.assertEqual(len(storage_writer.events), (6063 + 437) * 2)
 
     # Event number      : 1392
     # Creation time     : Jul 27, 2011 06:41:47 UTC
@@ -46,7 +42,7 @@ class WinEvtParserTest(test_lib.ParserTestCase):
     # String: 2         : "The system detected a possible attempt to compromise
     #                     security. Please ensure that you can contact the
     #                     server that authenticated you.\r\n (0xc0000388)"
-    event_object = event_objects[1]
+    event_object = storage_writer.events[1]
     self.assertEqual(event_object.record_number, 1392)
     self.assertEqual(event_object.event_type, 2)
     self.assertEqual(event_object.computer_name, u'WKS-WINXP32BIT')
@@ -62,7 +58,7 @@ class WinEvtParserTest(test_lib.ParserTestCase):
 
     self.assertEqual(event_object.strings[1], expected_string)
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2011-07-27 06:41:47')
@@ -70,7 +66,7 @@ class WinEvtParserTest(test_lib.ParserTestCase):
     self.assertEqual(
         event_object.timestamp_desc, eventdata.EventTimestamp.CREATION_TIME)
 
-    event_object = event_objects[1]
+    event_object = storage_writer.events[1]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2011-07-27 06:41:47')
