@@ -15,15 +15,11 @@ from tests.parsers import test_lib
 class WinEvtxParserTest(test_lib.ParserTestCase):
   """Tests for the Windows XML EventLog (EVTX) parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = winevtx.WinEvtxParser()
-
   def testParse(self):
     """Tests the Parse function."""
-    test_file = self._GetTestFilePath([u'System.evtx'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = winevtx.WinEvtxParser()
+    storage_writer = self._ParseFile(
+        [u'System.evtx'], parser_object)
 
     # Windows Event Viewer Log (EVTX) information:
     #   Version                     : 3.1
@@ -31,7 +27,7 @@ class WinEvtxParserTest(test_lib.ParserTestCase):
     #   Number of recovered records : 0
     #   Log type                    : System
 
-    self.assertEqual(len(event_objects), 1601)
+    self.assertEqual(len(storage_writer.events), 1601)
 
     # Event number        : 12049
     # Written time        : Mar 14, 2012 04:17:43.354562700 UTC
@@ -45,7 +41,7 @@ class WinEvtxParserTest(test_lib.ParserTestCase):
     # String: 2           : C:\Windows\System32\Winevt\Logs\
     #                     : Archive-System-2012-03-14-04-17-39-932.evtx
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
 
     self.assertEqual(event_object.record_number, 12049)
     expected_computer_name = u'WKS-WIN764BITB.shieldbase.local'
@@ -62,7 +58,7 @@ class WinEvtxParserTest(test_lib.ParserTestCase):
 
     self.assertEqual(event_object.strings[1], expected_string)
 
-    event_object = event_objects[1]
+    event_object = storage_writer.events[1]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2012-03-14 04:17:38.276340')
@@ -120,6 +116,42 @@ class WinEvtxParserTest(test_lib.ParserTestCase):
 
     self._TestGetMessageStrings(event_object, expected_msg, expected_msg_short)
 
+    parser_object = winevtx.WinEvtxParser()
+    # Be aware of System2.evtx file, it was manually shortened so it probably
+    # contains invalid log at the end.
+    storage_writer = self._ParseFile([u'System2.evtx'], parser_object)
+
+    self.assertEqual(len(storage_writer.events), 194)
+
+    expected_strings_parsed = [
+        (u'source_user_id', u'S-1-5-18'),
+        (u'source_user_name', u'GREENDALEGOLD$'),
+        (u'target_machine_ip', u'-'),
+        (u'target_machine_name', None),
+        (u'target_user_id', u'S-1-5-18'),
+        (u'target_user_name', u'SYSTEM')]
+
+    strings_parsed = sorted(storage_writer.events[178].strings_parsed.items())
+    self.assertEqual(strings_parsed, expected_strings_parsed)
+
+    expected_event_identifier = 4624
+    event_identifier = storage_writer.events[178].event_identifier
+    self.assertEqual(event_identifier, expected_event_identifier)
+
+    expected_strings_parsed = [
+        (u'source_user_id', u'S-1-5-21-1539974973-2753941131-3212641383-1000'),
+        (u'source_user_name', u'gold_administrator'),
+        (u'target_machine_ip', u'-'),
+        (u'target_machine_name', u'DC1.internal.greendale.edu'),
+        (u'target_user_name', u'administrator')]
+
+    strings_parsed = sorted(storage_writer.events[180].strings_parsed.items())
+    self.assertEqual(strings_parsed, expected_strings_parsed)
+
+    expected_event_identifier = 4648
+    event_identifier = storage_writer.events[180].event_identifier
+    self.assertEqual(event_identifier, expected_event_identifier)
+
 
 if __name__ == '__main__':
   unittest.main()
