@@ -15,28 +15,26 @@ from tests.parsers import test_lib
 class WinJobTest(test_lib.ParserTestCase):
   """Tests for the Windows Scheduled Task job file parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = winjob.WinJobParser()
-
   def testParse(self):
     """Tests the Parse function."""
-    test_file = self._GetTestFilePath([u'wintask.job'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = winjob.WinJobParser()
+    storage_writer = self._ParseFile([u'wintask.job'], parser_object)
 
-    self.assertEqual(len(event_objects), 2)
+    self.assertEqual(len(storage_writer.events), 2)
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
+
+    expected_timestamp = timelib.Timestamp.CopyFromString(
+        u'2013-08-24 12:42:00.112')
+    self.assertEqual(event_object.timestamp, expected_timestamp)
+    self.assertEqual(
+        event_object.timestamp_desc, eventdata.EventTimestamp.LAST_RUNTIME)
 
     expected_application = (
         u'C:\\Program Files (x86)\\Google\\Update\\GoogleUpdate.exe')
     self.assertEqual(event_object.application, expected_application)
 
     self.assertEqual(event_object.username, u'Brian')
-    self.assertEqual(
-        event_object.timestamp_desc, eventdata.EventTimestamp.LAST_RUNTIME)
-    self.assertEqual(event_object.trigger, 1)
 
     expected_comment = (
         u'Keeps your Google software up to date. If this task is disabled or '
@@ -46,23 +44,20 @@ class WinJobTest(test_lib.ParserTestCase):
         u'no Google software using it.')
     self.assertEqual(event_object.comment, expected_comment)
 
-    expected_timestamp = timelib.Timestamp.CopyFromString(
-        u'2013-08-24 12:42:00.112')
-    self.assertEqual(event_object.timestamp, expected_timestamp)
-
     # Parse second event. Same metadata; different timestamp event.
-    event_object = event_objects[1]
-
-    self.assertEqual(event_object.timestamp_desc, u'Scheduled To Start')
+    event_object = storage_writer.events[1]
 
     expected_timestamp = timelib.Timestamp.CopyFromString(
         u'2013-07-12 15:42:00')
     self.assertEqual(event_object.timestamp, expected_timestamp)
+    self.assertEqual(event_object.timestamp_desc, u'Scheduled to start')
+
+    self.assertEqual(event_object.trigger_type, 1)
 
     expected_message = (
         u'Application: {0:s} /ua /installsource scheduler '
         u'Scheduled by: Brian '
-        u'Run Iteration: DAILY').format(expected_application)
+        u'Trigger type: DAILY').format(expected_application)
 
     expected_short_message = (
         u'Application: {0:s} /ua /insta...').format(expected_application)
