@@ -5,16 +5,16 @@
 import unittest
 
 from plaso.parsers import winreg
+# Register all plugins.
+from plaso.parsers import winreg_plugins  # pylint: disable=unused-import
 
 from tests.parsers import test_lib
 
 
-class WinRegTest(test_lib.ParserTestCase):
+class WinRegistryParserTest(test_lib.ParserTestCase):
   """Tests for the Windows Registry file parser."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._parser = winreg.WinRegistryParser()
+  # pylint: disable=protected-access
 
   def _GetParserChains(self, event_objects):
     """Return a dict with a plugin count given a list of event objects."""
@@ -35,13 +35,23 @@ class WinRegTest(test_lib.ParserTestCase):
     """Generate the correct parser chain for a given plugin."""
     return u'winreg/{0:s}'.format(plugin_name)
 
+  def testEnablePlugins(self):
+    """Tests the EnablePlugins function."""
+    parser_object = winreg.WinRegistryParser()
+    parser_object.EnablePlugins([u'appcompatcache'])
+
+    self.assertIsNotNone(parser_object)
+    self.assertIsNotNone(parser_object._default_plugin)
+    self.assertNotEqual(parser_object._plugin_objects, [])
+    self.assertEqual(len(parser_object._plugin_objects), 1)
+
   def testParseNTUserDat(self):
     """Tests the Parse function on a NTUSER.DAT file."""
-    test_file = self._GetTestFilePath([u'NTUSER.DAT'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = winreg.WinRegistryParser()
+    storage_writer = self._ParseFile(
+        [u'NTUSER.DAT'], parser_object)
 
-    parser_chains = self._GetParserChains(event_objects)
+    parser_chains = self._GetParserChains(storage_writer.events)
 
     expected_parser_chain = self._PluginNameToParserChain(u'userassist')
     self.assertTrue(expected_parser_chain in parser_chains)
@@ -50,19 +60,19 @@ class WinRegTest(test_lib.ParserTestCase):
 
   def testParseNoRootKey(self):
     """Test the parse function on a Registry file with no root key."""
-    test_file = self._GetTestFilePath([u'ntuser.dat.LOG'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = winreg.WinRegistryParser()
+    storage_writer = self._ParseFile(
+        [u'ntuser.dat.LOG'], parser_object)
 
-    self.assertEqual(len(event_objects), 0)
+    self.assertEqual(len(storage_writer.events), 0)
 
   def testParseSystem(self):
     """Tests the Parse function on a SYSTEM file."""
-    test_file = self._GetTestFilePath([u'SYSTEM'])
-    event_queue_consumer = self._ParseFile(self._parser, test_file)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    parser_object = winreg.WinRegistryParser()
+    storage_writer = self._ParseFile(
+        [u'SYSTEM'], parser_object)
 
-    parser_chains = self._GetParserChains(event_objects)
+    parser_chains = self._GetParserChains(storage_writer.events)
 
     # Check the existence of few known plugins, see if they
     # are being properly picked up and are parsed.
@@ -77,7 +87,7 @@ class WinRegTest(test_lib.ParserTestCase):
 
     # Check that the number of events produced by each plugin are correct.
     parser_chain = self._PluginNameToParserChain(u'windows_usbstor_devices')
-    self.assertEqual(parser_chains.get(parser_chain, 0), 7)
+    self.assertEqual(parser_chains.get(parser_chain, 0), 10)
 
     parser_chain = self._PluginNameToParserChain(u'windows_boot_execute')
     self.assertEqual(parser_chains.get(parser_chain, 0), 4)
