@@ -4,8 +4,10 @@
 
 import unittest
 
-from plaso.dfwinreg import definitions as dfwinreg_definitions
-from plaso.dfwinreg import fake as dfwinreg_fake
+from dfdatetime import filetime as dfdatetime_filetime
+from dfwinreg import definitions as dfwinreg_definitions
+from dfwinreg import fake as dfwinreg_fake
+
 from plaso.formatters import winreg as _  # pylint: disable=unused-import
 from plaso.lib import timelib
 from plaso.parsers.winreg_plugins import outlook
@@ -16,10 +18,6 @@ from tests.parsers.winreg_plugins import test_lib
 class MSOutlook2013SearchMRUPluginTest(test_lib.RegistryPluginTestCase):
   """Tests for the Outlook Search MRU Windows Registry plugin."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._plugin = outlook.OutlookSearchMRUPlugin()
-
   def _CreateTestKey(self, key_path, time_string):
     """Creates Registry keys and values for testing.
 
@@ -30,7 +28,7 @@ class MSOutlook2013SearchMRUPluginTest(test_lib.RegistryPluginTestCase):
     Returns:
       A Windows Registry key (instance of dfwinreg.WinRegistryKey).
     """
-    filetime = dfwinreg_fake.Filetime()
+    filetime = dfdatetime_filetime.Filetime()
     filetime.CopyFromString(time_string)
     registry_key = dfwinreg_fake.FakeWinRegistryKey(
         u'Search', key_path=key_path, last_written_time=filetime.timestamp,
@@ -55,16 +53,16 @@ class MSOutlook2013SearchMRUPluginTest(test_lib.RegistryPluginTestCase):
     time_string = u'2012-08-28 09:23:49.002031'
     registry_key = self._CreateTestKey(key_path, time_string)
 
-    event_queue_consumer = self._ParseKeyWithPlugin(self._plugin, registry_key)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    plugin_object = outlook.OutlookSearchMRUPlugin()
+    storage_writer = self._ParseKeyWithPlugin(registry_key, plugin_object)
 
-    self.assertEqual(len(event_objects), 1)
+    self.assertEqual(len(storage_writer.events), 1)
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
 
     # This should just be the plugin name, as we're invoking it directly,
     # and not through the parser.
-    self.assertEqual(event_object.parser, self._plugin.plugin_name)
+    self.assertEqual(event_object.parser, plugin_object.plugin_name)
 
     expected_timestamp = timelib.Timestamp.CopyFromString(time_string)
     self.assertEqual(event_object.timestamp, expected_timestamp)
@@ -87,10 +85,6 @@ class MSOutlook2013SearchMRUPluginTest(test_lib.RegistryPluginTestCase):
 # class MSOutlook2013SearchCatalogMRUPluginTest(unittest.TestCase):
 #   """Tests for the Outlook Search Catalog MRU Windows Registry plugin."""
 #
-#   def setUp(self):
-#     """Makes preparations before running an individual test."""
-#     self._plugin = outlook.MSOutlook2013SearchCatalogMRUPlugin()
-#
 #   def testProcess(self):
 #     """Tests the Process function."""
 #     key_path = (
@@ -98,7 +92,7 @@ class MSOutlook2013SearchMRUPluginTest(test_lib.RegistryPluginTestCase):
 #         u'Search\\Catalog')
 #     time_string = u'2012-08-28 09:23:49.002031'
 #
-#     filetime = dfwinreg_fake.Filetime()
+#     filetime = dfdatetime_filetime.Filetime()
 #     filetime.CopyFromString(time_string)
 #     registry_key = dfwinreg_fake.FakeWinRegistryKey(
 #         u'Catalog', key_path=key_path, last_written_time=filetime.timestamp,
@@ -113,6 +107,8 @@ class MSOutlook2013SearchMRUPluginTest(test_lib.RegistryPluginTestCase):
 #         data_type=dfwinreg_definitions.REG_BINARY, offset=827)
 #     registry_key.AddValue(registry_value)
 #
+#     plugin_object = outlook.MSOutlook2013SearchCatalogMRUPlugin()
+#
 #     # TODO: add test for Catalog key.
 
 
