@@ -4,7 +4,8 @@
 
 import unittest
 
-from plaso.formatters import winreg as _  # pylint: disable=unused-import
+from plaso.formatters import shutdown as _  # pylint: disable=unused-import
+from plaso.lib import eventdata
 from plaso.lib import timelib
 from plaso.parsers.winreg_plugins import shutdown
 
@@ -17,10 +18,6 @@ __author__ = 'Preston Miller, dpmforensics.com, github.com/prmiller91'
 class ShutdownPluginTest(test_lib.RegistryPluginTestCase):
   """Tests for the LastShutdown value plugin."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._plugin = shutdown.ShutdownPlugin()
-
   def testProcess(self):
     """Tests the Process function."""
     test_file_entry = self._GetTestFileEntryFromPath([u'SYSTEM'])
@@ -28,31 +25,33 @@ class ShutdownPluginTest(test_lib.RegistryPluginTestCase):
 
     win_registry = self._GetWinRegistryFromFileEntry(test_file_entry)
     registry_key = win_registry.GetKeyByPath(key_path)
-    event_queue_consumer = self._ParseKeyWithPlugin(
-        self._plugin, registry_key, file_entry=test_file_entry)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
 
-    self.assertEqual(len(event_objects), 1)
+    plugin_object = shutdown.ShutdownPlugin()
+    storage_writer = self._ParseKeyWithPlugin(
+        registry_key, plugin_object, file_entry=test_file_entry)
 
-    event_object = event_objects[0]
+    self.assertEqual(len(storage_writer.events), 1)
+
+    event_object = storage_writer.events[0]
 
     self.assertEqual(event_object.pathspec, test_file_entry.path_spec)
     # This should just be the plugin name, as we're invoking it directly,
     # and not through the parser.
-    self.assertEqual(event_object.parser, self._plugin.plugin_name)
+    self.assertEqual(event_object.parser, plugin_object.plugin_name)
 
-    expected_value = u'ShutdownTime'
-    self._TestRegvalue(event_object, u'Description', expected_value)
+    self.assertEqual(event_object.value_name, u'ShutdownTime')
 
     # Match UTC timestamp.
-    time = long(timelib.Timestamp.CopyFromString(
-        u'2012-04-04 01:58:40.839249'))
-    self.assertEqual(event_object.timestamp, time)
+    expected_timestamp = timelib.Timestamp.CopyFromString(
+        u'2012-04-04 01:58:40.839249')
+    self.assertEqual(event_object.timestamp, expected_timestamp)
+    self.assertEqual(
+        event_object.timestamp_desc, eventdata.EventTimestamp.LAST_SHUTDOWN)
 
     expected_message = (
         u'[{0:s}] '
         u'Description: ShutdownTime').format(key_path)
-    expected_short_message = u'{0:s}...'.format(expected_message[0:77])
+    expected_short_message = u'ShutdownTime'
 
     self._TestGetMessageStrings(
         event_object, expected_message, expected_short_message)
