@@ -4,8 +4,10 @@
 
 import unittest
 
-from plaso.dfwinreg import definitions as dfwinreg_definitions
-from plaso.dfwinreg import fake as dfwinreg_fake
+from dfdatetime import filetime as dfdatetime_filetime
+from dfwinreg import definitions as dfwinreg_definitions
+from dfwinreg import fake as dfwinreg_fake
+
 from plaso.formatters import winreg as _  # pylint: disable=unused-import
 from plaso.lib import timelib
 from plaso.parsers.winreg_plugins import terminal_server
@@ -16,10 +18,6 @@ from tests.parsers.winreg_plugins import test_lib
 class ServersTerminalServerClientPluginTest(test_lib.RegistryPluginTestCase):
   """Tests for the Terminal Server Client Windows Registry plugin."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._plugin = terminal_server.TerminalServerClientPlugin()
-
   def _CreateTestKey(self, key_path, time_string):
     """Creates Registry keys and values for testing.
 
@@ -30,7 +28,7 @@ class ServersTerminalServerClientPluginTest(test_lib.RegistryPluginTestCase):
     Returns:
       A Windows Registry key (instance of dfwinreg.WinRegistryKey).
     """
-    filetime = dfwinreg_fake.Filetime()
+    filetime = dfdatetime_filetime.Filetime()
     filetime.CopyFromString(time_string)
     registry_key = dfwinreg_fake.FakeWinRegistryKey(
         u'Servers', key_path=key_path, last_written_time=filetime.timestamp,
@@ -57,16 +55,16 @@ class ServersTerminalServerClientPluginTest(test_lib.RegistryPluginTestCase):
     time_string = u'2012-08-28 09:23:49.002031'
     registry_key = self._CreateTestKey(key_path, time_string)
 
-    event_queue_consumer = self._ParseKeyWithPlugin(self._plugin, registry_key)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    plugin_object = terminal_server.TerminalServerClientPlugin()
+    storage_writer = self._ParseKeyWithPlugin(registry_key, plugin_object)
 
-    self.assertEqual(len(event_objects), 2)
+    self.assertEqual(len(storage_writer.events), 2)
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
 
     # This should just be the plugin name, as we're invoking it directly,
     # and not through the parser.
-    self.assertEqual(event_object.parser, self._plugin.plugin_name)
+    self.assertEqual(event_object.parser, plugin_object.plugin_name)
 
     expected_timestamp = timelib.Timestamp.CopyFromString(time_string)
     self.assertEqual(event_object.timestamp, expected_timestamp)
@@ -79,7 +77,7 @@ class ServersTerminalServerClientPluginTest(test_lib.RegistryPluginTestCase):
     self._TestGetMessageStrings(
         event_object, expected_message, expected_short_message)
 
-    event_object = event_objects[1]
+    event_object = storage_writer.events[1]
 
     expected_message = (
         u'[{0:s}] '
@@ -93,10 +91,6 @@ class ServersTerminalServerClientPluginTest(test_lib.RegistryPluginTestCase):
 class DefaultTerminalServerClientMRUPluginTest(test_lib.RegistryPluginTestCase):
   """Tests for the Terminal Server Client MRU Windows Registry plugin."""
 
-  def setUp(self):
-    """Makes preparations before running an individual test."""
-    self._plugin = terminal_server.TerminalServerClientMRUPlugin()
-
   def _CreateTestKey(self, key_path, time_string):
     """Creates Registry keys and values for testing.
 
@@ -107,7 +101,7 @@ class DefaultTerminalServerClientMRUPluginTest(test_lib.RegistryPluginTestCase):
     Returns:
       A Windows Registry key (instance of dfwinreg.WinRegistryKey).
     """
-    filetime = dfwinreg_fake.Filetime()
+    filetime = dfdatetime_filetime.Filetime()
     filetime.CopyFromString(time_string)
     registry_key = dfwinreg_fake.FakeWinRegistryKey(
         u'Default', key_path=key_path, last_written_time=filetime.timestamp,
@@ -135,16 +129,16 @@ class DefaultTerminalServerClientMRUPluginTest(test_lib.RegistryPluginTestCase):
     time_string = u'2012-08-28 09:23:49.002031'
     registry_key = self._CreateTestKey(key_path, time_string)
 
-    event_queue_consumer = self._ParseKeyWithPlugin(self._plugin, registry_key)
-    event_objects = self._GetEventObjectsFromQueue(event_queue_consumer)
+    plugin_object = terminal_server.TerminalServerClientMRUPlugin()
+    storage_writer = self._ParseKeyWithPlugin(registry_key, plugin_object)
 
-    self.assertEqual(len(event_objects), 1)
+    self.assertEqual(len(storage_writer.events), 1)
 
-    event_object = event_objects[0]
+    event_object = storage_writer.events[0]
 
     # This should just be the plugin name, as we're invoking it directly,
     # and not through the parser.
-    self.assertEqual(event_object.parser, self._plugin.plugin_name)
+    self.assertEqual(event_object.parser, plugin_object.plugin_name)
 
     expected_timestamp = timelib.Timestamp.CopyFromString(time_string)
     self.assertEqual(event_object.timestamp, expected_timestamp)
