@@ -4,6 +4,7 @@
 
 import unittest
 
+from dfvfs.helpers import fake_file_system_builder
 from dfvfs.helpers import file_system_searcher
 from dfvfs.path import fake_path_spec
 
@@ -11,17 +12,16 @@ from plaso.engine import knowledge_base
 from plaso.preprocessors import linux
 
 from tests import test_lib as shared_test_lib
-from tests.preprocessors import test_lib
 
 
-class LinuxHostnameTest(test_lib.PreprocessPluginTest):
+class LinuxHostnameTest(shared_test_lib.BaseTestCase):
   """Tests for the Linux hostname preprocess plug-in object."""
 
   _FILE_DATA = 'plaso.kiddaland.net\n'
 
   def setUp(self):
     """Makes preparations before running an individual test."""
-    file_system_builder = shared_test_lib.FakeFileSystemBuilder()
+    file_system_builder = fake_file_system_builder.FakeFileSystemBuilder()
     file_system_builder.AddFile(u'/etc/hostname', self._FILE_DATA)
 
     mount_point = fake_path_spec.FakePathSpec(location=u'/')
@@ -38,9 +38,36 @@ class LinuxHostnameTest(test_lib.PreprocessPluginTest):
     self.assertEqual(knowledge_base_object.hostname, u'plaso.kiddaland.net')
 
 
-class LinuxUsernamesTest(test_lib.PreprocessPluginTest):
+class LinuxTimezoneTest(shared_test_lib.BaseTestCase):
+  """Test for the Linux timezone preprocess plug-in object."""
+
+  _FILE_DATA = 'Europe/Zurich\n'
+
+  def setUp(self):
+    """Makes preparations before running an individual test."""
+    file_system_builder = fake_file_system_builder.FakeFileSystemBuilder()
+    file_system_builder.AddFile(u'/etc/timezone', self._FILE_DATA)
+
+    mount_point = fake_path_spec.FakePathSpec(location=u'/')
+    self._searcher = file_system_searcher.FileSystemSearcher(
+        file_system_builder.file_system, mount_point)
+
+  def testGetValue(self):
+    """Test the GetValue function."""
+    knowledge_base_object = knowledge_base.KnowledgeBase()
+
+    plugin = linux.LinuxTimezone()
+    plugin.Run(self._searcher, knowledge_base_object)
+
+    time_zone_str = knowledge_base_object.GetValue(u'time_zone_str')
+    self.assertEqual(time_zone_str, u'Europe/Zurich')
+
+
+class LinuxUsernamesTest(shared_test_lib.BaseTestCase):
   """Tests for the Linux usernames preprocess plug-in object."""
 
+  # pylint: disable=protected-access
+
   _FILE_DATA = (
       'root:x:0:0:root:/root:/bin/bash\n'
       'bin:x:1:1:bin:/bin:/sbin/nologin\n'
@@ -58,7 +85,7 @@ class LinuxUsernamesTest(test_lib.PreprocessPluginTest):
 
   def setUp(self):
     """Makes preparations before running an individual test."""
-    file_system_builder = shared_test_lib.FakeFileSystemBuilder()
+    file_system_builder = fake_file_system_builder.FakeFileSystemBuilder()
     file_system_builder.AddFile(u'/etc/passwd', self._FILE_DATA)
 
     mount_point = fake_path_spec.FakePathSpec(location=u'/')
@@ -72,14 +99,18 @@ class LinuxUsernamesTest(test_lib.PreprocessPluginTest):
     plugin = linux.LinuxUsernames()
     plugin.Run(self._searcher, knowledge_base_object)
 
-    users = knowledge_base_object.GetValue('users')
+    users = sorted(
+        knowledge_base_object._user_accounts[0].values(),
+        key=lambda user_account: user_account.identifier)
     self.assertEqual(len(users), 13)
 
-    self.assertEqual(users[11].get('uid', None), u'14')
-    self.assertEqual(users[11].get('gid', None), u'50')
-    self.assertEqual(users[11].get('name', None), u'ftp')
-    self.assertEqual(users[11].get('path', None), u'/var/ftp')
-    self.assertEqual(users[11].get('shell', None), u'/sbin/nologin')
+    user_account = users[4]
+
+    self.assertEqual(user_account.identifier, u'14')
+    self.assertEqual(user_account.group_identifier, u'50')
+    self.assertEqual(user_account.user_directory, u'/var/ftp')
+    self.assertEqual(user_account.username, u'ftp')
+    self.assertEqual(user_account.shell, u'/sbin/nologin')
 
 
 if __name__ == '__main__':
