@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-"""The log2timeline front-end."""
+"""The log2timeline command line tool."""
 
 import argparse
 import logging
@@ -10,7 +10,6 @@ import time
 import textwrap
 
 try:
-  import win32api
   import win32console
 except ImportError:
   win32console = None
@@ -32,30 +31,32 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
   """Class that implements the log2timeline CLI tool.
 
   Attributes:
-    dependencies_check: a boolean value to indicate the availability and
-                        versions of dependencies should be checked.
-    list_output_modules: a boolean value to indicate information about the
-                         output modules should be shows.
-    show_info: a boolean value to indicate information about hashers, parsers,
-               plugins, etc. should be shown.
+    dependencies_check (bool): True if the availability and versions of
+        dependencies should be checked.
+    list_output_modules (bool): True if information about the output modules
+        should be shown.
+    show_info (bool): True if information about hashers, parsers, plugins,
+        etc. should be shown.
   """
 
   NAME = u'log2timeline'
   DESCRIPTION = textwrap.dedent(u'\n'.join([
       u'',
-      u'log2timeline is the main front-end to the plaso back-end, used to',
-      u'collect and correlate events extracted from a filesystem.',
+      (u'log2timeline is a command line tool to extract events from '
+       u'individual '),
+      u'files, recursing a directory (e.g. mount point) or storage media ',
+      u'image or device.',
       u'',
       u'More information can be gathered from here:',
-      u'    http://plaso.kiddaland.net/usage/log2timeline',
+      u'    https://github.com/log2timeline/plaso/wiki/Using-log2timeline',
       u'']))
 
   EPILOG = textwrap.dedent(u'\n'.join([
       u'',
       u'Example usage:',
       u'',
-      u'Run the tool against an image (full kitchen sink)',
-      u'    log2timeline.py /cases/mycase/plaso.plaso ímynd.dd',
+      u'Run the tool against a storage media image (full kitchen sink)',
+      u'    log2timeline.py /cases/mycase/storage.plaso ímynd.dd',
       u'',
       u'Instead of answering questions, indicate some of the options on the',
       u'command line (including data from particular VSS stores).',
@@ -69,12 +70,10 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Initializes the CLI tool object.
 
     Args:
-      input_reader: the input reader (instance of InputReader).
-                    The default is None which indicates the use of the stdin
-                    input reader.
-      output_writer: the output writer (instance of OutputWriter).
-                     The default is None which indicates the use of the stdout
-                     output writer.
+      input_reader (Optional[InputReader]): input reader, where None indicates
+          that the stdin input reader should be used.
+      output_writer (Optional[OutputWriter]): output writer, where None
+          indicates that the stdout output writer should be used.
     """
     super(Log2TimelineTool, self).__init__(
         input_reader=input_reader, output_writer=output_writer)
@@ -83,87 +82,65 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     self._filter_expression = None
     self._foreman_verbose = False
     self._front_end = log2timeline.Log2TimelineFrontend()
-    self._stdout_output_writer = isinstance(
-        self._output_writer, cli_tools.StdoutOutputWriter)
+    self._number_of_extraction_workers = 0
+    self._output = None
     self._source_type = None
     self._source_type_string = u'UNKNOWN'
     self._status_view_mode = u'linear'
-    self._output = None
+    self._stdout_output_writer = isinstance(
+        self._output_writer, cli_tools.StdoutOutputWriter)
 
     self.dependencies_check = True
     self.list_output_modules = False
     self.show_info = False
 
-  def _ClearScreen(self):
-    """Clears the terminal/console screen."""
-    if not win32console:
-      # ANSI escape sequence to clear screen.
-      self._output_writer.Write(b'\033[2J')
-      # ANSI escape sequence to move cursor to top left.
-      self._output_writer.Write(b'\033[H')
-
-    else:
-      # Windows cmd.exe does not support ANSI escape codes, thus instead we
-      # fill the console screen buffer with spaces.
-      top_left_coordinate = win32console.PyCOORDType(0, 0)
-      screen_buffer = win32console.GetStdHandle(win32api.STD_OUTPUT_HANDLE)
-      screen_buffer_information = screen_buffer.GetConsoleScreenBufferInfo()
-
-      screen_buffer_attributes = screen_buffer_information[u'Attributes']
-      screen_buffer_size = screen_buffer_information[u'Size']
-      console_size = screen_buffer_size.X * screen_buffer_size.Y
-
-      screen_buffer.FillConsoleOutputCharacter(
-          u' ', console_size, top_left_coordinate)
-      screen_buffer.FillConsoleOutputAttribute(
-          screen_buffer_attributes, console_size, top_left_coordinate)
-      screen_buffer.SetConsoleCursorPosition(top_left_coordinate)
-
-  def _FormatStatusTableRow(
-      self, identifier, pid, status, process_status, number_of_events,
-      number_of_events_delta, display_name):
+  def _FormatStatusTableRow(self, process_status):
     """Formats a status table row.
 
     Args:
-      identifier: identifier to describe the status table entry.
-      pid: the process identifier (PID).
-      status: the process status string.
-      process_status: string containing the process status.
-      number_of_events: the total number of events.
-      number_of_events_delta: the number of events since the last status update.
-      display_name: the display name of the file last processed.
+      process_status (ProcessStatus): processing status.
     """
-    if (process_status and number_of_events_delta == 0 and
-        status in [definitions.PROCESSING_STATUS_RUNNING,
-                   definitions.PROCESSING_STATUS_HASHING,
-                   definitions.PROCESSING_STATUS_PARSING]):
-      status = process_status
-
     # This check makes sure the columns are tab aligned.
+    identifier = process_status.identifier
     if len(identifier) < 8:
       identifier = u'{0:s}\t'.format(identifier)
 
+    status = process_status.status
     if len(status) < 8:
       status = u'{0:s}\t'.format(status)
 
-    if number_of_events is None or number_of_events_delta is None:
-      events = u''
-    else:
-      events = u'{0:d} ({1:d})'.format(number_of_events, number_of_events_delta)
+    sources = u''
+    if (process_status.number_of_produced_sources is not None and
+        process_status.number_of_produced_sources_delta is not None):
+      sources = u'{0:d} ({1:d})'.format(
+          process_status.number_of_produced_sources,
+          process_status.number_of_produced_sources_delta)
 
-      # This check makes sure the columns are tab aligned.
-      if len(events) < 8:
-        events = u'{0:s}\t'.format(events)
+    # This check makes sure the columns are tab aligned.
+    if len(sources) < 8:
+      sources = u'{0:s}\t'.format(sources)
+
+    events = u''
+    if (process_status.number_of_produced_events is not None and
+        process_status.number_of_produced_events_delta is not None):
+      events = u'{0:d} ({1:d})'.format(
+          process_status.number_of_produced_events,
+          process_status.number_of_produced_events_delta)
+
+    # This check makes sure the columns are tab aligned.
+    if len(events) < 8:
+      events = u'{0:s}\t'.format(events)
 
     # TODO: shorten display name to fit in 80 chars and show the filename.
-    return u'{0:s}\t{1:d}\t{2:s}\t{3:s}\t{4:s}'.format(
-        identifier, pid, status, events, display_name)
+    return u'{0:s}\t{1:d}\t{2:s}\t{3:s}\t{4:s}\t{5:s}'.format(
+        identifier, process_status.pid, status, sources, events,
+        process_status.display_name)
 
   def _GetMatcher(self, filter_expression):
     """Retrieves a filter object for a specific filter expression.
 
     Args:
-      filter_expression: string that contains the filter expression.
+      filter_expression (str): filter expression.
 
     Returns:
       A filter object (instance of objectfilter.TODO) or None.
@@ -177,21 +154,11 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
           u'Unable to create filter: {0:s} with error: {1:s}'.format(
               filter_expression, exception))
 
-  def _ParseExperimentalOptions(self, options):
-    """Parses the experimental plugin options.
-
-    Args:
-      options: the command line arguments (instance of argparse.Namespace).
-    """
-    use_zeromq = getattr(options, u'use_zeromq', False)
-    if use_zeromq:
-      self._front_end.SetUseZeroMQ(use_zeromq)
-
   def _ParseOutputOptions(self, options):
     """Parses the output options.
 
     Args:
-      options: the command line arguments (instance of argparse.Namespace).
+      options (argparse.Namespace): command line arguments.
 
     Raises:
       BadConfigOption: if the options are invalid.
@@ -208,7 +175,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Parses the processing options.
 
     Args:
-      options: the command line arguments (instance of argparse.Namespace).
+      options (argparse.Namespace): command line arguments.
 
     Raises:
       BadConfigOption: if the options are invalid.
@@ -217,6 +184,9 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
 
     self._foreman_verbose = getattr(options, u'foreman_verbose', False)
 
+    use_zeromq = getattr(options, u'use_zeromq', True)
+    self._front_end.SetUseZeroMQ(use_zeromq)
+
     self._number_of_extraction_workers = getattr(options, u'workers', 0)
 
     # TODO: add code to parse the worker options.
@@ -238,7 +208,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Prints the processing status.
 
     Args:
-      processing_status: the processing status (instance of ProcessingStatus).
+      processing_status (ProcessingStatus): processing status.
     """
     if self._stdout_output_writer:
       self._ClearScreen()
@@ -252,50 +222,26 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
 
     # TODO: for win32console get current color and set intensity,
     # write the header separately then reset intensity.
-    status_header = u'Identifier\tPID\tStatus\t\tEvents\t\tFile'
+    status_header = u'Identifier\tPID\tStatus\t\tSources\t\tEvents\t\tFile'
     if not win32console:
       status_header = u'\x1b[1m{0:s}\x1b[0m'.format(status_header)
 
     status_table = [status_header]
 
-    status_row = self._FormatStatusTableRow(
-        processing_status.collector.identifier, processing_status.collector.pid,
-        processing_status.collector.status,
-        processing_status.collector.process_status, None, None, u'')
-
+    status_row = self._FormatStatusTableRow(processing_status.foreman_status)
     status_table.append(status_row)
 
-    for extraction_worker_status in processing_status.extraction_workers:
-      status_row = self._FormatStatusTableRow(
-          extraction_worker_status.identifier,
-          extraction_worker_status.pid,
-          extraction_worker_status.status,
-          extraction_worker_status.process_status,
-          extraction_worker_status.number_of_events,
-          extraction_worker_status.number_of_events_delta,
-          extraction_worker_status.display_name)
-
+    for worker_status in processing_status.workers_status:
+      status_row = self._FormatStatusTableRow(worker_status)
       status_table.append(status_row)
 
-    if processing_status.storage_writer:
-      status_row = self._FormatStatusTableRow(
-          processing_status.storage_writer.identifier,
-          processing_status.storage_writer.pid,
-          processing_status.storage_writer.status,
-          processing_status.storage_writer.process_status,
-          processing_status.storage_writer.number_of_events,
-          processing_status.storage_writer.number_of_events_delta, u'')
-
-    status_table.append(status_row)
-
     status_table.append(u'')
     self._output_writer.Write(u'\n'.join(status_table))
     self._output_writer.Write(u'\n')
 
-    if processing_status.GetExtractionCompleted():
+    if processing_status.aborted:
       self._output_writer.Write(
-          u'All extraction workers completed - waiting for storage.\n')
-      self._output_writer.Write(u'\n')
+          u'Processing aborted - waiting for clean up.\n\n')
 
     # TODO: remove update flicker. For win32console we could set the cursor
     # top left, write the table, clean the remainder of the screen buffer
@@ -308,44 +254,23 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Prints the processing status as a stream of output.
 
     Args:
-      processing_status: the processing status (instance of ProcessingStatus).
+      processing_status (ProcessingStatus): processing status.
     """
-    if processing_status.GetExtractionCompleted():
-      self._output_writer.Write(
-          u'All extraction workers completed - waiting for storage.\n')
-
-    else:
-      for extraction_worker_status in processing_status.extraction_workers:
-        status = extraction_worker_status.status
-        self._output_writer.Write((
-            u'{0:s} (PID: {1:d}) - events extracted: {2:d} - file: {3:s} '
-            u'- running: {4!s} <{5:s}>\n').format(
-                extraction_worker_status.identifier,
-                extraction_worker_status.pid,
-                extraction_worker_status.number_of_events,
-                extraction_worker_status.display_name,
-                status in [definitions.PROCESSING_STATUS_RUNNING,
-                           definitions.PROCESSING_STATUS_HASHING,
-                           definitions.PROCESSING_STATUS_PARSING],
-                extraction_worker_status.process_status))
-
-  def AddExperimentalOptions(self, argument_group):
-    """Adds experimental options to the argument group
-
-    Args:
-      argument_group: The argparse argument group (instance of
-                      argparse._ArgumentGroup).
-    """
-    argument_group.add_argument(
-        u'--use_zeromq', action=u'store_true', dest=u'use_zeromq', help=(
-            u'Enables experimental queueing using ZeroMQ'))
+    for worker_status in processing_status.workers_status:
+      status_line = (
+          u'{0:s} (PID: {1:d}) - events produced: {2:d} - file: {3:s} '
+          u'- running: {4!s}\n').format(
+              worker_status.identifier, worker_status.pid,
+              worker_status.number_of_produced_events,
+              worker_status.display_name,
+              worker_status.status not in definitions.PROCESSING_ERROR_STATUS)
+      self._output_writer.Write(status_line)
 
   def AddOutputOptions(self, argument_group):
     """Adds the output options to the argument group.
 
     Args:
-      argument_group: The argparse argument group (instance of
-                      argparse._ArgumentGroup).
+      argument_group (argparse._ArgumentGroup): argparse argument group.
     """
     argument_group.add_argument(
         u'--output', dest=u'output_module', action=u'store', type=str,
@@ -368,8 +293,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Adds the processing options to the argument group.
 
     Args:
-      argument_group: The argparse argument group (instance of
-                      argparse._ArgumentGroup).
+      argument_group (argparse._ArgumentGroup): argparse argument group.
     """
     argument_group.add_argument(
         u'--single_process', u'--single-process', dest=u'single_process',
@@ -383,10 +307,16 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
             u'output of the process monitor. If this option is not set the '
             u'tool only displays basic status and counter information.'))
 
+    argument_group.add_argument(
+        u'--disable_zeromq', u'--disable-zeromq', action=u'store_false',
+        dest=u'use_zeromq', default=True, help=(
+            u'Disable queueing using ZeroMQ. A Multiprocessing queue will be '
+            u'used instead.'))
+
     argument_group.add_argument(
         u'--workers', dest=u'workers', action=u'store', type=int, default=0,
         help=(u'The number of worker threads [defaults to available system '
-              u'CPUs minus three].'))
+              u'CPUs minus one].'))
 
   def ListHashers(self):
     """Lists information about the available hashers."""
@@ -434,7 +364,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
 
     for parser_name in self._front_end.GetNamesOfParsersWithPlugins():
       plugins_information = self._front_end.GetParserPluginsInformation(
-          parser_filter_string=parser_name)
+          parser_filter_expression=parser_name)
 
       table_title = u'Parser plugins: {0:s}'.format(parser_name)
       table_view = cli_views.ViewsFactory.GetTableView(
@@ -457,7 +387,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Parses the command line arguments.
 
     Returns:
-      A boolean value indicating the arguments were successfully parsed.
+      bool: True if the arguments were successfully parsed.
     """
     self._ConfigureLogging()
 
@@ -467,9 +397,6 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
 
     self.AddBasicOptions(argument_parser)
 
-    experimental_group = argument_parser.add_argument_group(u'Experimental')
-    self.AddExperimentalOptions(experimental_group)
-
     extraction_group = argument_parser.add_argument_group(
         u'Extraction Arguments')
 
@@ -517,7 +444,6 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     output_group = argument_parser.add_argument_group(u'Output Arguments')
 
     self.AddOutputOptions(output_group)
-    self.AddStorageOptions(output_group)
 
     processing_group = argument_parser.add_argument_group(
         u'Processing Arguments')
@@ -577,7 +503,6 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
           u'risk.')
       time.sleep(5)
 
-    # TODO: added now since it can cause a deadlock.
     if self._process_archive_files:
       logging.warning(
           u'Scanning archive files currently can cause deadlock. Continue at '
@@ -587,8 +512,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     try:
       self.ParseOptions(options)
     except errors.BadConfigOption as exception:
-      logging.error(u'{0:s}'.format(exception))
-
+      self._output_writer.Write(u'ERROR: {0:s}'.format(exception))
       self._output_writer.Write(u'\n')
       self._output_writer.Write(argument_parser.format_usage())
       return False
@@ -601,7 +525,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     """Parses the options.
 
     Args:
-      options: the command line arguments (instance of argparse.Namespace).
+      options (argparse.Namespace): command line arguments.
 
     Raises:
       BadConfigOption: if the options are invalid.
@@ -609,10 +533,7 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     # Check the list options first otherwise required options will raise.
     self._ParseExtractionOptions(options)
     self._ParseOutputOptions(options)
-    # TODO: refactor usage of self._old_preprocess.
-    self._front_end.SetUseOldPreprocess(self._old_preprocess)
     self._ParseTimezoneOption(options)
-    self._ParseExperimentalOptions(options)
 
     self.show_info = getattr(options, u'show_info', False)
 
@@ -681,11 +602,11 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
       UserAbort: if the user initiated an abort.
     """
     self._front_end.SetDebugMode(self._debug_mode)
-    self._front_end.SetEnableProfiling(
-        self._enable_profiling,
-        profiling_sample_rate=self._profiling_sample_rate,
-        profiling_type=self._profiling_type)
-    self._front_end.SetStorageFile(self._output)
+    if self._enable_profiling:
+      self._front_end.EnableProfiling(
+          profiling_directory=self._profiling_directory,
+          profiling_sample_rate=self._profiling_sample_rate,
+          profiling_type=self._profiling_type)
     self._front_end.SetShowMemoryInformation(show_memory=self._foreman_verbose)
 
     scan_context = self.ScanSource()
@@ -720,32 +641,62 @@ class Log2TimelineTool(extraction_tool.ExtractionTool):
     else:
       status_update_callback = None
 
-    processing_status = self._front_end.ProcessSources(
-        self._source_path_specs, self._source_type,
+    session = self._front_end.CreateSession(
         command_line_arguments=self._command_line_arguments,
-        enable_sigsegv_handler=self._enable_sigsegv_handler,
         filter_file=self._filter_file,
+        parser_filter_expression=self._parser_filter_expression,
+        preferred_encoding=self.preferred_encoding,
+        preferred_year=self._preferred_year)
+
+    storage_writer = self._front_end.CreateStorageWriter(
+        session, self._output)
+    # TODO: handle errors.BadConfigOption
+
+    processing_status = self._front_end.ProcessSources(
+        session, storage_writer, self._source_path_specs, self._source_type,
+        enable_sigsegv_handler=self._enable_sigsegv_handler,
+        force_preprocessing=self._force_preprocessing,
         hasher_names_string=self._hasher_names_string,
         number_of_extraction_workers=self._number_of_extraction_workers,
-        parser_filter_string=self._parser_filter_string,
-        preferred_encoding=self.preferred_encoding,
+        process_archive_files=self._process_archive_files,
         single_process_mode=self._single_process_mode,
         status_update_callback=status_update_callback,
-        storage_serializer_format=self._storage_serializer_format,
-        timezone=self._timezone)
+        timezone=self._timezone, yara_rules_string=self._yara_rules_string)
+
+    if not processing_status:
+      self._output_writer.Write(
+          u'WARNING: missing processing status information.\n')
+
+    elif not processing_status.aborted:
+      if processing_status.error_path_specs:
+        self._output_writer.Write(u'Processing completed with errors.\n')
+      else:
+        self._output_writer.Write(u'Processing completed.\n')
+
+      number_of_errors = (
+          processing_status.foreman_status.number_of_produced_errors)
+      if number_of_errors:
+        output_text = u'\n'.join([
+            u'',
+            (u'Number of errors encountered while extracting events: '
+             u'{0:d}.').format(number_of_errors),
+            u'',
+            u'Use pinfo to inspect errors in more detail.',
+            u''])
+        self._output_writer.Write(output_text)
+
+      if processing_status.error_path_specs:
+        output_text = u'\n'.join([
+            u'',
+            u'Path specifications that could not be processed:',
+            u''])
+        self._output_writer.Write(output_text)
+        for path_spec in processing_status.error_path_specs:
+          self._output_writer.Write(path_spec.comparable)
+          self._output_writer.Write(u'\n')
 
-    if processing_status and not processing_status.error_detected:
-      self._output_writer.Write(u'Processing completed.\n')
-    else:
-      self._output_writer.Write(u'Processing completed with errors.\n')
     self._output_writer.Write(u'\n')
 
-    if processing_status and processing_status.error_path_specs:
-      self._output_writer.Write(u'Path specifications that caused errors:\n')
-      for path_spec_comparable in processing_status.error_path_specs:
-        self._output_writer.Write(path_spec_comparable)
-        self._output_writer.Write(u'\n')
-
   def ShowInfo(self):
     """Shows information about available hashers, parsers, plugins, etc."""
     self._output_writer.Write(
@@ -805,7 +756,7 @@ def Main():
     logging.warning(u'Aborted by user.')
     return False
 
-  except errors.SourceScannerError as exception:
+  except (errors.BadConfigOption, errors.SourceScannerError) as exception:
     logging.warning(exception)
     return False
 
