@@ -6,13 +6,13 @@ import unittest
 
 from plaso.frontend import preg as preg_frontend
 from plaso.lib import errors
+
 from tests.cli import test_lib as cli_test_lib
 
 from tools import preg
-from tools import test_lib
 
 
-class PregToolTest(test_lib.ToolTestCase):
+class PregToolTest(cli_test_lib.CLIToolTestCase):
   """Tests for the preg tool."""
 
   def _ExtractPluginsAndKey(self, string):
@@ -217,9 +217,11 @@ class PregToolTest(test_lib.ToolTestCase):
     self.assertGreater(line_count, 1400)
 
 
-class PregConsoleTest(test_lib.ToolTestCase):
+class PregConsoleTest(cli_test_lib.CLIToolTestCase):
   """Tests for the preg console."""
 
+  # pylint: disable=protected-access
+
   _EXPECTED_BANNER_HEADER = [
       b'',
       b'Welcome to PREG - home of the Plaso Windows Registry Parsing.',
@@ -349,9 +351,11 @@ class PregConsoleTest(test_lib.ToolTestCase):
         u'http://javadl.sun.com/webapps/download/AutoDL?BundleId=33742')
 
 
-class PregMagicClassTest(test_lib.ToolTestCase):
+class PregMagicClassTest(cli_test_lib.CLIToolTestCase):
   """Tests for the IPython magic class."""
 
+  # pylint: disable=protected-access
+
   def setUp(self):
     """Sets up the needed objects used throughout the test."""
     self._output_writer = cli_test_lib.TestOutputWriter(encoding=u'utf-8')
